@@ -18,7 +18,8 @@ Before installing the Python client library, you must make sure the following pa
 installed on your system:  
 
 * python 3.5 or later    
-* requests 2.21.0 or later    
+* requests 2.21.0 or later   
+* requests-toolbelt 0.9.1 or later
 * marshmallow 3.2.1 or later  
 
 
@@ -38,7 +39,7 @@ from netapp_ontap.resources import Volume, Snapshot
 ## Creating an object
 
 You can create an object in several different ways. Here are three examples of
-creating an equivalent `netapp_ontap.resources.volume` object.
+creating an equivalent `Volume` object.
 
 ```python
 from netapp_ontap.resources import Volume
@@ -76,8 +77,7 @@ This means that all objects and the associated actions reuse
 this same connection. See *Host connections* for more information.
 
 ```python
-from netapp_ontap import config
-from netapp_ontap.host_connection import HostConnection
+from netapp_ontap import config, HostConnection
 from netapp_ontap.resources import Volume, Snapshot
 
 config.CONNECTION = HostConnection('myhost.mycompany.com', 'username', 'password')
@@ -129,22 +129,22 @@ it is ignored.
 from netapp_ontap import config, HostConnection
 headers = {'my-header1':'my-header-value1', 'my-header2':'my-header-value2'}
 
-#Initialize a connection object with custom headers
+# Initialize a connection object with custom headers
 config.CONNECTION = HostConnection('myhost.mycompany.com', 'username', 'password', headers=headers)
 
-#Delete a header from a connection object
+# Delete a header from a connection object
 conn = HostConnection('myhost.mycompany.com', 'username', 'password', headers=headers)
 del conn.request_headers['my-header1']
 
-#Add a header to a connection object using the assignment operator
+# Add a header to a connection object using the assignment operator
 conn = HostConnection('myhost.mycompany.com', 'username', 'password', headers=headers)
 conn.request_headers['mynew-header'] = 'mynew-header-value'
 
-#Add headers to a connection object
+# Add headers to a connection object
 config.CONNECTION = HostConnection('myhost.mycompany.com', 'username' 'password')
 config.CONNECTION.request_headers = headers
 
-#Update an existing header using the assignment operator
+# Update an existing header using the assignment operator
 config.CONNECTION = HostConnection('myhost.mycompany.com','username','password', headers=headers)
 config.CONNECTION.request_headers['my-header1'] = 'my-new-header'
 ```
@@ -181,7 +181,7 @@ object and handle any errors. Refer to `netapp_ontap.error.NetAppRestError` for
 ```python
 # Set RAISE_API_ERRORS to False and check the HTTP response.
 config.RAISE_API_ERRORS = False
-response = Svm.find(name = "nonexistent_vs)
+response = Svm.find(name="nonexistent_vs")
 assert "entry doesn't exist" in response.http_response.text
 ```
 
@@ -365,26 +365,284 @@ foo = Foo()
 foo.class_ = "high"
 ```
 
+# Documentation
+
+To view the full documentation, visit https://library.netapp.com/ecmdocs/ECMLP2858435/html/index.html
+or to view an offline copy, see the `<python_environment>/lib/<python_version>/site_packages/netapp_ontap/docs`
+Documentation of ONTAP's REST APIs and other helpful resources can be found at https://devnet.netapp.com/restapi.
+
 # Compatibility
 
 The version assigned to the library consists of the major ONTAP release it is generated
-from and a minor version for the library within that release. The minor version allows the
-library to be updated within the same ONTAP release. For example, valid versions for
-the library associated with ONTAP 9.6 include 9.6.0, 9.6.1, and so on.
+from and a minor version for the library within that release. For example: within the
+ONTAP 9.7 product family, the library may ship several fix releases by incrementing the
+minor index: 9.7.0, 9.7.1, 9.7.2. The minor version
+allows the library to be updated at a cadence separate from ONTAP.
 
 Client libraries that have the same major version as ONTAP are completely compatible.
 For example, the libraries netapp-ontap-9.6.1 and netapp-ontap-9.6.4 are fully
 compatible with both ONTAP 9.6 and ONTAP 9.6P1.
 
-A client library with a major version that does not match the ONTAP release can still be
-used, however it will not be fully compatible with the REST API. For example, the library
-netapp-ontap-9.6.4 is only partially compatible with ONTAP 9.7. In these cases, the
-library may encounter unknown fields or APIs. When this occurs, the library will ignore
-unknown fields, return an error, or raise a runtime exception.
+A client library will support N-1 major versions of ONTAP with full backwards compatiblity
+of all APIs and fields. For example, a program written using client library 9.6.1 and
+talking to ONTAP 9.6 will continue to function consistently when the client library is
+updated to 9.7.0.
+
+A client library with a major version less than the ONTAP release can still be
+used, however it will not be able to access any of the new REST APIs. For example, the library
+netapp-ontap-9.6.4 is only partially compatible with ONTAP 9.7. In this case, the library will
+not have access to the newer APIs or fields offered by ONTAP, but scripts can continue to
+access any of the same 9.6 fields they were before without issue.
+
+For example a new property **volume.is_svm_root** was added with ONTAP 9.7.
+The following behaviors would be seen with different libraries and ONTAP combinations:
+
+* library 9.6.0 would ignore the value coming from an ONTAP 9.7 response
+
+* library 9.7.0 would fully support the property coming from an ONTAP 9.7+ response
+
+* library 9.7.0 would not produce any errors fro that property coming from an ONTAP 9.6 response
 
 # Changelog
 
 There are several changes to the Python Client Library and the ONTAP REST API, which are organized by release below.
+## 9.8.0 RC1 library updates
+
+** New **
+** Fixed issues **
+
+* [Bug ID 1349122](https://mysupport.netapp.com/NOW/cgi-bin/bol?Type=Detail&Display=1349122)
+
+Due to a type mismatch between documentation and implementation, some endpoints were failing because of a validation error.
+
+## ONTAP 9.8 REST API updates ##
+All new ONTAP APIs have corresponding library resource objects which can be used
+to perform the operations. See the `netapp_ontap.resources` package for details
+about each of the objects and their fields.
+
+For a summary of the changes in the ONTAP REST API between versions of ONTAP 9, see the [ONTAP 9 Release Notes](https://library.netapp.com/ecmdocs/ECMLP2492508/html/frameset.html).
+
+** New endpoints **
+
+* Endpoint: /cluster/firmware/history  
+  HTTP methods: GET  
+  This API retrieves the details history of firmware update requests for the cluster.  
+
+* Endpoint: /cluster/licensing/capacity-pools  
+  HTTP methods: GET  
+  This API retrieves information about associations between ONTAP nodes in the cluster and capacity pool licenses. It can also report how much capacity each node is consuming from the pool.  
+
+* Endpoint: /cluster/licensing/license-managers  
+  HTTP methods: GET, PATCH  
+  These APIs allow for managing information about the license manager associated with the cluster.  
+
+* Endpoint: /cluster/mediators  
+  HTTP methods: GET, POST, DELETE  
+  These APIs allow for adding or removing a mediator to MetroCluster over IP configuration as well as retrieving the status of the existing mediator.  
+
+* Endpoint: /cluster/metrocluster  
+  HTTP methods: GET, POST, PATCH  
+  These APIs allows for creating, performing operations, and retrieving relevant information pertaining to MetroCluster.  
+
+* Endpoint: /cluster/metrocluster/diagnostics  
+  HTTP methods: GET, POST
+  This API can be used to initiate a MetroCluster diagnostics operation and fetch the results of a completed diagnostic operation.  
+
+* Endpoint: /cluster/metrocluster/dr-groups  
+  HTTP methods: GET, POST, DELETE  
+  These APIs allow for creating, performing operations, and retrieving relevant information about MetroCluster DR groups.  
+
+* Endpoint: /cluster/metrocluster/interconnects  
+  HTTP methods: GET  
+  This API retrieves information pertaining to MetroCluster interconnect status.  
+
+* Endpoint: /cluster/metrocluster/nodes  
+  HTTP methods: GET  
+  This API retrieves details about MetroCluster nodes.  
+
+* Endpoint: /cluster/metrocluster/operations  
+  HTTP methods: GET  
+  This API retrieves the list of MetroCluster operations on the local cluster.  
+
+* Endpoint: /cluster/nodes/{uuid}/metrics  
+  HTTP methods: GET  
+  This API retrieves historical performance metrics for a node.  
+
+* Endpoint: /cluster/software/upload  
+  HTTP methods: POST  
+  This API uploads a software or firmware package located on the local filesystem.  
+
+* Endpoint: /network/ethernet/ports/{uuid}/metrics  
+  HTTP methdos: GET  
+  This API retrieves historical performance metrics for a port.  
+
+* Endpoint: /network/ethernet/switch/ports  
+  HTTP methods: GET  
+  This API can be used to get the port information for an ethernet switch used in a cluster or storage networks. 
+
+* Endpoint: /network/ethernet/switches  
+  HTTP methods: GET, PATCH  
+  These APIs can be used to retrieve and modify ethernet switches used for the cluster and/or storage networks.  
+
+* Endpoint: /network/fc/interfaces/{uuid}/metrics  
+  HTTP methods: GET  
+  This API retrieves historical performance metrics for an FC interface.  
+
+* Endpoint: /network/fc/ports/{uuid}/metrics  
+  HTTP methods: GET  
+  This API retrieves historical performance metrics for an FC port.  
+
+* Endpoint: /network/ip/interfaces/{uuid}/metrics  
+  HTTP methods: GET  
+  This API retrieves historical performance metrics for an interface.  
+
+* Endpoint: /network/ip/service-policies  
+  HTTP methods: POST, PATCH, DELETE  
+  These APIs allow for creating, modifying, and deleting a servicy policy for network interfaces.  
+
+* Endpoint: /storage/namespaces/{uuid}/metrics  
+  HTTP methods: GET  
+  This API retrieves historical performance metrics for an NVMe namespace.  
+
+* Endpoint: /security  
+  HTTP methods: PATCH  
+  This API updates the software FIPS mode or enables conversion of non-encrypted metadata volumes to encrypted metadata volumes and non-NAE aggregates to NAE aggregates.  
+
+* Endpoint: /security/azure-key-vaults  
+  HTTP methods: GET, POST, PATCH, DELETE  
+  These APIs allow for managing Azure Key Vaults on a cluster.  
+
+* Endpoint: /security/azure-key-vaults/{azure_key_vault.uuid}/rekey-internal  
+  HTTP methods: POST  
+  This API rekeys the internal key in the key hierarchy for an SVM with and AKV configuration.  
+
+* Endpoint: /security/azure-key-vaults/{azure_key_vault.uuid}/restore  
+  HTTP methods: POST  
+  This API restores the keys for an SVM from a configures AKV.  
+
+* Endpoint: /security/certificate-signing-request  
+  HTTP methods: POST  
+  This API generates a Certificate Signing Request and a private key pair.  
+
+* Endpoint: /security/gcp-kms  
+  HTTP methods: GET, POST, PATCH, DELETE  
+  These APIs allow ONTAP to store encryption keys using Google Cloud Key Management Services.  
+
+* Endpoint: /security/gcp-kms/{gcp_kms.uuid}/restore  
+  HTTP methods: POST  
+  This API restores the keys for an SVM from a configure Google Cloud Key Management Service.  
+
+* Endpoint: /security/ipsec  
+  HTTP methods: GET, PATCH  
+  These APIs allow for retrieving and updating IPsec status.  
+
+* Endpoint: /security/ipsec/policies  
+  HTTP methods: GET, POST, PATCH, DELETE  
+  These APIs allow for creating, retrieving information about, and updating IPsec policies.  
+
+* Endpoint: /security/ipsec/security-associations  
+  HTTP methods: GET  
+  This API retrieves the IPsec and IKE(Internet Key Exchange) security associations.  
+
+* Endpoint: /storage/file/copy  
+  HTTP methods: POST  
+  This API starts a file copy operations which is only supported on flexible volumes.  
+
+* Endpoint: /storage/file/move  
+  HTTP methods: POST  
+  This API starts a file move operation which is only supported on flexible volumes.  
+
+* Endpoint: /storage/flexcache/flexcaches/{uuid}  
+  HTTP methods: PATCH  
+  This API prepopulates a FlexCache volume in the cluster.  
+
+* Endpoint: /storage/monitored-files  
+  HTTP methods: GET, POST, DELETE  
+  These APIs allow for creating, deleting, and retrieving information about monitored files.  
+
+* Endpoint: /storage/monitored-files/{monitored_file.uuid}/metrics  
+  HTTP methods: GET  
+  This API retrieves historical performance metrics for the monitored file.  
+
+* Endpoint: /storage/snapshot-policies/{snapshot_policy.uuid}/schedules  
+  HTTP methods: GET, POST, PATCH, DELETE  
+  These APIs perform operations related to Snapshot copy policy schedules.  
+
+* Endpoint: /storage/volume-efficiency-policies  
+  HTTP methods: GET, POST, PATCH, DELETE  
+  These APIs allow for configuring volume efficiency policies on a cluster.  
+
+* Endpoint: /storage/volumes/{volume.uuid}/files/{path}  
+  HTTP methods: POST, PATCH, DELETE  
+  These APIs allow for creating files, modifying files, and deleting files on a volume.  
+
+* Endpoint: /private/protocols/audit/audit-log-redirect  
+  HTTP methods: GET, POST, PATCH, DELETE  
+  These APIs can be used to specify a dedicated SVM for all NAS auditing event log to reside in.  
+
+* Endpoint: /protocols/cifs/sessions  
+  HTTP methods: GET  
+  This API retrieves the CIFS sessions information for all SVMs.  
+
+* Endpoint: /protocols/cifs/sessions/{node.uuid}/{svm.uuid}/{identifier}/{connection_id}  
+  HTTP methods: GET  
+  This API retrieves SMB session information for a specific SMF connection of a SVM in a node.  
+* Endpoint: /protocols/file-access-tracing/events  
+  HTTP methods: GET, DELETE  
+  These APIs retrieves or delete trace results for access allowed or denied events.  
+
+* Endpoint: /protocols/file-access-tracing/filters  
+  HTTP methods: GET, POST, PATCH, DELETE  
+  These APIs manage security trace filter entries.  
+
+* Endpoint: /protocols/file-security/effective-permissions/{svm.uuid}/{path}  
+  HTTP methods: GET  
+  This API displays the effective permissions granted to a Windows or UNIX user on the specified file or folder path.  
+
+* Endpoint: /private/manage/event-remediations  
+  HTTP methods: GET, PATCH  
+  These APIs allow for retrieving about and performing event management actions.  
+
+* Endpoint: /protocols/s3/buckets  
+  HTTP methods: POST    
+  This API creates the S3 bucket configuration for an SVM.  
+
+* Endpoint: /protocols/s3/buckets/{svm.uuid}/{uuid}  
+  HTTP methods: GET, PATCH, DELETE  
+  These APIs manage S3 bucket configurations for the specified SVM.  
+
+* Endpoint: /protocols/s3/services/{svm.uuid}/groups  
+  HTTP methods: GET, POST, PATCH, DELETE  
+  These APIs manage S3 group configurations for the specified SVM.  
+
+* Endpoint: /protocols/s3/services/{svm.uuid}/metrics  
+  HTTP methods: GET  
+  This API retrieves historical performance metrics for the S3 protocol of an SVM.  
+
+* Endpoint: /protocols/s4/services/{svm.uuid}/policies  
+  HTTP methods: GET, POST, PATCH, DELETE  
+  These APIs allow for configuring S3 policies for the specified SVM.  
+
+
+## 9.7.3 library updates  
+(2020-07-21)
+
+**Fixed issues**
+
+* [Bug ID 1322090](https://mysupport.netapp.com/NOW/cgi-bin/bol?Type=Detail&Display=1322090)  
+  When polling jobs, the certificate verification setting was hard-coded to False, so it would behave the same regardless of how the user set it.
+
+* [Bug ID 1322095](https://mysupport.netapp.com/NOW/cgi-bin/bol?Type=Detail&Display=1322095) 
+  The get_collection() call using the connection parameter was not correctly setting the connection on the returned resource objects.
+
+
+## 9.7.1 library updates  
+(2020-04-06)
+
+**New**
+
+* A `count_collection()` method is now available on all resources which have a `get_collection()`. This method is a shortcut for getting only the number of items matching a query. For example: `Volume.count_collection(name="backup_vol*")` is roughly equivalent to `len(list(Volume.get_collection(name="backup_vol*")))`.
+
 ## 9.7.0 GA library updates  
 (2020-01-23)
 
@@ -426,6 +684,8 @@ All new ONTAP APIs have corresponding library resource objects which can be used
 to perform the operations. See the `netapp_ontap.resources` package for details
 about each of the objects and their fields.
 
+For a summary of the changes in the ONTAP REST API between versions of ONTAP 9, see the [ONTAP 9 Release Notes](https://library.netapp.com/ecmdocs/ECMLP2492508/html/frameset.html).
+
 **New endpoints** 
 
 * Endpoint: /cluster/nodes/{uuid}  
@@ -599,7 +859,7 @@ Initial release of the library
 
 # Copyright, trademarks, and feedback
 ## Copyright information
-Copyright &copy; 2019 NetApp, Inc. All Rights Reserved. Printed in the U.S.
+Copyright &copy; 2020 NetApp, Inc. All Rights Reserved. Printed in the U.S.
 
 No part of this document covered by copyright may be reproduced in any form or by any means—graphic,
 electronic, or mechanical, including photocopying, recording, taping, or storage in an electronic
@@ -666,4 +926,4 @@ from netapp_ontap.error import NetAppRestError
 from netapp_ontap.host_connection import HostConnection
 from netapp_ontap.response import NetAppResponse
 
-__version__ = "9.7.3"
+__version__ = "9.8.0"
