@@ -1,6 +1,6 @@
 # pylint: disable=line-too-long
 """
-Copyright &copy; 2019 NetApp Inc. All rights reserved.
+Copyright &copy; 2020 NetApp Inc. All rights reserved.
 
 This module defines the custom exception type. All exceptions raised by
 the library descend from this type.
@@ -8,13 +8,17 @@ the library descend from this type.
 
 from typing import Optional  # pylint: disable=unused-import
 
-import requests
+from netapp_ontap.response import NetAppResponse
 
-if False:  # pylint: disable=using-constant-test
-    # This is for mypy's benefit. Otherwise, it can't find the name when
-    # examining the return type of http_err_response. But If we import it in
-    # the module scope, we have a cyclic import problem.
-    from netapp_ontap.response import NetAppResponse  # pylint: disable=unused-import
+
+# Error message that is called when a user hits either a MemoryError or OverflowError
+# when trying to send large files via a multipart/form-data post/patch through
+# the requests library.
+FILE_SIZE_WARNING = (
+    "One of the file(s) you are trying to upload may be too large. Install these"
+    " additional dependencies to handle the large file upload and try again."
+    "\npip install requests[security]"
+)
 
 
 class NetAppRestError(Exception):
@@ -33,16 +37,14 @@ class NetAppRestError(Exception):
             cause: An exception object that caused this exception to be raised.
         """
 
-        from netapp_ontap.response import NetAppResponse  # pylint: disable=redefined-outer-name
-
         msg = message if message else ""
         if cause:
             self.cause = cause
             msg += " Caused by %r" % cause
-            if isinstance(cause, requests.exceptions.RequestException):
-                self._response = NetAppResponse(cause.response)
+            if getattr(cause, "response", None) is not None:
                 try:
-                    err_msg = cause.response.json().get("error", {}).get("message")
+                    self._response = NetAppResponse(cause.response)  # type: ignore
+                    err_msg = cause.response.json().get("error", {}).get("message")  # type: ignore
                     if err_msg:
                         msg += ": %s" % err_msg
                 except Exception:  # pylint: disable=broad-except
@@ -53,7 +55,7 @@ class NetAppRestError(Exception):
         super().__init__(msg)
 
     @property
-    def http_err_response(self) -> "Optional[NetAppResponse]":
+    def http_err_response(self) -> Optional[NetAppResponse]:
         """Describes a response to an API request that contains an error.
 
         Returns:
