@@ -1,19 +1,24 @@
 # pylint: disable=line-too-long
 """
-Copyright &copy; 2019 NetApp Inc.
+Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
 
 This module defines a host connection object which is used to communicate with
 the API host.
 """
-
+from contextlib import contextmanager
+import copy
 from http.client import responses
 import logging
-from typing import Optional, Tuple
+from typing import Generator, Optional, Tuple
+import urllib.parse
+
+
 
 import requests
 from requests.adapters import HTTPAdapter
 
+
 # prevent "No handlers" message if consumer application doesn't configure logging at all
 LOGGER = logging.getLogger(__name__)
 LOGGER.addHandler(logging.NullHandler())
@@ -180,6 +185,15 @@ class HostConnection:  # pylint: disable=too-many-instance-attributes
         else:
             raise TypeError("Request headers must be specified as a 'dict' type")
 
+    @contextmanager
+    def with_headers(self, headers: dict) -> Generator["HostConnection", None, None]:
+        """ Manually set the headers field of the connection object """
+        old_headers = copy.deepcopy(self.request_headers)
+        self.headers = headers
+        yield self
+        self.headers = old_headers
+        self._request_session = None
+
     def __enter__(self):
         global _HOST_CONTEXT  # pylint: disable=global-statement
         self._old_context = _HOST_CONTEXT
@@ -243,8 +257,9 @@ class LoggingAdapter(HTTPAdapter):
         cert=None,
         proxies=None,
     ) -> requests.Response:
-        from netapp_ontap import utils  # pylint: disable=cyclic-import
         timeout = timeout if timeout else self.timeout
+        request.url = _percent_encode_spaces(request.url)
+        from netapp_ontap import utils  # pylint: disable=cyclic-import
         response = super().send(
             request, stream=stream, timeout=timeout, verify=verify,
             cert=cert, proxies=proxies,
@@ -275,3 +290,15 @@ def pretty_print_request_response(response: requests.Response) -> None:
     result += "\n" + response.text
     result += "\n------------------------------"
     LOGGER.debug(result)
+
+
+def _percent_encode_spaces(url: str) -> str:
+    """ONTAP likes spaces in query parameters to be space encoded, but the requests
+    library encodes them as + by default. Here, we will fix that up so that ONTAP
+    will return correct responses.
+    """
+
+    parse_result = urllib.parse.urlparse(url)
+    query_data = dict(urllib.parse.parse_qsl(parse_result.query))
+    query_data_str = urllib.parse.urlencode(query_data, quote_via=urllib.parse.quote)
+    return urllib.parse.urlunparse(parse_result._replace(query=query_data_str))
