@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["AggregateDataEncryption", "AggregateDataEncryptionSchema"]
@@ -26,26 +20,32 @@ class AggregateDataEncryptionSchema(ResourceSchema):
     """The fields of the AggregateDataEncryption object"""
 
     drive_protection_enabled = fields.Boolean(data_key="drive_protection_enabled")
-    r""" Aggregate uses self-encrypting drives with data protection enabled. """
+    r""" Specifies whether the aggregate uses self-encrypting drives with data protection enabled. """
 
     software_encryption_enabled = fields.Boolean(data_key="software_encryption_enabled")
-    r""" NetApp Aggregate Encryption enabled. All data in the aggregate is encrypted. """
+    r""" Specifies whether NetApp aggregate encryption is enabled. All data in the aggregate is encrypted. """
 
     @property
     def resource(self):
         return AggregateDataEncryption
 
-    @property
-    def patchable_fields(self):
-        return [
-        ]
+    gettable_fields = [
+        "drive_protection_enabled",
+        "software_encryption_enabled",
+    ]
+    """drive_protection_enabled,software_encryption_enabled,"""
 
-    @property
-    def postable_fields(self):
-        return [
-        ]
+    patchable_fields = [
+        "software_encryption_enabled",
+    ]
+    """software_encryption_enabled,"""
+
+    postable_fields = [
+        "software_encryption_enabled",
+    ]
+    """software_encryption_enabled,"""
 
 
-class AggregateDataEncryption(Resource):  # pylint: disable=missing-docstring
+class AggregateDataEncryption(Resource):
 
     _schema = AggregateDataEncryptionSchema
