@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["AggregateSpaceCloudStorage", "AggregateSpaceCloudStorageSchema"]
@@ -25,8 +19,8 @@ __pdoc__ = {
 class AggregateSpaceCloudStorageSchema(ResourceSchema):
     """The fields of the AggregateSpaceCloudStorage object"""
 
-    used = fields.Integer(data_key="used")
-    r""" Used space in bytes in the cloud store. Only applicable for aggregate with a cloud store tier.
+    used = Size(data_key="used")
+    r""" Used space in bytes in the cloud store. Only applicable for aggregates with a cloud store tier.
 
 Example: 402743264 """
 
@@ -34,17 +28,20 @@ Example: 402743264 """
     def resource(self):
         return AggregateSpaceCloudStorage
 
-    @property
-    def patchable_fields(self):
-        return [
-        ]
+    gettable_fields = [
+        "used",
+    ]
+    """used,"""
 
-    @property
-    def postable_fields(self):
-        return [
-        ]
+    patchable_fields = [
+    ]
+    """"""
+
+    postable_fields = [
+    ]
+    """"""
 
 
-class AggregateSpaceCloudStorage(Resource):  # pylint: disable=missing-docstring
+class AggregateSpaceCloudStorage(Resource):
 
     _schema = AggregateSpaceCloudStorageSchema
