@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["ApplicationComponentApplication", "ApplicationComponentApplicationSchema"]
@@ -38,17 +32,22 @@ class ApplicationComponentApplicationSchema(ResourceSchema):
     def resource(self):
         return ApplicationComponentApplication
 
-    @property
-    def patchable_fields(self):
-        return [
-        ]
+    gettable_fields = [
+        "links",
+        "name",
+        "uuid",
+    ]
+    """links,name,uuid,"""
 
-    @property
-    def postable_fields(self):
-        return [
-        ]
+    patchable_fields = [
+    ]
+    """"""
+
+    postable_fields = [
+    ]
+    """"""
 
 
-class ApplicationComponentApplication(Resource):  # pylint: disable=missing-docstring
+class ApplicationComponentApplication(Resource):
 
     _schema = ApplicationComponentApplicationSchema
