@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["ApplicationLinks", "ApplicationLinksSchema"]
@@ -35,21 +29,21 @@ class ApplicationLinksSchema(ResourceSchema):
     def resource(self):
         return ApplicationLinks
 
-    @property
-    def patchable_fields(self):
-        return [
-            "self_",
-            "snapshots",
-        ]
+    gettable_fields = [
+        "self_",
+        "snapshots",
+    ]
+    """self_,snapshots,"""
 
-    @property
-    def postable_fields(self):
-        return [
-            "self_",
-            "snapshots",
-        ]
+    patchable_fields = [
+    ]
+    """"""
+
+    postable_fields = [
+    ]
+    """"""
 
 
-class ApplicationLinks(Resource):  # pylint: disable=missing-docstring
+class ApplicationLinks(Resource):
 
     _schema = ApplicationLinksSchema
