@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["ApplicationLunMappingObjectIgroup", "ApplicationLunMappingObjectIgroupSchema"]
@@ -38,19 +32,24 @@ class ApplicationLunMappingObjectIgroupSchema(ResourceSchema):
     def resource(self):
         return ApplicationLunMappingObjectIgroup
 
-    @property
-    def patchable_fields(self):
-        return [
-            "initiators",
-        ]
+    gettable_fields = [
+        "initiators",
+        "name",
+        "uuid",
+    ]
+    """initiators,name,uuid,"""
 
-    @property
-    def postable_fields(self):
-        return [
-            "initiators",
-        ]
+    patchable_fields = [
+        "initiators",
+    ]
+    """initiators,"""
+
+    postable_fields = [
+        "initiators",
+    ]
+    """initiators,"""
 
 
-class ApplicationLunMappingObjectIgroup(Resource):  # pylint: disable=missing-docstring
+class ApplicationLunMappingObjectIgroup(Resource):
 
     _schema = ApplicationLunMappingObjectIgroupSchema
