@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["ApplicationLunObject", "ApplicationLunObjectSchema"]
@@ -25,13 +19,13 @@ __pdoc__ = {
 class ApplicationLunObjectSchema(ResourceSchema):
     """The fields of the ApplicationLunObject object"""
 
-    creation_timestamp = fields.DateTime(data_key="creation_timestamp")
+    creation_timestamp = ImpreciseDateTime(data_key="creation_timestamp")
     r""" LUN creation time """
 
     path = fields.Str(data_key="path")
     r""" LUN path """
 
-    size = fields.Integer(data_key="size")
+    size = Size(data_key="size")
     r""" LUN size """
 
     uuid = fields.Str(data_key="uuid")
@@ -41,17 +35,23 @@ class ApplicationLunObjectSchema(ResourceSchema):
     def resource(self):
         return ApplicationLunObject
 
-    @property
-    def patchable_fields(self):
-        return [
-        ]
+    gettable_fields = [
+        "creation_timestamp",
+        "path",
+        "size",
+        "uuid",
+    ]
+    """creation_timestamp,path,size,uuid,"""
 
-    @property
-    def postable_fields(self):
-        return [
-        ]
+    patchable_fields = [
+    ]
+    """"""
+
+    postable_fields = [
+    ]
+    """"""
 
 
-class ApplicationLunObject(Resource):  # pylint: disable=missing-docstring
+class ApplicationLunObject(Resource):
 
     _schema = ApplicationLunObjectSchema
