@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["ApplicationNamespaceObject", "ApplicationNamespaceObjectSchema"]
@@ -28,13 +22,13 @@ class ApplicationNamespaceObjectSchema(ResourceSchema):
     links = fields.Nested("netapp_ontap.models.self_link.SelfLinkSchema", unknown=EXCLUDE, data_key="_links")
     r""" The links field of the application_namespace_object. """
 
-    creation_timestamp = fields.DateTime(data_key="creation_timestamp")
+    creation_timestamp = ImpreciseDateTime(data_key="creation_timestamp")
     r""" Namespace creation time """
 
     name = fields.Str(data_key="name")
     r""" Namespace name """
 
-    size = fields.Integer(data_key="size")
+    size = Size(data_key="size")
     r""" Namespace size """
 
     uuid = fields.Str(data_key="uuid")
@@ -44,17 +38,24 @@ class ApplicationNamespaceObjectSchema(ResourceSchema):
     def resource(self):
         return ApplicationNamespaceObject
 
-    @property
-    def patchable_fields(self):
-        return [
-        ]
+    gettable_fields = [
+        "links",
+        "creation_timestamp",
+        "name",
+        "size",
+        "uuid",
+    ]
+    """links,creation_timestamp,name,size,uuid,"""
 
-    @property
-    def postable_fields(self):
-        return [
-        ]
+    patchable_fields = [
+    ]
+    """"""
+
+    postable_fields = [
+    ]
+    """"""
 
 
-class ApplicationNamespaceObject(Resource):  # pylint: disable=missing-docstring
+class ApplicationNamespaceObject(Resource):
 
     _schema = ApplicationNamespaceObjectSchema
