@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["ApplicationRpoComponents", "ApplicationRpoComponentsSchema"]
@@ -38,19 +32,24 @@ class ApplicationRpoComponentsSchema(ResourceSchema):
     def resource(self):
         return ApplicationRpoComponents
 
-    @property
-    def patchable_fields(self):
-        return [
-            "rpo",
-        ]
+    gettable_fields = [
+        "name",
+        "rpo",
+        "uuid",
+    ]
+    """name,rpo,uuid,"""
 
-    @property
-    def postable_fields(self):
-        return [
-            "rpo",
-        ]
+    patchable_fields = [
+        "rpo",
+    ]
+    """rpo,"""
+
+    postable_fields = [
+        "rpo",
+    ]
+    """rpo,"""
 
 
-class ApplicationRpoComponents(Resource):  # pylint: disable=missing-docstring
+class ApplicationRpoComponents(Resource):
 
     _schema = ApplicationRpoComponentsSchema
