@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["ApplicationRpoRpo", "ApplicationRpoRpoSchema"]
@@ -35,21 +29,25 @@ class ApplicationRpoRpoSchema(ResourceSchema):
     def resource(self):
         return ApplicationRpoRpo
 
-    @property
-    def patchable_fields(self):
-        return [
-            "local",
-            "remote",
-        ]
+    gettable_fields = [
+        "local",
+        "remote",
+    ]
+    """local,remote,"""
 
-    @property
-    def postable_fields(self):
-        return [
-            "local",
-            "remote",
-        ]
+    patchable_fields = [
+        "local",
+        "remote",
+    ]
+    """local,remote,"""
+
+    postable_fields = [
+        "local",
+        "remote",
+    ]
+    """local,remote,"""
 
 
-class ApplicationRpoRpo(Resource):  # pylint: disable=missing-docstring
+class ApplicationRpoRpo(Resource):
 
     _schema = ApplicationRpoRpoSchema
