@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["ApplicationRpoRpoLocal", "ApplicationRpoRpoLocalSchema"]
@@ -42,17 +36,21 @@ Valid choices:
     def resource(self):
         return ApplicationRpoRpoLocal
 
-    @property
-    def patchable_fields(self):
-        return [
-        ]
+    gettable_fields = [
+        "description",
+        "name",
+    ]
+    """description,name,"""
 
-    @property
-    def postable_fields(self):
-        return [
-        ]
+    patchable_fields = [
+    ]
+    """"""
+
+    postable_fields = [
+    ]
+    """"""
 
 
-class ApplicationRpoRpoLocal(Resource):  # pylint: disable=missing-docstring
+class ApplicationRpoRpoLocal(Resource):
 
     _schema = ApplicationRpoRpoLocalSchema
