@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["ApplicationSanAccessFcpEndpoint", "ApplicationSanAccessFcpEndpointSchema"]
@@ -32,17 +26,23 @@ class ApplicationSanAccessFcpEndpointSchema(ResourceSchema):
     def resource(self):
         return ApplicationSanAccessFcpEndpoint
 
-    @property
-    def patchable_fields(self):
-        return [
-        ]
+    gettable_fields = [
+        "interface.links",
+        "interface.name",
+        "interface.uuid",
+        "interface.wwpn",
+    ]
+    """interface.links,interface.name,interface.uuid,interface.wwpn,"""
 
-    @property
-    def postable_fields(self):
-        return [
-        ]
+    patchable_fields = [
+    ]
+    """"""
+
+    postable_fields = [
+    ]
+    """"""
 
 
-class ApplicationSanAccessFcpEndpoint(Resource):  # pylint: disable=missing-docstring
+class ApplicationSanAccessFcpEndpoint(Resource):
 
     _schema = ApplicationSanAccessFcpEndpointSchema
