@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["ApplicationStatisticsIops1", "ApplicationStatisticsIops1Schema"]
@@ -25,27 +19,31 @@ __pdoc__ = {
 class ApplicationStatisticsIops1Schema(ResourceSchema):
     """The fields of the ApplicationStatisticsIops1 object"""
 
-    per_tb = fields.Integer(data_key="per_tb")
+    per_tb = Size(data_key="per_tb")
     r""" The number of IOPS per terabyte of logical space currently being used by the application. """
 
-    total = fields.Integer(data_key="total")
+    total = Size(data_key="total")
     r""" The total number of IOPS being used by the application. """
 
     @property
     def resource(self):
         return ApplicationStatisticsIops1
 
-    @property
-    def patchable_fields(self):
-        return [
-        ]
+    gettable_fields = [
+        "per_tb",
+        "total",
+    ]
+    """per_tb,total,"""
 
-    @property
-    def postable_fields(self):
-        return [
-        ]
+    patchable_fields = [
+    ]
+    """"""
+
+    postable_fields = [
+    ]
+    """"""
 
 
-class ApplicationStatisticsIops1(Resource):  # pylint: disable=missing-docstring
+class ApplicationStatisticsIops1(Resource):
 
     _schema = ApplicationStatisticsIops1Schema
