@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["ApplicationStatisticsLatency", "ApplicationStatisticsLatencySchema"]
@@ -25,27 +19,31 @@ __pdoc__ = {
 class ApplicationStatisticsLatencySchema(ResourceSchema):
     """The fields of the ApplicationStatisticsLatency object"""
 
-    average = fields.Integer(data_key="average")
+    average = Size(data_key="average")
     r""" The cumulative average response time in microseconds for this component. """
 
-    raw = fields.Integer(data_key="raw")
+    raw = Size(data_key="raw")
     r""" The cumulative response time in microseconds for this component. """
 
     @property
     def resource(self):
         return ApplicationStatisticsLatency
 
-    @property
-    def patchable_fields(self):
-        return [
-        ]
+    gettable_fields = [
+        "average",
+        "raw",
+    ]
+    """average,raw,"""
 
-    @property
-    def postable_fields(self):
-        return [
-        ]
+    patchable_fields = [
+    ]
+    """"""
+
+    postable_fields = [
+    ]
+    """"""
 
 
-class ApplicationStatisticsLatency(Resource):  # pylint: disable=missing-docstring
+class ApplicationStatisticsLatency(Resource):
 
     _schema = ApplicationStatisticsLatencySchema
