@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["ApplicationStatisticsSnapshot", "ApplicationStatisticsSnapshotSchema"]
@@ -25,27 +19,31 @@ __pdoc__ = {
 class ApplicationStatisticsSnapshotSchema(ResourceSchema):
     """The fields of the ApplicationStatisticsSnapshot object"""
 
-    reserve = fields.Integer(data_key="reserve")
+    reserve = Size(data_key="reserve")
     r""" The amount of space reserved by the system for Snapshot copies. """
 
-    used = fields.Integer(data_key="used")
+    used = Size(data_key="used")
     r""" The amount of spacing currently in use by the system to store Snapshot copies. """
 
     @property
     def resource(self):
         return ApplicationStatisticsSnapshot
 
-    @property
-    def patchable_fields(self):
-        return [
-        ]
+    gettable_fields = [
+        "reserve",
+        "used",
+    ]
+    """reserve,used,"""
 
-    @property
-    def postable_fields(self):
-        return [
-        ]
+    patchable_fields = [
+    ]
+    """"""
+
+    postable_fields = [
+    ]
+    """"""
 
 
-class ApplicationStatisticsSnapshot(Resource):  # pylint: disable=missing-docstring
+class ApplicationStatisticsSnapshot(Resource):
 
     _schema = ApplicationStatisticsSnapshotSchema
