@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["ApplicationSubsystemMapObject", "ApplicationSubsystemMapObjectSchema"]
@@ -38,19 +32,24 @@ class ApplicationSubsystemMapObjectSchema(ResourceSchema):
     def resource(self):
         return ApplicationSubsystemMapObject
 
-    @property
-    def patchable_fields(self):
-        return [
-            "subsystem",
-        ]
+    gettable_fields = [
+        "anagrpid",
+        "nsid",
+        "subsystem",
+    ]
+    """anagrpid,nsid,subsystem,"""
 
-    @property
-    def postable_fields(self):
-        return [
-            "subsystem",
-        ]
+    patchable_fields = [
+        "subsystem",
+    ]
+    """subsystem,"""
+
+    postable_fields = [
+        "subsystem",
+    ]
+    """subsystem,"""
 
 
-class ApplicationSubsystemMapObject(Resource):  # pylint: disable=missing-docstring
+class ApplicationSubsystemMapObject(Resource):
 
     _schema = ApplicationSubsystemMapObjectSchema
