@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["ApplicationSubsystemMapObjectSubsystemLinks", "ApplicationSubsystemMapObjectSubsystemLinksSchema"]
@@ -32,17 +26,20 @@ class ApplicationSubsystemMapObjectSubsystemLinksSchema(ResourceSchema):
     def resource(self):
         return ApplicationSubsystemMapObjectSubsystemLinks
 
-    @property
-    def patchable_fields(self):
-        return [
-        ]
+    gettable_fields = [
+        "self_",
+    ]
+    """self_,"""
 
-    @property
-    def postable_fields(self):
-        return [
-        ]
+    patchable_fields = [
+    ]
+    """"""
+
+    postable_fields = [
+    ]
+    """"""
 
 
-class ApplicationSubsystemMapObjectSubsystemLinks(Resource):  # pylint: disable=missing-docstring
+class ApplicationSubsystemMapObjectSubsystemLinks(Resource):
 
     _schema = ApplicationSubsystemMapObjectSubsystemLinksSchema
