@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["ApplicationVolumeObject", "ApplicationVolumeObjectSchema"]
@@ -25,13 +19,13 @@ __pdoc__ = {
 class ApplicationVolumeObjectSchema(ResourceSchema):
     """The fields of the ApplicationVolumeObject object"""
 
-    creation_timestamp = fields.DateTime(data_key="creation_timestamp")
+    creation_timestamp = ImpreciseDateTime(data_key="creation_timestamp")
     r""" Creation time """
 
     name = fields.Str(data_key="name")
     r""" Name """
 
-    size = fields.Integer(data_key="size")
+    size = Size(data_key="size")
     r""" Size """
 
     uuid = fields.Str(data_key="uuid")
@@ -41,17 +35,23 @@ class ApplicationVolumeObjectSchema(ResourceSchema):
     def resource(self):
         return ApplicationVolumeObject
 
-    @property
-    def patchable_fields(self):
-        return [
-        ]
+    gettable_fields = [
+        "creation_timestamp",
+        "name",
+        "size",
+        "uuid",
+    ]
+    """creation_timestamp,name,size,uuid,"""
 
-    @property
-    def postable_fields(self):
-        return [
-        ]
+    patchable_fields = [
+    ]
+    """"""
+
+    postable_fields = [
+    ]
+    """"""
 
 
-class ApplicationVolumeObject(Resource):  # pylint: disable=missing-docstring
+class ApplicationVolumeObject(Resource):
 
     _schema = ApplicationVolumeObjectSchema
