@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["AutosupportMessageError", "AutosupportMessageErrorSchema"]
@@ -25,7 +19,7 @@ __pdoc__ = {
 class AutosupportMessageErrorSchema(ResourceSchema):
     """The fields of the AutosupportMessageError object"""
 
-    code = fields.Integer(data_key="code")
+    code = Size(data_key="code")
     r""" Error code
 
 Example: 53149746 """
@@ -39,17 +33,21 @@ Example: Could not resolve host: test.com """
     def resource(self):
         return AutosupportMessageError
 
-    @property
-    def patchable_fields(self):
-        return [
-        ]
+    gettable_fields = [
+        "code",
+        "message",
+    ]
+    """code,message,"""
 
-    @property
-    def postable_fields(self):
-        return [
-        ]
+    patchable_fields = [
+    ]
+    """"""
+
+    postable_fields = [
+    ]
+    """"""
 
 
-class AutosupportMessageError(Resource):  # pylint: disable=missing-docstring
+class AutosupportMessageError(Resource):
 
     _schema = AutosupportMessageErrorSchema
