@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["BackupNode", "BackupNodeSchema"]
@@ -32,19 +26,22 @@ class BackupNodeSchema(ResourceSchema):
     def resource(self):
         return BackupNode
 
-    @property
-    def patchable_fields(self):
-        return [
-            "name",
-        ]
+    gettable_fields = [
+        "name",
+    ]
+    """name,"""
 
-    @property
-    def postable_fields(self):
-        return [
-            "name",
-        ]
+    patchable_fields = [
+        "name",
+    ]
+    """name,"""
+
+    postable_fields = [
+        "name",
+    ]
+    """name,"""
 
 
-class BackupNode(Resource):  # pylint: disable=missing-docstring
+class BackupNode(Resource):
 
     _schema = BackupNodeSchema
