@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["BgpPeerGroupPeer", "BgpPeerGroupPeerSchema"]
@@ -30,27 +24,31 @@ class BgpPeerGroupPeerSchema(ResourceSchema):
 
 Example: 10.10.10.7 """
 
-    asn = fields.Integer(data_key="asn")
+    asn = Size(data_key="asn")
     r""" Autonomous system number of peer """
 
     @property
     def resource(self):
         return BgpPeerGroupPeer
 
-    @property
-    def patchable_fields(self):
-        return [
-            "address",
-        ]
+    gettable_fields = [
+        "address",
+        "asn",
+    ]
+    """address,asn,"""
 
-    @property
-    def postable_fields(self):
-        return [
-            "address",
-            "asn",
-        ]
+    patchable_fields = [
+        "address",
+    ]
+    """address,"""
+
+    postable_fields = [
+        "address",
+        "asn",
+    ]
+    """address,asn,"""
 
 
-class BgpPeerGroupPeer(Resource):  # pylint: disable=missing-docstring
+class BgpPeerGroupPeer(Resource):
 
     _schema = BgpPeerGroupPeerSchema
