@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["ChassisFrus", "ChassisFrusSchema"]
@@ -48,23 +42,28 @@ Valid choices:
     def resource(self):
         return ChassisFrus
 
-    @property
-    def patchable_fields(self):
-        return [
-            "id",
-            "state",
-            "type",
-        ]
+    gettable_fields = [
+        "id",
+        "state",
+        "type",
+    ]
+    """id,state,type,"""
 
-    @property
-    def postable_fields(self):
-        return [
-            "id",
-            "state",
-            "type",
-        ]
+    patchable_fields = [
+        "id",
+        "state",
+        "type",
+    ]
+    """id,state,type,"""
+
+    postable_fields = [
+        "id",
+        "state",
+        "type",
+    ]
+    """id,state,type,"""
 
 
-class ChassisFrus(Resource):  # pylint: disable=missing-docstring
+class ChassisFrus(Resource):
 
     _schema = ChassisFrusSchema
