@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["CifsServiceDelete", "CifsServiceDeleteSchema"]
@@ -32,19 +26,22 @@ class CifsServiceDeleteSchema(ResourceSchema):
     def resource(self):
         return CifsServiceDelete
 
-    @property
-    def patchable_fields(self):
-        return [
-            "ad_domain",
-        ]
+    gettable_fields = [
+        "ad_domain",
+    ]
+    """ad_domain,"""
 
-    @property
-    def postable_fields(self):
-        return [
-            "ad_domain",
-        ]
+    patchable_fields = [
+        "ad_domain",
+    ]
+    """ad_domain,"""
+
+    postable_fields = [
+        "ad_domain",
+    ]
+    """ad_domain,"""
 
 
-class CifsServiceDelete(Resource):  # pylint: disable=missing-docstring
+class CifsServiceDelete(Resource):
 
     _schema = CifsServiceDeleteSchema
