@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["CloudStorageTier", "CloudStorageTierSchema"]
@@ -28,28 +22,30 @@ class CloudStorageTierSchema(ResourceSchema):
     cloud_store = fields.Nested("netapp_ontap.resources.cloud_store.CloudStoreSchema", unknown=EXCLUDE, data_key="cloud_store")
     r""" The cloud_store field of the cloud_storage_tier. """
 
-    used = fields.Integer(data_key="used")
+    used = Size(data_key="used")
     r""" Capacity used in bytes in the cloud store by this aggregate. This is a cached value calculated every 5 minutes. """
 
     @property
     def resource(self):
         return CloudStorageTier
 
-    @property
-    def patchable_fields(self):
-        return [
-            "cloud_store.name",
-            "cloud_store.uuid",
-        ]
+    gettable_fields = [
+        "cloud_store.links",
+        "cloud_store.name",
+        "cloud_store.uuid",
+        "used",
+    ]
+    """cloud_store.links,cloud_store.name,cloud_store.uuid,used,"""
 
-    @property
-    def postable_fields(self):
-        return [
-            "cloud_store.name",
-            "cloud_store.uuid",
-        ]
+    patchable_fields = [
+    ]
+    """"""
+
+    postable_fields = [
+    ]
+    """"""
 
 
-class CloudStorageTier(Resource):  # pylint: disable=missing-docstring
+class CloudStorageTier(Resource):
 
     _schema = CloudStorageTierSchema
