@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["ClusterPeerEncryption", "ClusterPeerEncryptionSchema"]
@@ -45,19 +39,23 @@ Valid choices:
     def resource(self):
         return ClusterPeerEncryption
 
-    @property
-    def patchable_fields(self):
-        return [
-            "proposed",
-        ]
+    gettable_fields = [
+        "proposed",
+        "state",
+    ]
+    """proposed,state,"""
 
-    @property
-    def postable_fields(self):
-        return [
-            "proposed",
-        ]
+    patchable_fields = [
+        "proposed",
+    ]
+    """proposed,"""
+
+    postable_fields = [
+        "proposed",
+    ]
+    """proposed,"""
 
 
-class ClusterPeerEncryption(Resource):  # pylint: disable=missing-docstring
+class ClusterPeerEncryption(Resource):
 
     _schema = ClusterPeerEncryptionSchema
