@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["ClusterPeerLinks", "ClusterPeerLinksSchema"]
@@ -35,21 +29,21 @@ class ClusterPeerLinksSchema(ResourceSchema):
     def resource(self):
         return ClusterPeerLinks
 
-    @property
-    def patchable_fields(self):
-        return [
-            "interfaces",
-            "self_",
-        ]
+    gettable_fields = [
+        "interfaces",
+        "self_",
+    ]
+    """interfaces,self_,"""
 
-    @property
-    def postable_fields(self):
-        return [
-            "interfaces",
-            "self_",
-        ]
+    patchable_fields = [
+    ]
+    """"""
+
+    postable_fields = [
+    ]
+    """"""
 
 
-class ClusterPeerLinks(Resource):  # pylint: disable=missing-docstring
+class ClusterPeerLinks(Resource):
 
     _schema = ClusterPeerLinksSchema
