@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["ClusterPeerRemote", "ClusterPeerRemoteSchema"]
@@ -42,19 +36,24 @@ Example: 4048820-60-9 """
     def resource(self):
         return ClusterPeerRemote
 
-    @property
-    def patchable_fields(self):
-        return [
-            "ip_addresses",
-        ]
+    gettable_fields = [
+        "ip_addresses",
+        "name",
+        "serial_number",
+    ]
+    """ip_addresses,name,serial_number,"""
 
-    @property
-    def postable_fields(self):
-        return [
-            "ip_addresses",
-        ]
+    patchable_fields = [
+        "ip_addresses",
+    ]
+    """ip_addresses,"""
+
+    postable_fields = [
+        "ip_addresses",
+    ]
+    """ip_addresses,"""
 
 
-class ClusterPeerRemote(Resource):  # pylint: disable=missing-docstring
+class ClusterPeerRemote(Resource):
 
     _schema = ClusterPeerRemoteSchema
