@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["ClusterPeerSetupResponseAuthentication", "ClusterPeerSetupResponseAuthenticationSchema"]
@@ -25,7 +19,7 @@ __pdoc__ = {
 class ClusterPeerSetupResponseAuthenticationSchema(ResourceSchema):
     """The fields of the ClusterPeerSetupResponseAuthentication object"""
 
-    expiry_time = fields.DateTime(data_key="expiry_time")
+    expiry_time = ImpreciseDateTime(data_key="expiry_time")
     r""" The date and time the passphrase will expire.  The default expiry time is one hour.
 
 Example: 2017-01-25T11:20:13.000+0000 """
@@ -37,21 +31,25 @@ Example: 2017-01-25T11:20:13.000+0000 """
     def resource(self):
         return ClusterPeerSetupResponseAuthentication
 
-    @property
-    def patchable_fields(self):
-        return [
-            "expiry_time",
-            "passphrase",
-        ]
+    gettable_fields = [
+        "expiry_time",
+        "passphrase",
+    ]
+    """expiry_time,passphrase,"""
 
-    @property
-    def postable_fields(self):
-        return [
-            "expiry_time",
-            "passphrase",
-        ]
+    patchable_fields = [
+        "expiry_time",
+        "passphrase",
+    ]
+    """expiry_time,passphrase,"""
+
+    postable_fields = [
+        "expiry_time",
+        "passphrase",
+    ]
+    """expiry_time,passphrase,"""
 
 
-class ClusterPeerSetupResponseAuthentication(Resource):  # pylint: disable=missing-docstring
+class ClusterPeerSetupResponseAuthentication(Resource):
 
     _schema = ClusterPeerSetupResponseAuthenticationSchema
