@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["ClusterPeerStatus", "ClusterPeerStatusSchema"]
@@ -36,7 +30,7 @@ Valid choices:
 * pending
 * unidentified """
 
-    update_time = fields.DateTime(data_key="update_time")
+    update_time = ImpreciseDateTime(data_key="update_time")
     r""" The last time the state was updated.
 
 Example: 2017-01-25T11:20:13.000+0000 """
@@ -45,17 +39,21 @@ Example: 2017-01-25T11:20:13.000+0000 """
     def resource(self):
         return ClusterPeerStatus
 
-    @property
-    def patchable_fields(self):
-        return [
-        ]
+    gettable_fields = [
+        "state",
+        "update_time",
+    ]
+    """state,update_time,"""
 
-    @property
-    def postable_fields(self):
-        return [
-        ]
+    patchable_fields = [
+    ]
+    """"""
+
+    postable_fields = [
+    ]
+    """"""
 
 
-class ClusterPeerStatus(Resource):  # pylint: disable=missing-docstring
+class ClusterPeerStatus(Resource):
 
     _schema = ClusterPeerStatusSchema
