@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["ClusterSpaceCloudStorage", "ClusterSpaceCloudStorageSchema"]
@@ -25,24 +19,27 @@ __pdoc__ = {
 class ClusterSpaceCloudStorageSchema(ResourceSchema):
     """The fields of the ClusterSpaceCloudStorage object"""
 
-    used = fields.Integer(data_key="used")
+    used = Size(data_key="used")
     r""" Total space used in cloud. """
 
     @property
     def resource(self):
         return ClusterSpaceCloudStorage
 
-    @property
-    def patchable_fields(self):
-        return [
-        ]
+    gettable_fields = [
+        "used",
+    ]
+    """used,"""
 
-    @property
-    def postable_fields(self):
-        return [
-        ]
+    patchable_fields = [
+    ]
+    """"""
+
+    postable_fields = [
+    ]
+    """"""
 
 
-class ClusterSpaceCloudStorage(Resource):  # pylint: disable=missing-docstring
+class ClusterSpaceCloudStorage(Resource):
 
     _schema = ClusterSpaceCloudStorageSchema
