@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["DiskDrawer", "DiskDrawerSchema"]
@@ -25,31 +19,35 @@ __pdoc__ = {
 class DiskDrawerSchema(ResourceSchema):
     """The fields of the DiskDrawer object"""
 
-    id = fields.Integer(data_key="id")
+    id = Size(data_key="id")
     r""" The id field of the disk_drawer. """
 
-    slot = fields.Integer(data_key="slot")
+    slot = Size(data_key="slot")
     r""" The slot field of the disk_drawer. """
 
     @property
     def resource(self):
         return DiskDrawer
 
-    @property
-    def patchable_fields(self):
-        return [
-            "id",
-            "slot",
-        ]
+    gettable_fields = [
+        "id",
+        "slot",
+    ]
+    """id,slot,"""
 
-    @property
-    def postable_fields(self):
-        return [
-            "id",
-            "slot",
-        ]
+    patchable_fields = [
+        "id",
+        "slot",
+    ]
+    """id,slot,"""
+
+    postable_fields = [
+        "id",
+        "slot",
+    ]
+    """id,slot,"""
 
 
-class DiskDrawer(Resource):  # pylint: disable=missing-docstring
+class DiskDrawer(Resource):
 
     _schema = DiskDrawerSchema
