@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["DiskKeyId", "DiskKeyIdSchema"]
@@ -35,21 +29,25 @@ class DiskKeyIdSchema(ResourceSchema):
     def resource(self):
         return DiskKeyId
 
-    @property
-    def patchable_fields(self):
-        return [
-            "data",
-            "fips",
-        ]
+    gettable_fields = [
+        "data",
+        "fips",
+    ]
+    """data,fips,"""
 
-    @property
-    def postable_fields(self):
-        return [
-            "data",
-            "fips",
-        ]
+    patchable_fields = [
+        "data",
+        "fips",
+    ]
+    """data,fips,"""
+
+    postable_fields = [
+        "data",
+        "fips",
+    ]
+    """data,fips,"""
 
 
-class DiskKeyId(Resource):  # pylint: disable=missing-docstring
+class DiskKeyId(Resource):
 
     _schema = DiskKeyIdSchema
