@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["EmsDestinationCertificate", "EmsDestinationCertificateSchema"]
@@ -39,21 +33,25 @@ Example: 1234567890 """
     def resource(self):
         return EmsDestinationCertificate
 
-    @property
-    def patchable_fields(self):
-        return [
-            "ca",
-            "serial_number",
-        ]
+    gettable_fields = [
+        "ca",
+        "serial_number",
+    ]
+    """ca,serial_number,"""
 
-    @property
-    def postable_fields(self):
-        return [
-            "ca",
-            "serial_number",
-        ]
+    patchable_fields = [
+        "ca",
+        "serial_number",
+    ]
+    """ca,serial_number,"""
+
+    postable_fields = [
+        "ca",
+        "serial_number",
+    ]
+    """ca,serial_number,"""
 
 
-class EmsDestinationCertificate(Resource):  # pylint: disable=missing-docstring
+class EmsDestinationCertificate(Resource):
 
     _schema = EmsDestinationCertificateSchema
