@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["Error", "ErrorSchema"]
@@ -47,17 +41,23 @@ Example: uuid """
     def resource(self):
         return Error
 
-    @property
-    def patchable_fields(self):
-        return [
-        ]
+    gettable_fields = [
+        "arguments",
+        "code",
+        "message",
+        "target",
+    ]
+    """arguments,code,message,target,"""
 
-    @property
-    def postable_fields(self):
-        return [
-        ]
+    patchable_fields = [
+    ]
+    """"""
+
+    postable_fields = [
+    ]
+    """"""
 
 
-class Error(Resource):  # pylint: disable=missing-docstring
+class Error(Resource):
 
     _schema = ErrorSchema
