@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["ErrorResponses", "ErrorResponsesSchema"]
@@ -32,19 +26,20 @@ class ErrorResponsesSchema(ResourceSchema):
     def resource(self):
         return ErrorResponses
 
-    @property
-    def patchable_fields(self):
-        return [
-            "errors",
-        ]
+    gettable_fields = [
+        "errors",
+    ]
+    """errors,"""
 
-    @property
-    def postable_fields(self):
-        return [
-            "errors",
-        ]
+    patchable_fields = [
+    ]
+    """"""
+
+    postable_fields = [
+    ]
+    """"""
 
 
-class ErrorResponses(Resource):  # pylint: disable=missing-docstring
+class ErrorResponses(Resource):
 
     _schema = ErrorResponsesSchema
