@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["FcInterfaceSvmLocation", "FcInterfaceSvmLocationSchema"]
@@ -32,23 +26,29 @@ class FcInterfaceSvmLocationSchema(ResourceSchema):
     def resource(self):
         return FcInterfaceSvmLocation
 
-    @property
-    def patchable_fields(self):
-        return [
-            "port.name",
-            "port.node",
-            "port.uuid",
-        ]
+    gettable_fields = [
+        "port.links",
+        "port.name",
+        "port.node",
+        "port.uuid",
+    ]
+    """port.links,port.name,port.node,port.uuid,"""
 
-    @property
-    def postable_fields(self):
-        return [
-            "port.name",
-            "port.node",
-            "port.uuid",
-        ]
+    patchable_fields = [
+        "port.name",
+        "port.node",
+        "port.uuid",
+    ]
+    """port.name,port.node,port.uuid,"""
+
+    postable_fields = [
+        "port.name",
+        "port.node",
+        "port.uuid",
+    ]
+    """port.name,port.node,port.uuid,"""
 
 
-class FcInterfaceSvmLocation(Resource):  # pylint: disable=missing-docstring
+class FcInterfaceSvmLocation(Resource):
 
     _schema = FcInterfaceSvmLocationSchema
