@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["IgroupInitiatorIgroup", "IgroupInitiatorIgroupSchema"]
@@ -38,17 +32,21 @@ Example: 4ea7a442-86d1-11e0-ae1c-123478563412 """
     def resource(self):
         return IgroupInitiatorIgroup
 
-    @property
-    def patchable_fields(self):
-        return [
-        ]
+    gettable_fields = [
+        "links",
+        "uuid",
+    ]
+    """links,uuid,"""
 
-    @property
-    def postable_fields(self):
-        return [
-        ]
+    patchable_fields = [
+    ]
+    """"""
+
+    postable_fields = [
+    ]
+    """"""
 
 
-class IgroupInitiatorIgroup(Resource):  # pylint: disable=missing-docstring
+class IgroupInitiatorIgroup(Resource):
 
     _schema = IgroupInitiatorIgroupSchema
