@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["IgroupLun", "IgroupLunSchema"]
@@ -47,21 +41,29 @@ Example: 4ea7a442-86d1-11e0-ae1c-123478563412 """
     def resource(self):
         return IgroupLun
 
-    @property
-    def patchable_fields(self):
-        return [
-            "node.name",
-            "node.uuid",
-        ]
+    gettable_fields = [
+        "links",
+        "name",
+        "node.links",
+        "node.name",
+        "node.uuid",
+        "uuid",
+    ]
+    """links,name,node.links,node.name,node.uuid,uuid,"""
 
-    @property
-    def postable_fields(self):
-        return [
-            "node.name",
-            "node.uuid",
-        ]
+    patchable_fields = [
+        "node.name",
+        "node.uuid",
+    ]
+    """node.name,node.uuid,"""
+
+    postable_fields = [
+        "node.name",
+        "node.uuid",
+    ]
+    """node.name,node.uuid,"""
 
 
-class IgroupLun(Resource):  # pylint: disable=missing-docstring
+class IgroupLun(Resource):
 
     _schema = IgroupLunSchema
