@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["IgroupLunMaps", "IgroupLunMapsSchema"]
@@ -28,7 +22,7 @@ class IgroupLunMapsSchema(ResourceSchema):
     links = fields.Nested("netapp_ontap.models.self_link.SelfLinkSchema", unknown=EXCLUDE, data_key="_links")
     r""" The links field of the igroup_lun_maps. """
 
-    logical_unit_number = fields.Integer(data_key="logical_unit_number")
+    logical_unit_number = Size(data_key="logical_unit_number")
     r""" The logical unit number assigned to the LUN for initiators in the initiator group. """
 
     lun = fields.Nested("netapp_ontap.models.igroup_lun.IgroupLunSchema", unknown=EXCLUDE, data_key="lun")
@@ -38,19 +32,24 @@ class IgroupLunMapsSchema(ResourceSchema):
     def resource(self):
         return IgroupLunMaps
 
-    @property
-    def patchable_fields(self):
-        return [
-            "lun",
-        ]
+    gettable_fields = [
+        "links",
+        "logical_unit_number",
+        "lun",
+    ]
+    """links,logical_unit_number,lun,"""
 
-    @property
-    def postable_fields(self):
-        return [
-            "lun",
-        ]
+    patchable_fields = [
+        "lun",
+    ]
+    """lun,"""
+
+    postable_fields = [
+        "lun",
+    ]
+    """lun,"""
 
 
-class IgroupLunMaps(Resource):  # pylint: disable=missing-docstring
+class IgroupLunMaps(Resource):
 
     _schema = IgroupLunMapsSchema
