@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["IpAddressRange", "IpAddressRangeSchema"]
@@ -38,23 +32,28 @@ class IpAddressRangeSchema(ResourceSchema):
     def resource(self):
         return IpAddressRange
 
-    @property
-    def patchable_fields(self):
-        return [
-            "end",
-            "family",
-            "start",
-        ]
+    gettable_fields = [
+        "end",
+        "family",
+        "start",
+    ]
+    """end,family,start,"""
 
-    @property
-    def postable_fields(self):
-        return [
-            "end",
-            "family",
-            "start",
-        ]
+    patchable_fields = [
+        "end",
+        "family",
+        "start",
+    ]
+    """end,family,start,"""
+
+    postable_fields = [
+        "end",
+        "family",
+        "start",
+    ]
+    """end,family,start,"""
 
 
-class IpAddressRange(Resource):  # pylint: disable=missing-docstring
+class IpAddressRange(Resource):
 
     _schema = IpAddressRangeSchema
