@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["IpInterfaceAndGateway", "IpInterfaceAndGatewaySchema"]
@@ -42,23 +36,28 @@ Example: 10.1.1.1 """
     def resource(self):
         return IpInterfaceAndGateway
 
-    @property
-    def patchable_fields(self):
-        return [
-            "address",
-            "gateway",
-            "netmask",
-        ]
+    gettable_fields = [
+        "address",
+        "gateway",
+        "netmask",
+    ]
+    """address,gateway,netmask,"""
 
-    @property
-    def postable_fields(self):
-        return [
-            "address",
-            "gateway",
-            "netmask",
-        ]
+    patchable_fields = [
+        "address",
+        "gateway",
+        "netmask",
+    ]
+    """address,gateway,netmask,"""
+
+    postable_fields = [
+        "address",
+        "gateway",
+        "netmask",
+    ]
+    """address,gateway,netmask,"""
 
 
-class IpInterfaceAndGateway(Resource):  # pylint: disable=missing-docstring
+class IpInterfaceAndGateway(Resource):
 
     _schema = IpInterfaceAndGatewaySchema
