@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["IpInterfaceSvmIp", "IpInterfaceSvmIpSchema"]
@@ -35,21 +29,25 @@ class IpInterfaceSvmIpSchema(ResourceSchema):
     def resource(self):
         return IpInterfaceSvmIp
 
-    @property
-    def patchable_fields(self):
-        return [
-            "address",
-            "netmask",
-        ]
+    gettable_fields = [
+        "address",
+        "netmask",
+    ]
+    """address,netmask,"""
 
-    @property
-    def postable_fields(self):
-        return [
-            "address",
-            "netmask",
-        ]
+    patchable_fields = [
+        "address",
+        "netmask",
+    ]
+    """address,netmask,"""
+
+    postable_fields = [
+        "address",
+        "netmask",
+    ]
+    """address,netmask,"""
 
 
-class IpInterfaceSvmIp(Resource):  # pylint: disable=missing-docstring
+class IpInterfaceSvmIp(Resource):
 
     _schema = IpInterfaceSvmIpSchema
