@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["IpsecEndpoint", "IpsecEndpointSchema"]
@@ -43,25 +37,31 @@ Example: 23 """
     def resource(self):
         return IpsecEndpoint
 
-    @property
-    def patchable_fields(self):
-        return [
-            "address",
-            "family",
-            "netmask",
-            "port",
-        ]
+    gettable_fields = [
+        "address",
+        "family",
+        "netmask",
+        "port",
+    ]
+    """address,family,netmask,port,"""
 
-    @property
-    def postable_fields(self):
-        return [
-            "address",
-            "family",
-            "netmask",
-            "port",
-        ]
+    patchable_fields = [
+        "address",
+        "family",
+        "netmask",
+        "port",
+    ]
+    """address,family,netmask,port,"""
+
+    postable_fields = [
+        "address",
+        "family",
+        "netmask",
+        "port",
+    ]
+    """address,family,netmask,port,"""
 
 
-class IpsecEndpoint(Resource):  # pylint: disable=missing-docstring
+class IpsecEndpoint(Resource):
 
     _schema = IpsecEndpointSchema
