@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["IscsiConnectionInitiatorAddress", "IscsiConnectionInitiatorAddressSchema"]
@@ -31,7 +25,7 @@ class IscsiConnectionInitiatorAddressSchema(ResourceSchema):
 
 Example: 10.10.10.7 """
 
-    port = fields.Integer(data_key="port")
+    port = Size(data_key="port")
     r""" The TCP port number of the initiator end of the iSCSI connection.
 
 
@@ -41,17 +35,21 @@ Example: 55432 """
     def resource(self):
         return IscsiConnectionInitiatorAddress
 
-    @property
-    def patchable_fields(self):
-        return [
-        ]
+    gettable_fields = [
+        "address",
+        "port",
+    ]
+    """address,port,"""
 
-    @property
-    def postable_fields(self):
-        return [
-        ]
+    patchable_fields = [
+    ]
+    """"""
+
+    postable_fields = [
+    ]
+    """"""
 
 
-class IscsiConnectionInitiatorAddress(Resource):  # pylint: disable=missing-docstring
+class IscsiConnectionInitiatorAddress(Resource):
 
     _schema = IscsiConnectionInitiatorAddressSchema
