@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["IscsiConnectionInterfaceIp", "IscsiConnectionInterfaceIpSchema"]
@@ -28,7 +22,7 @@ class IscsiConnectionInterfaceIpSchema(ResourceSchema):
     address = fields.Str(data_key="address")
     r""" The address field of the iscsi_connection_interface_ip. """
 
-    port = fields.Integer(data_key="port")
+    port = Size(data_key="port")
     r""" The TCP port number of the iSCSI access endpoint.
 
 Example: 3260 """
@@ -37,19 +31,23 @@ Example: 3260 """
     def resource(self):
         return IscsiConnectionInterfaceIp
 
-    @property
-    def patchable_fields(self):
-        return [
-            "address",
-        ]
+    gettable_fields = [
+        "address",
+        "port",
+    ]
+    """address,port,"""
 
-    @property
-    def postable_fields(self):
-        return [
-            "address",
-        ]
+    patchable_fields = [
+        "address",
+    ]
+    """address,"""
+
+    postable_fields = [
+        "address",
+    ]
+    """address,"""
 
 
-class IscsiConnectionInterfaceIp(Resource):  # pylint: disable=missing-docstring
+class IscsiConnectionInterfaceIp(Resource):
 
     _schema = IscsiConnectionInterfaceIpSchema
