@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["IscsiCredentialsChap", "IscsiCredentialsChapSchema"]
@@ -35,21 +29,25 @@ class IscsiCredentialsChapSchema(ResourceSchema):
     def resource(self):
         return IscsiCredentialsChap
 
-    @property
-    def patchable_fields(self):
-        return [
-            "inbound",
-            "outbound",
-        ]
+    gettable_fields = [
+        "inbound",
+        "outbound",
+    ]
+    """inbound,outbound,"""
 
-    @property
-    def postable_fields(self):
-        return [
-            "inbound",
-            "outbound",
-        ]
+    patchable_fields = [
+        "inbound",
+        "outbound",
+    ]
+    """inbound,outbound,"""
+
+    postable_fields = [
+        "inbound",
+        "outbound",
+    ]
+    """inbound,outbound,"""
 
 
-class IscsiCredentialsChap(Resource):  # pylint: disable=missing-docstring
+class IscsiCredentialsChap(Resource):
 
     _schema = IscsiCredentialsChapSchema
