@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["IscsiCredentialsChapOutbound", "IscsiCredentialsChapOutboundSchema"]
@@ -35,21 +29,24 @@ class IscsiCredentialsChapOutboundSchema(ResourceSchema):
     def resource(self):
         return IscsiCredentialsChapOutbound
 
-    @property
-    def patchable_fields(self):
-        return [
-            "password",
-            "user",
-        ]
+    gettable_fields = [
+        "user",
+    ]
+    """user,"""
 
-    @property
-    def postable_fields(self):
-        return [
-            "password",
-            "user",
-        ]
+    patchable_fields = [
+        "password",
+        "user",
+    ]
+    """password,user,"""
+
+    postable_fields = [
+        "password",
+        "user",
+    ]
+    """password,user,"""
 
 
-class IscsiCredentialsChapOutbound(Resource):  # pylint: disable=missing-docstring
+class IscsiCredentialsChapOutbound(Resource):
 
     _schema = IscsiCredentialsChapOutboundSchema
