@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["IscsiCredentialsInitiatorAddress", "IscsiCredentialsInitiatorAddressSchema"]
@@ -35,21 +29,25 @@ class IscsiCredentialsInitiatorAddressSchema(ResourceSchema):
     def resource(self):
         return IscsiCredentialsInitiatorAddress
 
-    @property
-    def patchable_fields(self):
-        return [
-            "masks",
-            "ranges",
-        ]
+    gettable_fields = [
+        "masks",
+        "ranges",
+    ]
+    """masks,ranges,"""
 
-    @property
-    def postable_fields(self):
-        return [
-            "masks",
-            "ranges",
-        ]
+    patchable_fields = [
+        "masks",
+        "ranges",
+    ]
+    """masks,ranges,"""
+
+    postable_fields = [
+        "masks",
+        "ranges",
+    ]
+    """masks,ranges,"""
 
 
-class IscsiCredentialsInitiatorAddress(Resource):  # pylint: disable=missing-docstring
+class IscsiCredentialsInitiatorAddress(Resource):
 
     _schema = IscsiCredentialsInitiatorAddressSchema
