@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["KerberosRealmAdServer", "KerberosRealmAdServerSchema"]
@@ -37,21 +31,25 @@ Example: 1.2.3.4 """
     def resource(self):
         return KerberosRealmAdServer
 
-    @property
-    def patchable_fields(self):
-        return [
-            "address",
-            "name",
-        ]
+    gettable_fields = [
+        "address",
+        "name",
+    ]
+    """address,name,"""
 
-    @property
-    def postable_fields(self):
-        return [
-            "address",
-            "name",
-        ]
+    patchable_fields = [
+        "address",
+        "name",
+    ]
+    """address,name,"""
+
+    postable_fields = [
+        "address",
+        "name",
+    ]
+    """address,name,"""
 
 
-class KerberosRealmAdServer(Resource):  # pylint: disable=missing-docstring
+class KerberosRealmAdServer(Resource):
 
     _schema = KerberosRealmAdServerSchema
