@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["KerberosRealmKdc", "KerberosRealmKdcSchema"]
@@ -30,7 +24,7 @@ class KerberosRealmKdcSchema(ResourceSchema):
 
 Example: 1.2.3.4 """
 
-    port = fields.Integer(data_key="port")
+    port = Size(data_key="port")
     r""" KDC port
 
 Example: 88 """
@@ -51,23 +45,28 @@ Valid choices:
     def resource(self):
         return KerberosRealmKdc
 
-    @property
-    def patchable_fields(self):
-        return [
-            "ip",
-            "port",
-            "vendor",
-        ]
+    gettable_fields = [
+        "ip",
+        "port",
+        "vendor",
+    ]
+    """ip,port,vendor,"""
 
-    @property
-    def postable_fields(self):
-        return [
-            "ip",
-            "port",
-            "vendor",
-        ]
+    patchable_fields = [
+        "ip",
+        "port",
+        "vendor",
+    ]
+    """ip,port,vendor,"""
+
+    postable_fields = [
+        "ip",
+        "port",
+        "vendor",
+    ]
+    """ip,port,vendor,"""
 
 
-class KerberosRealmKdc(Resource):  # pylint: disable=missing-docstring
+class KerberosRealmKdc(Resource):
 
     _schema = KerberosRealmKdcSchema
