@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["LayoutRequirement", "LayoutRequirementSchema"]
@@ -25,7 +19,7 @@ __pdoc__ = {
 class LayoutRequirementSchema(ResourceSchema):
     """The fields of the LayoutRequirement object"""
 
-    aggregate_min_disks = fields.Integer(data_key="aggregate_min_disks")
+    aggregate_min_disks = Size(data_key="aggregate_min_disks")
     r""" Minimum number of disks to create an aggregate
 
 Example: 6 """
@@ -50,19 +44,23 @@ Valid choices:
     def resource(self):
         return LayoutRequirement
 
-    @property
-    def patchable_fields(self):
-        return [
-            "raid_group",
-        ]
+    gettable_fields = [
+        "aggregate_min_disks",
+        "default",
+        "raid_group",
+        "raid_type",
+    ]
+    """aggregate_min_disks,default,raid_group,raid_type,"""
 
-    @property
-    def postable_fields(self):
-        return [
-            "raid_group",
-        ]
+    patchable_fields = [
+    ]
+    """"""
+
+    postable_fields = [
+    ]
+    """"""
 
 
-class LayoutRequirement(Resource):  # pylint: disable=missing-docstring
+class LayoutRequirement(Resource):
 
     _schema = LayoutRequirementSchema
