@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["LayoutRequirementRaidGroup", "LayoutRequirementRaidGroupSchema"]
@@ -25,17 +19,17 @@ __pdoc__ = {
 class LayoutRequirementRaidGroupSchema(ResourceSchema):
     """The fields of the LayoutRequirementRaidGroup object"""
 
-    default = fields.Integer(data_key="default")
+    default = Size(data_key="default")
     r""" Default number of disks in a RAID group
 
 Example: 16 """
 
-    max = fields.Integer(data_key="max")
+    max = Size(data_key="max")
     r""" Maximum number of disks allowed in a RAID group
 
 Example: 28 """
 
-    min = fields.Integer(data_key="min")
+    min = Size(data_key="min")
     r""" Minimum number of disks allowed in a RAID group
 
 Example: 5 """
@@ -44,17 +38,22 @@ Example: 5 """
     def resource(self):
         return LayoutRequirementRaidGroup
 
-    @property
-    def patchable_fields(self):
-        return [
-        ]
+    gettable_fields = [
+        "default",
+        "max",
+        "min",
+    ]
+    """default,max,min,"""
 
-    @property
-    def postable_fields(self):
-        return [
-        ]
+    patchable_fields = [
+    ]
+    """"""
+
+    postable_fields = [
+    ]
+    """"""
 
 
-class LayoutRequirementRaidGroup(Resource):  # pylint: disable=missing-docstring
+class LayoutRequirementRaidGroup(Resource):
 
     _schema = LayoutRequirementRaidGroupSchema
