@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["LicenseCapacity", "LicenseCapacitySchema"]
@@ -25,27 +19,31 @@ __pdoc__ = {
 class LicenseCapacitySchema(ResourceSchema):
     """The fields of the LicenseCapacity object"""
 
-    maximum_size = fields.Integer(data_key="maximum_size")
+    maximum_size = Size(data_key="maximum_size")
     r""" Licensed capacity size (in bytes) that can be used. """
 
-    used_size = fields.Integer(data_key="used_size")
+    used_size = Size(data_key="used_size")
     r""" Capacity that is currently used (in bytes). """
 
     @property
     def resource(self):
         return LicenseCapacity
 
-    @property
-    def patchable_fields(self):
-        return [
-        ]
+    gettable_fields = [
+        "maximum_size",
+        "used_size",
+    ]
+    """maximum_size,used_size,"""
 
-    @property
-    def postable_fields(self):
-        return [
-        ]
+    patchable_fields = [
+    ]
+    """"""
+
+    postable_fields = [
+    ]
+    """"""
 
 
-class LicenseCapacity(Resource):  # pylint: disable=missing-docstring
+class LicenseCapacity(Resource):
 
     _schema = LicenseCapacitySchema
