@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["LogRetention", "LogRetentionSchema"]
@@ -25,7 +19,7 @@ __pdoc__ = {
 class LogRetentionSchema(ResourceSchema):
     """The fields of the LogRetention object"""
 
-    count = fields.Integer(data_key="count")
+    count = Size(data_key="count")
     r""" Determines how many audit log files to retain before
 rotating the oldest log file out. This is mutually exclusive with
 duration. """
@@ -41,21 +35,25 @@ Example: P4DT12H30M5S """
     def resource(self):
         return LogRetention
 
-    @property
-    def patchable_fields(self):
-        return [
-            "count",
-            "duration",
-        ]
+    gettable_fields = [
+        "count",
+        "duration",
+    ]
+    """count,duration,"""
 
-    @property
-    def postable_fields(self):
-        return [
-            "count",
-            "duration",
-        ]
+    patchable_fields = [
+        "count",
+        "duration",
+    ]
+    """count,duration,"""
+
+    postable_fields = [
+        "count",
+        "duration",
+    ]
+    """count,duration,"""
 
 
-class LogRetention(Resource):  # pylint: disable=missing-docstring
+class LogRetention(Resource):
 
     _schema = LogRetentionSchema
