@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["LunCloneSource", "LunCloneSourceSchema"]
@@ -41,21 +35,23 @@ Example: 1cd8a442-86d1-11e0-ae1c-123478563412 """
     def resource(self):
         return LunCloneSource
 
-    @property
-    def patchable_fields(self):
-        return [
-            "name",
-            "uuid",
-        ]
+    gettable_fields = [
+    ]
+    """"""
 
-    @property
-    def postable_fields(self):
-        return [
-            "name",
-            "uuid",
-        ]
+    patchable_fields = [
+        "name",
+        "uuid",
+    ]
+    """name,uuid,"""
+
+    postable_fields = [
+        "name",
+        "uuid",
+    ]
+    """name,uuid,"""
 
 
-class LunCloneSource(Resource):  # pylint: disable=missing-docstring
+class LunCloneSource(Resource):
 
     _schema = LunCloneSourceSchema
