@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["LunLunMaps", "LunLunMapsSchema"]
@@ -31,26 +25,31 @@ class LunLunMapsSchema(ResourceSchema):
     igroup = fields.Nested("netapp_ontap.models.lun_igroup.LunIgroupSchema", unknown=EXCLUDE, data_key="igroup")
     r""" The igroup field of the lun_lun_maps. """
 
-    logical_unit_number = fields.Integer(data_key="logical_unit_number")
+    logical_unit_number = Size(data_key="logical_unit_number")
     r""" The logical unit number assigned to the LUN for initiators in the initiator group. """
 
     @property
     def resource(self):
         return LunLunMaps
 
-    @property
-    def patchable_fields(self):
-        return [
-            "igroup",
-        ]
+    gettable_fields = [
+        "links",
+        "igroup",
+        "logical_unit_number",
+    ]
+    """links,igroup,logical_unit_number,"""
 
-    @property
-    def postable_fields(self):
-        return [
-            "igroup",
-        ]
+    patchable_fields = [
+        "igroup",
+    ]
+    """igroup,"""
+
+    postable_fields = [
+        "igroup",
+    ]
+    """igroup,"""
 
 
-class LunLunMaps(Resource):  # pylint: disable=missing-docstring
+class LunLunMaps(Resource):
 
     _schema = LunLunMapsSchema
