@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["LunMapLunNode", "LunMapLunNodeSchema"]
@@ -44,17 +38,22 @@ Example: 1cf8aa42-8cd1-12e0-a11c-423468563412 """
     def resource(self):
         return LunMapLunNode
 
-    @property
-    def patchable_fields(self):
-        return [
-        ]
+    gettable_fields = [
+        "links",
+        "name",
+        "uuid",
+    ]
+    """links,name,uuid,"""
 
-    @property
-    def postable_fields(self):
-        return [
-        ]
+    patchable_fields = [
+    ]
+    """"""
+
+    postable_fields = [
+    ]
+    """"""
 
 
-class LunMapLunNode(Resource):  # pylint: disable=missing-docstring
+class LunMapLunNode(Resource):
 
     _schema = LunMapLunNodeSchema
