@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["MaxdataOnSanMetadata", "MaxdataOnSanMetadataSchema"]
@@ -35,19 +29,23 @@ class MaxdataOnSanMetadataSchema(ResourceSchema):
     def resource(self):
         return MaxdataOnSanMetadata
 
-    @property
-    def patchable_fields(self):
-        return [
-        ]
+    gettable_fields = [
+        "key",
+        "value",
+    ]
+    """key,value,"""
 
-    @property
-    def postable_fields(self):
-        return [
-            "key",
-            "value",
-        ]
+    patchable_fields = [
+    ]
+    """"""
+
+    postable_fields = [
+        "key",
+        "value",
+    ]
+    """key,value,"""
 
 
-class MaxdataOnSanMetadata(Resource):  # pylint: disable=missing-docstring
+class MaxdataOnSanMetadata(Resource):
 
     _schema = MaxdataOnSanMetadataSchema
