@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["MongoDbOnSanProtectionType", "MongoDbOnSanProtectionTypeSchema"]
@@ -26,7 +20,7 @@ class MongoDbOnSanProtectionTypeSchema(ResourceSchema):
     """The fields of the MongoDbOnSanProtectionType object"""
 
     local_rpo = fields.Str(data_key="local_rpo")
-    r""" The local rpo of the application.
+    r""" The local RPO of the application.
 
 Valid choices:
 
@@ -34,7 +28,7 @@ Valid choices:
 * none """
 
     remote_rpo = fields.Str(data_key="remote_rpo")
-    r""" The remote rpo of the application.
+    r""" The remote RPO of the application.
 
 Valid choices:
 
@@ -45,20 +39,24 @@ Valid choices:
     def resource(self):
         return MongoDbOnSanProtectionType
 
-    @property
-    def patchable_fields(self):
-        return [
-            "local_rpo",
-        ]
+    gettable_fields = [
+        "local_rpo",
+        "remote_rpo",
+    ]
+    """local_rpo,remote_rpo,"""
 
-    @property
-    def postable_fields(self):
-        return [
-            "local_rpo",
-            "remote_rpo",
-        ]
+    patchable_fields = [
+        "local_rpo",
+    ]
+    """local_rpo,"""
+
+    postable_fields = [
+        "local_rpo",
+        "remote_rpo",
+    ]
+    """local_rpo,remote_rpo,"""
 
 
-class MongoDbOnSanProtectionType(Resource):  # pylint: disable=missing-docstring
+class MongoDbOnSanProtectionType(Resource):
 
     _schema = MongoDbOnSanProtectionTypeSchema
