@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["NasFlexcache", "NasFlexcacheSchema"]
@@ -32,18 +26,21 @@ class NasFlexcacheSchema(ResourceSchema):
     def resource(self):
         return NasFlexcache
 
-    @property
-    def patchable_fields(self):
-        return [
-        ]
+    gettable_fields = [
+        "origin",
+    ]
+    """origin,"""
 
-    @property
-    def postable_fields(self):
-        return [
-            "origin",
-        ]
+    patchable_fields = [
+    ]
+    """"""
+
+    postable_fields = [
+        "origin",
+    ]
+    """origin,"""
 
 
-class NasFlexcache(Resource):  # pylint: disable=missing-docstring
+class NasFlexcache(Resource):
 
     _schema = NasFlexcacheSchema
