@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["NasFlexcacheOrigin", "NasFlexcacheOriginSchema"]
@@ -35,19 +29,23 @@ class NasFlexcacheOriginSchema(ResourceSchema):
     def resource(self):
         return NasFlexcacheOrigin
 
-    @property
-    def patchable_fields(self):
-        return [
-        ]
+    gettable_fields = [
+        "component",
+        "svm",
+    ]
+    """component,svm,"""
 
-    @property
-    def postable_fields(self):
-        return [
-            "component",
-            "svm",
-        ]
+    patchable_fields = [
+    ]
+    """"""
+
+    postable_fields = [
+        "component",
+        "svm",
+    ]
+    """component,svm,"""
 
 
-class NasFlexcacheOrigin(Resource):  # pylint: disable=missing-docstring
+class NasFlexcacheOrigin(Resource):
 
     _schema = NasFlexcacheOriginSchema
