@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["NasProtectionType", "NasProtectionTypeSchema"]
@@ -26,10 +20,10 @@ class NasProtectionTypeSchema(ResourceSchema):
     """The fields of the NasProtectionType object"""
 
     local_policy = fields.Str(data_key="local_policy")
-    r""" The snapshot policy to apply to each volume in the smart container. This property is only supported for smart containers. Usage: &lt;snapshot policy&gt; """
+    r""" The Snapshot copy policy to apply to each volume in the smart container. This property is only supported for smart containers. Usage: &lt;snapshot policy&gt; """
 
     local_rpo = fields.Str(data_key="local_rpo")
-    r""" The local rpo of the application.
+    r""" The local RPO of the application.
 
 Valid choices:
 
@@ -37,7 +31,7 @@ Valid choices:
 * none """
 
     remote_rpo = fields.Str(data_key="remote_rpo")
-    r""" The remote rpo of the application.
+    r""" The remote RPO of the application.
 
 Valid choices:
 
@@ -48,21 +42,26 @@ Valid choices:
     def resource(self):
         return NasProtectionType
 
-    @property
-    def patchable_fields(self):
-        return [
-            "local_rpo",
-        ]
+    gettable_fields = [
+        "local_policy",
+        "local_rpo",
+        "remote_rpo",
+    ]
+    """local_policy,local_rpo,remote_rpo,"""
 
-    @property
-    def postable_fields(self):
-        return [
-            "local_policy",
-            "local_rpo",
-            "remote_rpo",
-        ]
+    patchable_fields = [
+        "local_rpo",
+    ]
+    """local_rpo,"""
+
+    postable_fields = [
+        "local_policy",
+        "local_rpo",
+        "remote_rpo",
+    ]
+    """local_policy,local_rpo,remote_rpo,"""
 
 
-class NasProtectionType(Resource):  # pylint: disable=missing-docstring
+class NasProtectionType(Resource):
 
     _schema = NasProtectionTypeSchema
