@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["NdmpConnect", "NdmpConnectSchema"]
@@ -28,7 +22,7 @@ class NdmpConnectSchema(ResourceSchema):
     address = fields.Str(data_key="address")
     r""" Indicates the NDMP data connection address. """
 
-    port = fields.Integer(data_key="port")
+    port = Size(data_key="port")
     r""" Indicates the NDMP data connection port.
 
 Example: 18600 """
@@ -40,23 +34,28 @@ Example: 18600 """
     def resource(self):
         return NdmpConnect
 
-    @property
-    def patchable_fields(self):
-        return [
-            "address",
-            "port",
-            "type",
-        ]
+    gettable_fields = [
+        "address",
+        "port",
+        "type",
+    ]
+    """address,port,type,"""
 
-    @property
-    def postable_fields(self):
-        return [
-            "address",
-            "port",
-            "type",
-        ]
+    patchable_fields = [
+        "address",
+        "port",
+        "type",
+    ]
+    """address,port,type,"""
+
+    postable_fields = [
+        "address",
+        "port",
+        "type",
+    ]
+    """address,port,type,"""
 
 
-class NdmpConnect(Resource):  # pylint: disable=missing-docstring
+class NdmpConnect(Resource):
 
     _schema = NdmpConnectSchema
