@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["NetworkRouteForSvm", "NetworkRouteForSvmSchema"]
@@ -37,21 +31,25 @@ Example: 10.1.1.1 """
     def resource(self):
         return NetworkRouteForSvm
 
-    @property
-    def patchable_fields(self):
-        return [
-            "destination",
-            "gateway",
-        ]
+    gettable_fields = [
+        "destination",
+        "gateway",
+    ]
+    """destination,gateway,"""
 
-    @property
-    def postable_fields(self):
-        return [
-            "destination",
-            "gateway",
-        ]
+    patchable_fields = [
+        "destination",
+        "gateway",
+    ]
+    """destination,gateway,"""
+
+    postable_fields = [
+        "destination",
+        "gateway",
+    ]
+    """destination,gateway,"""
 
 
-class NetworkRouteForSvm(Resource):  # pylint: disable=missing-docstring
+class NetworkRouteForSvm(Resource):
 
     _schema = NetworkRouteForSvmSchema
