@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["NfsServiceTransport", "NfsServiceTransportSchema"]
@@ -35,21 +29,25 @@ class NfsServiceTransportSchema(ResourceSchema):
     def resource(self):
         return NfsServiceTransport
 
-    @property
-    def patchable_fields(self):
-        return [
-            "tcp_enabled",
-            "udp_enabled",
-        ]
+    gettable_fields = [
+        "tcp_enabled",
+        "udp_enabled",
+    ]
+    """tcp_enabled,udp_enabled,"""
 
-    @property
-    def postable_fields(self):
-        return [
-            "tcp_enabled",
-            "udp_enabled",
-        ]
+    patchable_fields = [
+        "tcp_enabled",
+        "udp_enabled",
+    ]
+    """tcp_enabled,udp_enabled,"""
+
+    postable_fields = [
+        "tcp_enabled",
+        "udp_enabled",
+    ]
+    """tcp_enabled,udp_enabled,"""
 
 
-class NfsServiceTransport(Resource):  # pylint: disable=missing-docstring
+class NfsServiceTransport(Resource):
 
     _schema = NfsServiceTransportSchema
