@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["NodeControllerFrus", "NodeControllerFrusSchema"]
@@ -25,7 +19,7 @@ __pdoc__ = {
 class NodeControllerFrusSchema(ResourceSchema):
     """The fields of the NodeControllerFrus object"""
 
-    id = fields.Integer(data_key="id")
+    id = Size(data_key="id")
     r""" The id field of the node_controller_frus. """
 
     state = fields.Str(data_key="state")
@@ -53,17 +47,22 @@ Valid choices:
     def resource(self):
         return NodeControllerFrus
 
-    @property
-    def patchable_fields(self):
-        return [
-        ]
+    gettable_fields = [
+        "id",
+        "state",
+        "type",
+    ]
+    """id,state,type,"""
 
-    @property
-    def postable_fields(self):
-        return [
-        ]
+    patchable_fields = [
+    ]
+    """"""
+
+    postable_fields = [
+    ]
+    """"""
 
 
-class NodeControllerFrus(Resource):  # pylint: disable=missing-docstring
+class NodeControllerFrus(Resource):
 
     _schema = NodeControllerFrusSchema
