@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["NodeHaGivebackFailure", "NodeHaGivebackFailureSchema"]
@@ -25,7 +19,7 @@ __pdoc__ = {
 class NodeHaGivebackFailureSchema(ResourceSchema):
     """The fields of the NodeHaGivebackFailure object"""
 
-    code = fields.Integer(data_key="code")
+    code = Size(data_key="code")
     r""" Message code
 
 Example: 852126 """
@@ -39,21 +33,25 @@ Example: Failed to initiate giveback. Run the "storage failover show-giveback" c
     def resource(self):
         return NodeHaGivebackFailure
 
-    @property
-    def patchable_fields(self):
-        return [
-            "code",
-            "message",
-        ]
+    gettable_fields = [
+        "code",
+        "message",
+    ]
+    """code,message,"""
 
-    @property
-    def postable_fields(self):
-        return [
-            "code",
-            "message",
-        ]
+    patchable_fields = [
+        "code",
+        "message",
+    ]
+    """code,message,"""
+
+    postable_fields = [
+        "code",
+        "message",
+    ]
+    """code,message,"""
 
 
-class NodeHaGivebackFailure(Resource):  # pylint: disable=missing-docstring
+class NodeHaGivebackFailure(Resource):
 
     _schema = NodeHaGivebackFailureSchema
