@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["NodeHaPorts", "NodeHaPortsSchema"]
@@ -25,6 +19,11 @@ __pdoc__ = {
 class NodeHaPortsSchema(ResourceSchema):
     """The fields of the NodeHaPorts object"""
 
+    number = Size(data_key="number")
+    r""" HA port number
+
+Example: 0 """
+
     state = fields.Str(data_key="state")
     r""" HA port state:
 
@@ -47,17 +46,21 @@ Valid choices:
     def resource(self):
         return NodeHaPorts
 
-    @property
-    def patchable_fields(self):
-        return [
-        ]
+    gettable_fields = [
+        "number",
+        "state",
+    ]
+    """number,state,"""
 
-    @property
-    def postable_fields(self):
-        return [
-        ]
+    patchable_fields = [
+    ]
+    """"""
+
+    postable_fields = [
+    ]
+    """"""
 
 
-class NodeHaPorts(Resource):  # pylint: disable=missing-docstring
+class NodeHaPorts(Resource):
 
     _schema = NodeHaPortsSchema
