@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["NodeHaTakeover", "NodeHaTakeoverSchema"]
@@ -43,21 +37,25 @@ Valid choices:
     def resource(self):
         return NodeHaTakeover
 
-    @property
-    def patchable_fields(self):
-        return [
-            "failure",
-            "state",
-        ]
+    gettable_fields = [
+        "failure",
+        "state",
+    ]
+    """failure,state,"""
 
-    @property
-    def postable_fields(self):
-        return [
-            "failure",
-            "state",
-        ]
+    patchable_fields = [
+        "failure",
+        "state",
+    ]
+    """failure,state,"""
+
+    postable_fields = [
+        "failure",
+        "state",
+    ]
+    """failure,state,"""
 
 
-class NodeHaTakeover(Resource):  # pylint: disable=missing-docstring
+class NodeHaTakeover(Resource):
 
     _schema = NodeHaTakeoverSchema
