@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["NodeVm", "NodeVmSchema"]
@@ -38,17 +32,20 @@ Valid choices:
     def resource(self):
         return NodeVm
 
-    @property
-    def patchable_fields(self):
-        return [
-        ]
+    gettable_fields = [
+        "provider_type",
+    ]
+    """provider_type,"""
 
-    @property
-    def postable_fields(self):
-        return [
-        ]
+    patchable_fields = [
+    ]
+    """"""
+
+    postable_fields = [
+    ]
+    """"""
 
 
-class NodeVm(Resource):  # pylint: disable=missing-docstring
+class NodeVm(Resource):
 
     _schema = NodeVmSchema
