@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["NvmeNamespaceClone", "NvmeNamespaceCloneSchema"]
@@ -32,19 +26,21 @@ class NvmeNamespaceCloneSchema(ResourceSchema):
     def resource(self):
         return NvmeNamespaceClone
 
-    @property
-    def patchable_fields(self):
-        return [
-            "source",
-        ]
+    gettable_fields = [
+    ]
+    """"""
 
-    @property
-    def postable_fields(self):
-        return [
-            "source",
-        ]
+    patchable_fields = [
+        "source",
+    ]
+    """source,"""
+
+    postable_fields = [
+        "source",
+    ]
+    """source,"""
 
 
-class NvmeNamespaceClone(Resource):  # pylint: disable=missing-docstring
+class NvmeNamespaceClone(Resource):
 
     _schema = NvmeNamespaceCloneSchema
