@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["NvmeSubsystemControllerAdminQueue", "NvmeSubsystemControllerAdminQueueSchema"]
@@ -25,24 +19,27 @@ __pdoc__ = {
 class NvmeSubsystemControllerAdminQueueSchema(ResourceSchema):
     """The fields of the NvmeSubsystemControllerAdminQueue object"""
 
-    depth = fields.Integer(data_key="depth")
+    depth = Size(data_key="depth")
     r""" The depth of the admin queue for the controller. """
 
     @property
     def resource(self):
         return NvmeSubsystemControllerAdminQueue
 
-    @property
-    def patchable_fields(self):
-        return [
-        ]
+    gettable_fields = [
+        "depth",
+    ]
+    """depth,"""
 
-    @property
-    def postable_fields(self):
-        return [
-        ]
+    patchable_fields = [
+    ]
+    """"""
+
+    postable_fields = [
+    ]
+    """"""
 
 
-class NvmeSubsystemControllerAdminQueue(Resource):  # pylint: disable=missing-docstring
+class NvmeSubsystemControllerAdminQueue(Resource):
 
     _schema = NvmeSubsystemControllerAdminQueueSchema
