@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["NvmeSubsystemControllerHost", "NvmeSubsystemControllerHostSchema"]
@@ -47,17 +41,22 @@ Example: nn-0x20000090fae00806:pn-0x10000090fae00806 """
     def resource(self):
         return NvmeSubsystemControllerHost
 
-    @property
-    def patchable_fields(self):
-        return [
-        ]
+    gettable_fields = [
+        "id",
+        "nqn",
+        "transport_address",
+    ]
+    """id,nqn,transport_address,"""
 
-    @property
-    def postable_fields(self):
-        return [
-        ]
+    patchable_fields = [
+    ]
+    """"""
+
+    postable_fields = [
+    ]
+    """"""
 
 
-class NvmeSubsystemControllerHost(Resource):  # pylint: disable=missing-docstring
+class NvmeSubsystemControllerHost(Resource):
 
     _schema = NvmeSubsystemControllerHostSchema
