@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["NvmeSubsystemControllerInterface", "NvmeSubsystemControllerInterfaceSchema"]
@@ -47,17 +41,22 @@ Example: fa1c5941-2593-11e9-94c4-00a0989a1c8e """
     def resource(self):
         return NvmeSubsystemControllerInterface
 
-    @property
-    def patchable_fields(self):
-        return [
-        ]
+    gettable_fields = [
+        "name",
+        "transport_address",
+        "uuid",
+    ]
+    """name,transport_address,uuid,"""
 
-    @property
-    def postable_fields(self):
-        return [
-        ]
+    patchable_fields = [
+    ]
+    """"""
+
+    postable_fields = [
+    ]
+    """"""
 
 
-class NvmeSubsystemControllerInterface(Resource):  # pylint: disable=missing-docstring
+class NvmeSubsystemControllerInterface(Resource):
 
     _schema = NvmeSubsystemControllerInterfaceSchema
