@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["NvmeSubsystemControllerIoQueue", "NvmeSubsystemControllerIoQueueSchema"]
@@ -25,29 +19,33 @@ __pdoc__ = {
 class NvmeSubsystemControllerIoQueueSchema(ResourceSchema):
     """The fields of the NvmeSubsystemControllerIoQueue object"""
 
-    count = fields.Integer(data_key="count")
+    count = Size(data_key="count")
     r""" The number of I/O queues available to the controller. """
 
-    depth = fields.List(fields.Integer, data_key="depth")
+    depth = fields.List(Size, data_key="depth")
     r""" The depths of the I/O queues. """
 
     @property
     def resource(self):
         return NvmeSubsystemControllerIoQueue
 
-    @property
-    def patchable_fields(self):
-        return [
-            "depth",
-        ]
+    gettable_fields = [
+        "count",
+        "depth",
+    ]
+    """count,depth,"""
 
-    @property
-    def postable_fields(self):
-        return [
-            "depth",
-        ]
+    patchable_fields = [
+        "depth",
+    ]
+    """depth,"""
+
+    postable_fields = [
+        "depth",
+    ]
+    """depth,"""
 
 
-class NvmeSubsystemControllerIoQueue(Resource):  # pylint: disable=missing-docstring
+class NvmeSubsystemControllerIoQueue(Resource):
 
     _schema = NvmeSubsystemControllerIoQueueSchema
