@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["NvmeSubsystemHostIoQueue", "NvmeSubsystemHostIoQueueSchema"]
@@ -25,13 +19,13 @@ __pdoc__ = {
 class NvmeSubsystemHostIoQueueSchema(ResourceSchema):
     """The fields of the NvmeSubsystemHostIoQueue object"""
 
-    count = fields.Integer(data_key="count")
+    count = Size(data_key="count")
     r""" The number of I/O queue pairs. The default value is inherited from the owning NVMe subsystem.
 
 
 Example: 4 """
 
-    depth = fields.Integer(data_key="depth")
+    depth = Size(data_key="depth")
     r""" The I/O queue depth. The default value is inherited from the owning NVMe subsystem.
 
 
@@ -41,17 +35,21 @@ Example: 32 """
     def resource(self):
         return NvmeSubsystemHostIoQueue
 
-    @property
-    def patchable_fields(self):
-        return [
-        ]
+    gettable_fields = [
+        "count",
+        "depth",
+    ]
+    """count,depth,"""
 
-    @property
-    def postable_fields(self):
-        return [
-        ]
+    patchable_fields = [
+    ]
+    """"""
+
+    postable_fields = [
+    ]
+    """"""
 
 
-class NvmeSubsystemHostIoQueue(Resource):  # pylint: disable=missing-docstring
+class NvmeSubsystemHostIoQueue(Resource):
 
     _schema = NvmeSubsystemHostIoQueueSchema
