@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["NvmeSubsystemHosts", "NvmeSubsystemHostsSchema"]
@@ -35,18 +29,21 @@ Example: nqn.1992-01.example.com:string """
     def resource(self):
         return NvmeSubsystemHosts
 
-    @property
-    def patchable_fields(self):
-        return [
-        ]
+    gettable_fields = [
+        "nqn",
+    ]
+    """nqn,"""
 
-    @property
-    def postable_fields(self):
-        return [
-            "nqn",
-        ]
+    patchable_fields = [
+    ]
+    """"""
+
+    postable_fields = [
+        "nqn",
+    ]
+    """nqn,"""
 
 
-class NvmeSubsystemHosts(Resource):  # pylint: disable=missing-docstring
+class NvmeSubsystemHosts(Resource):
 
     _schema = NvmeSubsystemHostsSchema
