@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["NvmeSubsystemIoQueue", "NvmeSubsystemIoQueueSchema"]
@@ -32,19 +26,22 @@ class NvmeSubsystemIoQueueSchema(ResourceSchema):
     def resource(self):
         return NvmeSubsystemIoQueue
 
-    @property
-    def patchable_fields(self):
-        return [
-            "default",
-        ]
+    gettable_fields = [
+        "default",
+    ]
+    """default,"""
 
-    @property
-    def postable_fields(self):
-        return [
-            "default",
-        ]
+    patchable_fields = [
+        "default",
+    ]
+    """default,"""
+
+    postable_fields = [
+        "default",
+    ]
+    """default,"""
 
 
-class NvmeSubsystemIoQueue(Resource):  # pylint: disable=missing-docstring
+class NvmeSubsystemIoQueue(Resource):
 
     _schema = NvmeSubsystemIoQueueSchema
