@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["OracleOnNfsArchiveLogStorageService", "OracleOnNfsArchiveLogStorageServiceSchema"]
@@ -38,19 +32,22 @@ Valid choices:
     def resource(self):
         return OracleOnNfsArchiveLogStorageService
 
-    @property
-    def patchable_fields(self):
-        return [
-            "name",
-        ]
+    gettable_fields = [
+        "name",
+    ]
+    """name,"""
 
-    @property
-    def postable_fields(self):
-        return [
-            "name",
-        ]
+    patchable_fields = [
+        "name",
+    ]
+    """name,"""
+
+    postable_fields = [
+        "name",
+    ]
+    """name,"""
 
 
-class OracleOnNfsArchiveLogStorageService(Resource):  # pylint: disable=missing-docstring
+class OracleOnNfsArchiveLogStorageService(Resource):
 
     _schema = OracleOnNfsArchiveLogStorageServiceSchema
