@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["OracleOnNfsDb", "OracleOnNfsDbSchema"]
@@ -25,7 +19,7 @@ __pdoc__ = {
 class OracleOnNfsDbSchema(ResourceSchema):
     """The fields of the OracleOnNfsDb object"""
 
-    size = fields.Integer(data_key="size")
+    size = Size(data_key="size")
     r""" The size of the database. Usage: {&lt;integer&gt;[KB|MB|GB|TB|PB]} """
 
     storage_service = fields.Nested("netapp_ontap.models.mongo_db_on_san_dataset_storage_service.MongoDbOnSanDatasetStorageServiceSchema", unknown=EXCLUDE, data_key="storage_service")
@@ -35,21 +29,25 @@ class OracleOnNfsDbSchema(ResourceSchema):
     def resource(self):
         return OracleOnNfsDb
 
-    @property
-    def patchable_fields(self):
-        return [
-            "size",
-            "storage_service",
-        ]
+    gettable_fields = [
+        "size",
+        "storage_service",
+    ]
+    """size,storage_service,"""
 
-    @property
-    def postable_fields(self):
-        return [
-            "size",
-            "storage_service",
-        ]
+    patchable_fields = [
+        "size",
+        "storage_service",
+    ]
+    """size,storage_service,"""
+
+    postable_fields = [
+        "size",
+        "storage_service",
+    ]
+    """size,storage_service,"""
 
 
-class OracleOnNfsDb(Resource):  # pylint: disable=missing-docstring
+class OracleOnNfsDb(Resource):
 
     _schema = OracleOnNfsDbSchema
