@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["OracleOnNfsRedoLog", "OracleOnNfsRedoLogSchema"]
@@ -28,7 +22,7 @@ class OracleOnNfsRedoLogSchema(ResourceSchema):
     mirrored = fields.Boolean(data_key="mirrored")
     r""" Specifies whether the redo log group should be mirrored. """
 
-    size = fields.Integer(data_key="size")
+    size = Size(data_key="size")
     r""" The size of the redo log group. Usage: {&lt;integer&gt;[KB|MB|GB|TB|PB]} """
 
     storage_service = fields.Nested("netapp_ontap.models.oracle_on_nfs_redo_log_storage_service.OracleOnNfsRedoLogStorageServiceSchema", unknown=EXCLUDE, data_key="storage_service")
@@ -38,22 +32,27 @@ class OracleOnNfsRedoLogSchema(ResourceSchema):
     def resource(self):
         return OracleOnNfsRedoLog
 
-    @property
-    def patchable_fields(self):
-        return [
-            "size",
-            "storage_service",
-        ]
+    gettable_fields = [
+        "mirrored",
+        "size",
+        "storage_service",
+    ]
+    """mirrored,size,storage_service,"""
 
-    @property
-    def postable_fields(self):
-        return [
-            "mirrored",
-            "size",
-            "storage_service",
-        ]
+    patchable_fields = [
+        "size",
+        "storage_service",
+    ]
+    """size,storage_service,"""
+
+    postable_fields = [
+        "mirrored",
+        "size",
+        "storage_service",
+    ]
+    """mirrored,size,storage_service,"""
 
 
-class OracleOnNfsRedoLog(Resource):  # pylint: disable=missing-docstring
+class OracleOnNfsRedoLog(Resource):
 
     _schema = OracleOnNfsRedoLogSchema
