@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["Peer", "PeerSchema"]
@@ -35,25 +29,33 @@ class PeerSchema(ResourceSchema):
     def resource(self):
         return Peer
 
-    @property
-    def patchable_fields(self):
-        return [
-            "cluster.name",
-            "cluster.uuid",
-            "svm.name",
-            "svm.uuid",
-        ]
+    gettable_fields = [
+        "cluster.links",
+        "cluster.name",
+        "cluster.uuid",
+        "svm.links",
+        "svm.name",
+        "svm.uuid",
+    ]
+    """cluster.links,cluster.name,cluster.uuid,svm.links,svm.name,svm.uuid,"""
 
-    @property
-    def postable_fields(self):
-        return [
-            "cluster.name",
-            "cluster.uuid",
-            "svm.name",
-            "svm.uuid",
-        ]
+    patchable_fields = [
+        "cluster.name",
+        "cluster.uuid",
+        "svm.name",
+        "svm.uuid",
+    ]
+    """cluster.name,cluster.uuid,svm.name,svm.uuid,"""
+
+    postable_fields = [
+        "cluster.name",
+        "cluster.uuid",
+        "svm.name",
+        "svm.uuid",
+    ]
+    """cluster.name,cluster.uuid,svm.name,svm.uuid,"""
 
 
-class Peer(Resource):  # pylint: disable=missing-docstring
+class Peer(Resource):
 
     _schema = PeerSchema
