@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["PerformanceMetricIoTypeRwt", "PerformanceMetricIoTypeRwtSchema"]
@@ -25,17 +19,17 @@ __pdoc__ = {
 class PerformanceMetricIoTypeRwtSchema(ResourceSchema):
     """The fields of the PerformanceMetricIoTypeRwt object"""
 
-    read = fields.Integer(data_key="read")
+    read = Size(data_key="read")
     r""" Performance metric for read I/O operations.
 
 Example: 200 """
 
-    total = fields.Integer(data_key="total")
+    total = Size(data_key="total")
     r""" Performance metric aggregated over all types of I/O operations.
 
 Example: 1000 """
 
-    write = fields.Integer(data_key="write")
+    write = Size(data_key="write")
     r""" Peformance metric for write I/O operations.
 
 Example: 100 """
@@ -44,23 +38,28 @@ Example: 100 """
     def resource(self):
         return PerformanceMetricIoTypeRwt
 
-    @property
-    def patchable_fields(self):
-        return [
-            "read",
-            "total",
-            "write",
-        ]
+    gettable_fields = [
+        "read",
+        "total",
+        "write",
+    ]
+    """read,total,write,"""
 
-    @property
-    def postable_fields(self):
-        return [
-            "read",
-            "total",
-            "write",
-        ]
+    patchable_fields = [
+        "read",
+        "total",
+        "write",
+    ]
+    """read,total,write,"""
+
+    postable_fields = [
+        "read",
+        "total",
+        "write",
+    ]
+    """read,total,write,"""
 
 
-class PerformanceMetricIoTypeRwt(Resource):  # pylint: disable=missing-docstring
+class PerformanceMetricIoTypeRwt(Resource):
 
     _schema = PerformanceMetricIoTypeRwtSchema
