@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["PlexResync", "PlexResyncSchema"]
@@ -36,7 +30,7 @@ Valid choices:
 * full
 * incremental """
 
-    percent = fields.Integer(data_key="percent")
+    percent = Size(data_key="percent")
     r""" Plex resyncing percentage
 
 Example: 10 """
@@ -45,17 +39,22 @@ Example: 10 """
     def resource(self):
         return PlexResync
 
-    @property
-    def patchable_fields(self):
-        return [
-        ]
+    gettable_fields = [
+        "active",
+        "level",
+        "percent",
+    ]
+    """active,level,percent,"""
 
-    @property
-    def postable_fields(self):
-        return [
-        ]
+    patchable_fields = [
+    ]
+    """"""
+
+    postable_fields = [
+    ]
+    """"""
 
 
-class PlexResync(Resource):  # pylint: disable=missing-docstring
+class PlexResync(Resource):
 
     _schema = PlexResyncSchema
