@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["QuotaReportFiles", "QuotaReportFilesSchema"]
@@ -25,10 +19,10 @@ __pdoc__ = {
 class QuotaReportFilesSchema(ResourceSchema):
     """The fields of the QuotaReportFiles object"""
 
-    hard_limit = fields.Integer(data_key="hard_limit")
+    hard_limit = Size(data_key="hard_limit")
     r""" File hard limit """
 
-    soft_limit = fields.Integer(data_key="soft_limit")
+    soft_limit = Size(data_key="soft_limit")
     r""" File soft limit """
 
     used = fields.Nested("netapp_ontap.models.quota_report_files_used.QuotaReportFilesUsedSchema", unknown=EXCLUDE, data_key="used")
@@ -38,19 +32,24 @@ class QuotaReportFilesSchema(ResourceSchema):
     def resource(self):
         return QuotaReportFiles
 
-    @property
-    def patchable_fields(self):
-        return [
-            "used",
-        ]
+    gettable_fields = [
+        "hard_limit",
+        "soft_limit",
+        "used",
+    ]
+    """hard_limit,soft_limit,used,"""
 
-    @property
-    def postable_fields(self):
-        return [
-            "used",
-        ]
+    patchable_fields = [
+        "used",
+    ]
+    """used,"""
+
+    postable_fields = [
+        "used",
+    ]
+    """used,"""
 
 
-class QuotaReportFiles(Resource):  # pylint: disable=missing-docstring
+class QuotaReportFiles(Resource):
 
     _schema = QuotaReportFilesSchema
