@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["QuotaReportSpaceUsed", "QuotaReportSpaceUsedSchema"]
@@ -25,30 +19,35 @@ __pdoc__ = {
 class QuotaReportSpaceUsedSchema(ResourceSchema):
     """The fields of the QuotaReportSpaceUsed object"""
 
-    hard_limit_percent = fields.Integer(data_key="hard_limit_percent")
+    hard_limit_percent = Size(data_key="hard_limit_percent")
     r""" Total space used as a percentage of space hard limit """
 
-    soft_limit_percent = fields.Integer(data_key="soft_limit_percent")
+    soft_limit_percent = Size(data_key="soft_limit_percent")
     r""" Total space used as a percentage of space soft limit """
 
-    total = fields.Integer(data_key="total")
+    total = Size(data_key="total")
     r""" Total space used """
 
     @property
     def resource(self):
         return QuotaReportSpaceUsed
 
-    @property
-    def patchable_fields(self):
-        return [
-        ]
+    gettable_fields = [
+        "hard_limit_percent",
+        "soft_limit_percent",
+        "total",
+    ]
+    """hard_limit_percent,soft_limit_percent,total,"""
 
-    @property
-    def postable_fields(self):
-        return [
-        ]
+    patchable_fields = [
+    ]
+    """"""
+
+    postable_fields = [
+    ]
+    """"""
 
 
-class QuotaReportSpaceUsed(Resource):  # pylint: disable=missing-docstring
+class QuotaReportSpaceUsed(Resource):
 
     _schema = QuotaReportSpaceUsedSchema
