@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["QuotaRuleQtree", "QuotaRuleQtreeSchema"]
@@ -28,7 +22,7 @@ class QuotaRuleQtreeSchema(ResourceSchema):
     links = fields.Nested("netapp_ontap.models.self_link.SelfLinkSchema", unknown=EXCLUDE, data_key="_links")
     r""" The links field of the quota_rule_qtree. """
 
-    id = fields.Integer(data_key="id")
+    id = Size(data_key="id")
     r""" The unique identifier for a qtree.
 
 Example: 1 """
@@ -42,21 +36,24 @@ Example: qt1 """
     def resource(self):
         return QuotaRuleQtree
 
-    @property
-    def patchable_fields(self):
-        return [
-            "id",
-            "name",
-        ]
+    gettable_fields = [
+        "links",
+        "id",
+        "name",
+    ]
+    """links,id,name,"""
 
-    @property
-    def postable_fields(self):
-        return [
-            "id",
-            "name",
-        ]
+    patchable_fields = [
+        "name",
+    ]
+    """name,"""
+
+    postable_fields = [
+        "name",
+    ]
+    """name,"""
 
 
-class QuotaRuleQtree(Resource):  # pylint: disable=missing-docstring
+class QuotaRuleQtree(Resource):
 
     _schema = QuotaRuleQtreeSchema
