@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["RaidGroupReconstruct", "RaidGroupReconstructSchema"]
@@ -28,7 +22,7 @@ class RaidGroupReconstructSchema(ResourceSchema):
     active = fields.Boolean(data_key="active")
     r""" One or more disks in this RAID group are being reconstructed. """
 
-    percent = fields.Integer(data_key="percent")
+    percent = Size(data_key="percent")
     r""" Reconstruct percentage
 
 Example: 10 """
@@ -37,17 +31,21 @@ Example: 10 """
     def resource(self):
         return RaidGroupReconstruct
 
-    @property
-    def patchable_fields(self):
-        return [
-        ]
+    gettable_fields = [
+        "active",
+        "percent",
+    ]
+    """active,percent,"""
 
-    @property
-    def postable_fields(self):
-        return [
-        ]
+    patchable_fields = [
+    ]
+    """"""
+
+    postable_fields = [
+    ]
+    """"""
 
 
-class RaidGroupReconstruct(Resource):  # pylint: disable=missing-docstring
+class RaidGroupReconstruct(Resource):
 
     _schema = RaidGroupReconstructSchema
