@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["Rotation", "RotationSchema"]
@@ -31,29 +25,33 @@ class RotationSchema(ResourceSchema):
     schedule = fields.Nested("netapp_ontap.models.audit_schedule.AuditScheduleSchema", unknown=EXCLUDE, data_key="schedule")
     r""" The schedule field of the rotation. """
 
-    size = fields.Integer(data_key="size")
+    size = Size(data_key="size")
     r""" Rotates logs based on log size in bytes. """
 
     @property
     def resource(self):
         return Rotation
 
-    @property
-    def patchable_fields(self):
-        return [
-            "now",
-            "schedule",
-            "size",
-        ]
+    gettable_fields = [
+        "schedule",
+        "size",
+    ]
+    """schedule,size,"""
 
-    @property
-    def postable_fields(self):
-        return [
-            "schedule",
-            "size",
-        ]
+    patchable_fields = [
+        "now",
+        "schedule",
+        "size",
+    ]
+    """now,schedule,size,"""
+
+    postable_fields = [
+        "schedule",
+        "size",
+    ]
+    """schedule,size,"""
 
 
-class Rotation(Resource):  # pylint: disable=missing-docstring
+class Rotation(Resource):
 
     _schema = RotationSchema
