@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["S3BucketEncryption", "S3BucketEncryptionSchema"]
@@ -32,19 +26,22 @@ class S3BucketEncryptionSchema(ResourceSchema):
     def resource(self):
         return S3BucketEncryption
 
-    @property
-    def patchable_fields(self):
-        return [
-            "enabled",
-        ]
+    gettable_fields = [
+        "enabled",
+    ]
+    """enabled,"""
 
-    @property
-    def postable_fields(self):
-        return [
-            "enabled",
-        ]
+    patchable_fields = [
+        "enabled",
+    ]
+    """enabled,"""
+
+    postable_fields = [
+        "enabled",
+    ]
+    """enabled,"""
 
 
-class S3BucketEncryption(Resource):  # pylint: disable=missing-docstring
+class S3BucketEncryption(Resource):
 
     _schema = S3BucketEncryptionSchema
