@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["S3ServiceDeleteResponseRecords", "S3ServiceDeleteResponseRecordsSchema"]
@@ -32,19 +26,22 @@ class S3ServiceDeleteResponseRecordsSchema(ResourceSchema):
     def resource(self):
         return S3ServiceDeleteResponseRecords
 
-    @property
-    def patchable_fields(self):
-        return [
-            "job",
-        ]
+    gettable_fields = [
+        "job",
+    ]
+    """job,"""
 
-    @property
-    def postable_fields(self):
-        return [
-            "job",
-        ]
+    patchable_fields = [
+        "job",
+    ]
+    """job,"""
+
+    postable_fields = [
+        "job",
+    ]
+    """job,"""
 
 
-class S3ServiceDeleteResponseRecords(Resource):  # pylint: disable=missing-docstring
+class S3ServiceDeleteResponseRecords(Resource):
 
     _schema = S3ServiceDeleteResponseRecordsSchema
