@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["S3ServicePost", "S3ServicePostSchema"]
@@ -25,7 +19,7 @@ __pdoc__ = {
 class S3ServicePostSchema(ResourceSchema):
     """The fields of the S3ServicePost object"""
 
-    num_records = fields.Integer(data_key="num_records")
+    num_records = Size(data_key="num_records")
     r""" Number of Records """
 
     records = fields.List(fields.Nested("netapp_ontap.models.s3_service_post_response_records.S3ServicePostResponseRecordsSchema", unknown=EXCLUDE), data_key="records")
@@ -35,21 +29,25 @@ class S3ServicePostSchema(ResourceSchema):
     def resource(self):
         return S3ServicePost
 
-    @property
-    def patchable_fields(self):
-        return [
-            "num_records",
-            "records",
-        ]
+    gettable_fields = [
+        "num_records",
+        "records",
+    ]
+    """num_records,records,"""
 
-    @property
-    def postable_fields(self):
-        return [
-            "num_records",
-            "records",
-        ]
+    patchable_fields = [
+        "num_records",
+        "records",
+    ]
+    """num_records,records,"""
+
+    postable_fields = [
+        "num_records",
+        "records",
+    ]
+    """num_records,records,"""
 
 
-class S3ServicePost(Resource):  # pylint: disable=missing-docstring
+class S3ServicePost(Resource):
 
     _schema = S3ServicePostSchema
