@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["ShelfBays", "ShelfBaysSchema"]
@@ -28,7 +22,7 @@ class ShelfBaysSchema(ResourceSchema):
     has_disk = fields.Boolean(data_key="has_disk")
     r""" The has_disk field of the shelf_bays. """
 
-    id = fields.Integer(data_key="id")
+    id = Size(data_key="id")
     r""" The id field of the shelf_bays.
 
 Example: 0 """
@@ -55,25 +49,31 @@ Valid choices:
     def resource(self):
         return ShelfBays
 
-    @property
-    def patchable_fields(self):
-        return [
-            "has_disk",
-            "id",
-            "state",
-            "type",
-        ]
+    gettable_fields = [
+        "has_disk",
+        "id",
+        "state",
+        "type",
+    ]
+    """has_disk,id,state,type,"""
 
-    @property
-    def postable_fields(self):
-        return [
-            "has_disk",
-            "id",
-            "state",
-            "type",
-        ]
+    patchable_fields = [
+        "has_disk",
+        "id",
+        "state",
+        "type",
+    ]
+    """has_disk,id,state,type,"""
+
+    postable_fields = [
+        "has_disk",
+        "id",
+        "state",
+        "type",
+    ]
+    """has_disk,id,state,type,"""
 
 
-class ShelfBays(Resource):  # pylint: disable=missing-docstring
+class ShelfBays(Resource):
 
     _schema = ShelfBaysSchema
