@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["SnapmirrorError", "SnapmirrorErrorSchema"]
@@ -25,7 +19,7 @@ __pdoc__ = {
 class SnapmirrorErrorSchema(ResourceSchema):
     """The fields of the SnapmirrorError object"""
 
-    code = fields.Integer(data_key="code")
+    code = Size(data_key="code")
     r""" Error code """
 
     message = fields.Str(data_key="message")
@@ -38,23 +32,28 @@ class SnapmirrorErrorSchema(ResourceSchema):
     def resource(self):
         return SnapmirrorError
 
-    @property
-    def patchable_fields(self):
-        return [
-            "code",
-            "message",
-            "parameters",
-        ]
+    gettable_fields = [
+        "code",
+        "message",
+        "parameters",
+    ]
+    """code,message,parameters,"""
 
-    @property
-    def postable_fields(self):
-        return [
-            "code",
-            "message",
-            "parameters",
-        ]
+    patchable_fields = [
+        "code",
+        "message",
+        "parameters",
+    ]
+    """code,message,parameters,"""
+
+    postable_fields = [
+        "code",
+        "message",
+        "parameters",
+    ]
+    """code,message,parameters,"""
 
 
-class SnapmirrorError(Resource):  # pylint: disable=missing-docstring
+class SnapmirrorError(Resource):
 
     _schema = SnapmirrorErrorSchema
