@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["SnapmirrorTransferFiles", "SnapmirrorTransferFilesSchema"]
@@ -39,21 +33,25 @@ Example: /dira/file1 """
     def resource(self):
         return SnapmirrorTransferFiles
 
-    @property
-    def patchable_fields(self):
-        return [
-            "destination_path",
-            "source_path",
-        ]
+    gettable_fields = [
+        "destination_path",
+        "source_path",
+    ]
+    """destination_path,source_path,"""
 
-    @property
-    def postable_fields(self):
-        return [
-            "destination_path",
-            "source_path",
-        ]
+    patchable_fields = [
+        "destination_path",
+        "source_path",
+    ]
+    """destination_path,source_path,"""
+
+    postable_fields = [
+        "destination_path",
+        "source_path",
+    ]
+    """destination_path,source_path,"""
 
 
-class SnapmirrorTransferFiles(Resource):  # pylint: disable=missing-docstring
+class SnapmirrorTransferFiles(Resource):
 
     _schema = SnapmirrorTransferFilesSchema
