@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["SoftwareErrors", "SoftwareErrorsSchema"]
@@ -25,7 +19,7 @@ __pdoc__ = {
 class SoftwareErrorsSchema(ResourceSchema):
     """The fields of the SoftwareErrors object"""
 
-    code = fields.Integer(data_key="code")
+    code = Size(data_key="code")
     r""" Error code of message
 
 Example: 177 """
@@ -48,17 +42,22 @@ Valid choices:
     def resource(self):
         return SoftwareErrors
 
-    @property
-    def patchable_fields(self):
-        return [
-        ]
+    gettable_fields = [
+        "code",
+        "message",
+        "severity",
+    ]
+    """code,message,severity,"""
 
-    @property
-    def postable_fields(self):
-        return [
-        ]
+    patchable_fields = [
+    ]
+    """"""
+
+    postable_fields = [
+    ]
+    """"""
 
 
-class SoftwareErrors(Resource):  # pylint: disable=missing-docstring
+class SoftwareErrors(Resource):
 
     _schema = SoftwareErrorsSchema
