@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["SoftwareMcc", "SoftwareMccSchema"]
@@ -25,12 +19,12 @@ __pdoc__ = {
 class SoftwareMccSchema(ResourceSchema):
     """The fields of the SoftwareMcc object"""
 
-    elapsed_duration = fields.Integer(data_key="elapsed_duration")
+    elapsed_duration = Size(data_key="elapsed_duration")
     r""" Elapsed duration of update time (in seconds) of MetroCluster.
 
 Example: 2140 """
 
-    estimated_duration = fields.Integer(data_key="estimated_duration")
+    estimated_duration = Size(data_key="estimated_duration")
     r""" Estimated duration of update time (in seconds) of MetroCluster.
 
 Example: 3480 """
@@ -59,17 +53,23 @@ Valid choices:
     def resource(self):
         return SoftwareMcc
 
-    @property
-    def patchable_fields(self):
-        return [
-        ]
+    gettable_fields = [
+        "elapsed_duration",
+        "estimated_duration",
+        "name",
+        "state",
+    ]
+    """elapsed_duration,estimated_duration,name,state,"""
 
-    @property
-    def postable_fields(self):
-        return [
-        ]
+    patchable_fields = [
+    ]
+    """"""
+
+    postable_fields = [
+    ]
+    """"""
 
 
-class SoftwareMcc(Resource):  # pylint: disable=missing-docstring
+class SoftwareMcc(Resource):
 
     _schema = SoftwareMccSchema
