@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["SoftwareNode", "SoftwareNodeSchema"]
@@ -25,6 +19,9 @@ __pdoc__ = {
 class SoftwareNodeSchema(ResourceSchema):
     """The fields of the SoftwareNode object"""
 
+    firmware = fields.Nested("netapp_ontap.models.firmware.FirmwareSchema", unknown=EXCLUDE, data_key="firmware")
+    r""" The firmware field of the software_node. """
+
     name = fields.Str(data_key="name")
     r""" Name of the node.
 
@@ -39,17 +36,22 @@ Example: ONTAP_X """
     def resource(self):
         return SoftwareNode
 
-    @property
-    def patchable_fields(self):
-        return [
-        ]
+    gettable_fields = [
+        "firmware",
+        "name",
+        "version",
+    ]
+    """firmware,name,version,"""
 
-    @property
-    def postable_fields(self):
-        return [
-        ]
+    patchable_fields = [
+    ]
+    """"""
+
+    postable_fields = [
+    ]
+    """"""
 
 
-class SoftwareNode(Resource):  # pylint: disable=missing-docstring
+class SoftwareNode(Resource):
 
     _schema = SoftwareNodeSchema
