@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["SoftwarePackageDownloadGet", "SoftwarePackageDownloadGetSchema"]
@@ -25,7 +19,7 @@ __pdoc__ = {
 class SoftwarePackageDownloadGetSchema(ResourceSchema):
     """The fields of the SoftwarePackageDownloadGet object"""
 
-    code = fields.Integer(data_key="code")
+    code = Size(data_key="code")
     r""" Code corresponds to download message
 
 Example: 10551496 """
@@ -49,23 +43,22 @@ Valid choices:
     def resource(self):
         return SoftwarePackageDownloadGet
 
-    @property
-    def patchable_fields(self):
-        return [
-            "code",
-            "message",
-            "state",
-        ]
+    gettable_fields = [
+        "code",
+        "message",
+        "state",
+    ]
+    """code,message,state,"""
 
-    @property
-    def postable_fields(self):
-        return [
-            "code",
-            "message",
-            "state",
-        ]
+    patchable_fields = [
+    ]
+    """"""
+
+    postable_fields = [
+    ]
+    """"""
 
 
-class SoftwarePackageDownloadGet(Resource):  # pylint: disable=missing-docstring
+class SoftwarePackageDownloadGet(Resource):
 
     _schema = SoftwarePackageDownloadGetSchema
