@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["SoftwareReferenceMetroclusterProgressDetails", "SoftwareReferenceMetroclusterProgressDetailsSchema"]
@@ -34,19 +28,22 @@ Example: Switchover in progress """
     def resource(self):
         return SoftwareReferenceMetroclusterProgressDetails
 
-    @property
-    def patchable_fields(self):
-        return [
-            "message",
-        ]
+    gettable_fields = [
+        "message",
+    ]
+    """message,"""
 
-    @property
-    def postable_fields(self):
-        return [
-            "message",
-        ]
+    patchable_fields = [
+        "message",
+    ]
+    """message,"""
+
+    postable_fields = [
+        "message",
+    ]
+    """message,"""
 
 
-class SoftwareReferenceMetroclusterProgressDetails(Resource):  # pylint: disable=missing-docstring
+class SoftwareReferenceMetroclusterProgressDetails(Resource):
 
     _schema = SoftwareReferenceMetroclusterProgressDetailsSchema
