@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["SoftwareStatusDetailsReferenceAction", "SoftwareStatusDetailsReferenceActionSchema"]
@@ -25,26 +19,35 @@ __pdoc__ = {
 class SoftwareStatusDetailsReferenceActionSchema(ResourceSchema):
     """The fields of the SoftwareStatusDetailsReferenceAction object"""
 
+    code = Size(data_key="code")
+    r""" Error code corresponding the status error """
+
     message = fields.Str(data_key="message")
-    r""" The message field of the software_status_details_reference_action. """
+    r""" Corrective action to be taken to resolve the status error. """
 
     @property
     def resource(self):
         return SoftwareStatusDetailsReferenceAction
 
-    @property
-    def patchable_fields(self):
-        return [
-            "message",
-        ]
+    gettable_fields = [
+        "code",
+        "message",
+    ]
+    """code,message,"""
 
-    @property
-    def postable_fields(self):
-        return [
-            "message",
-        ]
+    patchable_fields = [
+        "code",
+        "message",
+    ]
+    """code,message,"""
+
+    postable_fields = [
+        "code",
+        "message",
+    ]
+    """code,message,"""
 
 
-class SoftwareStatusDetailsReferenceAction(Resource):  # pylint: disable=missing-docstring
+class SoftwareStatusDetailsReferenceAction(Resource):
 
     _schema = SoftwareStatusDetailsReferenceActionSchema
