@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["SoftwareStatusDetailsReferenceIssue", "SoftwareStatusDetailsReferenceIssueSchema"]
@@ -25,8 +19,13 @@ __pdoc__ = {
 class SoftwareStatusDetailsReferenceIssueSchema(ResourceSchema):
     """The fields of the SoftwareStatusDetailsReferenceIssue object"""
 
+    code = Size(data_key="code")
+    r""" Error code corresponding to update status
+
+Example: 10551399 """
+
     message = fields.Str(data_key="message")
-    r""" The message field of the software_status_details_reference_issue.
+    r""" Update status details
 
 Example: Image update complete """
 
@@ -34,19 +33,25 @@ Example: Image update complete """
     def resource(self):
         return SoftwareStatusDetailsReferenceIssue
 
-    @property
-    def patchable_fields(self):
-        return [
-            "message",
-        ]
+    gettable_fields = [
+        "code",
+        "message",
+    ]
+    """code,message,"""
 
-    @property
-    def postable_fields(self):
-        return [
-            "message",
-        ]
+    patchable_fields = [
+        "code",
+        "message",
+    ]
+    """code,message,"""
+
+    postable_fields = [
+        "code",
+        "message",
+    ]
+    """code,message,"""
 
 
-class SoftwareStatusDetailsReferenceIssue(Resource):  # pylint: disable=missing-docstring
+class SoftwareStatusDetailsReferenceIssue(Resource):
 
     _schema = SoftwareStatusDetailsReferenceIssueSchema
