@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["SoftwareValidationReferenceAction", "SoftwareValidationReferenceActionSchema"]
@@ -26,25 +20,30 @@ class SoftwareValidationReferenceActionSchema(ResourceSchema):
     """The fields of the SoftwareValidationReferenceAction object"""
 
     message = fields.Str(data_key="message")
-    r""" Specifies the corrective action to be taken to resolve a validation error """
+    r""" Specifies the corrective action to take to resolve an error.
+
+Example: Use NFS hard mounts, if possible. """
 
     @property
     def resource(self):
         return SoftwareValidationReferenceAction
 
-    @property
-    def patchable_fields(self):
-        return [
-            "message",
-        ]
+    gettable_fields = [
+        "message",
+    ]
+    """message,"""
 
-    @property
-    def postable_fields(self):
-        return [
-            "message",
-        ]
+    patchable_fields = [
+        "message",
+    ]
+    """message,"""
+
+    postable_fields = [
+        "message",
+    ]
+    """message,"""
 
 
-class SoftwareValidationReferenceAction(Resource):  # pylint: disable=missing-docstring
+class SoftwareValidationReferenceAction(Resource):
 
     _schema = SoftwareValidationReferenceActionSchema
