@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["SoftwareValidationReferenceIssue", "SoftwareValidationReferenceIssueSchema"]
@@ -26,27 +20,30 @@ class SoftwareValidationReferenceIssueSchema(ResourceSchema):
     """The fields of the SoftwareValidationReferenceIssue object"""
 
     message = fields.Str(data_key="message")
-    r""" Details of the error or warning encountered by the update checks
+    r""" Details of the error or warning encountered by the update checks.
 
-Example: Validation error: Cluster HA is not configured in the cluster """
+Example: Cluster HA is not configured in the cluster. """
 
     @property
     def resource(self):
         return SoftwareValidationReferenceIssue
 
-    @property
-    def patchable_fields(self):
-        return [
-            "message",
-        ]
+    gettable_fields = [
+        "message",
+    ]
+    """message,"""
 
-    @property
-    def postable_fields(self):
-        return [
-            "message",
-        ]
+    patchable_fields = [
+        "message",
+    ]
+    """message,"""
+
+    postable_fields = [
+        "message",
+    ]
+    """message,"""
 
 
-class SoftwareValidationReferenceIssue(Resource):  # pylint: disable=missing-docstring
+class SoftwareValidationReferenceIssue(Resource):
 
     _schema = SoftwareValidationReferenceIssueSchema
