@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["SpaceEfficiency", "SpaceEfficiencySchema"]
@@ -25,30 +19,35 @@ __pdoc__ = {
 class SpaceEfficiencySchema(ResourceSchema):
     """The fields of the SpaceEfficiency object"""
 
-    logical_used = fields.Integer(data_key="logical_used")
+    logical_used = Size(data_key="logical_used")
     r""" Logical used """
 
     ratio = fields.Number(data_key="ratio")
     r""" Data reduction ratio (logical_used / used) """
 
-    savings = fields.Integer(data_key="savings")
+    savings = Size(data_key="savings")
     r""" Space saved by storage efficiencies (logical_used - used) """
 
     @property
     def resource(self):
         return SpaceEfficiency
 
-    @property
-    def patchable_fields(self):
-        return [
-        ]
+    gettable_fields = [
+        "logical_used",
+        "ratio",
+        "savings",
+    ]
+    """logical_used,ratio,savings,"""
 
-    @property
-    def postable_fields(self):
-        return [
-        ]
+    patchable_fields = [
+    ]
+    """"""
+
+    postable_fields = [
+    ]
+    """"""
 
 
-class SpaceEfficiency(Resource):  # pylint: disable=missing-docstring
+class SpaceEfficiency(Resource):
 
     _schema = SpaceEfficiencySchema
