@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["SqlOnSmbAccess", "SqlOnSmbAccessSchema"]
@@ -35,19 +29,23 @@ class SqlOnSmbAccessSchema(ResourceSchema):
     def resource(self):
         return SqlOnSmbAccess
 
-    @property
-    def patchable_fields(self):
-        return [
-        ]
+    gettable_fields = [
+        "installer",
+        "service_account",
+    ]
+    """installer,service_account,"""
 
-    @property
-    def postable_fields(self):
-        return [
-            "installer",
-            "service_account",
-        ]
+    patchable_fields = [
+    ]
+    """"""
+
+    postable_fields = [
+        "installer",
+        "service_account",
+    ]
+    """installer,service_account,"""
 
 
-class SqlOnSmbAccess(Resource):  # pylint: disable=missing-docstring
+class SqlOnSmbAccess(Resource):
 
     _schema = SqlOnSmbAccessSchema
