@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["StoragePortError", "StoragePortErrorSchema"]
@@ -35,21 +29,25 @@ class StoragePortErrorSchema(ResourceSchema):
     def resource(self):
         return StoragePortError
 
-    @property
-    def patchable_fields(self):
-        return [
-            "corrective_action",
-            "message",
-        ]
+    gettable_fields = [
+        "corrective_action",
+        "message",
+    ]
+    """corrective_action,message,"""
 
-    @property
-    def postable_fields(self):
-        return [
-            "corrective_action",
-            "message",
-        ]
+    patchable_fields = [
+        "corrective_action",
+        "message",
+    ]
+    """corrective_action,message,"""
+
+    postable_fields = [
+        "corrective_action",
+        "message",
+    ]
+    """corrective_action,message,"""
 
 
-class StoragePortError(Resource):  # pylint: disable=missing-docstring
+class StoragePortError(Resource):
 
     _schema = StoragePortErrorSchema
