@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["SvmDns", "SvmDnsSchema"]
@@ -38,21 +32,26 @@ class SvmDnsSchema(ResourceSchema):
     def resource(self):
         return SvmDns
 
-    @property
-    def patchable_fields(self):
-        return [
-            "domains",
-            "servers",
-        ]
+    gettable_fields = [
+        "links",
+        "domains",
+        "servers",
+    ]
+    """links,domains,servers,"""
 
-    @property
-    def postable_fields(self):
-        return [
-            "domains",
-            "servers",
-        ]
+    patchable_fields = [
+        "domains",
+        "servers",
+    ]
+    """domains,servers,"""
+
+    postable_fields = [
+        "domains",
+        "servers",
+    ]
+    """domains,servers,"""
 
 
-class SvmDns(Resource):  # pylint: disable=missing-docstring
+class SvmDns(Resource):
 
     _schema = SvmDnsSchema
