@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["SvmNis", "SvmNisSchema"]
@@ -41,23 +35,29 @@ class SvmNisSchema(ResourceSchema):
     def resource(self):
         return SvmNis
 
-    @property
-    def patchable_fields(self):
-        return [
-            "domain",
-            "enabled",
-            "servers",
-        ]
+    gettable_fields = [
+        "links",
+        "domain",
+        "enabled",
+        "servers",
+    ]
+    """links,domain,enabled,servers,"""
 
-    @property
-    def postable_fields(self):
-        return [
-            "domain",
-            "enabled",
-            "servers",
-        ]
+    patchable_fields = [
+        "domain",
+        "enabled",
+        "servers",
+    ]
+    """domain,enabled,servers,"""
+
+    postable_fields = [
+        "domain",
+        "enabled",
+        "servers",
+    ]
+    """domain,enabled,servers,"""
 
 
-class SvmNis(Resource):  # pylint: disable=missing-docstring
+class SvmNis(Resource):
 
     _schema = SvmNisSchema
