@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["SvmNsswitch", "SvmNsswitchSchema"]
@@ -44,27 +38,34 @@ class SvmNsswitchSchema(ResourceSchema):
     def resource(self):
         return SvmNsswitch
 
-    @property
-    def patchable_fields(self):
-        return [
-            "group",
-            "hosts",
-            "namemap",
-            "netgroup",
-            "passwd",
-        ]
+    gettable_fields = [
+        "group",
+        "hosts",
+        "namemap",
+        "netgroup",
+        "passwd",
+    ]
+    """group,hosts,namemap,netgroup,passwd,"""
 
-    @property
-    def postable_fields(self):
-        return [
-            "group",
-            "hosts",
-            "namemap",
-            "netgroup",
-            "passwd",
-        ]
+    patchable_fields = [
+        "group",
+        "hosts",
+        "namemap",
+        "netgroup",
+        "passwd",
+    ]
+    """group,hosts,namemap,netgroup,passwd,"""
+
+    postable_fields = [
+        "group",
+        "hosts",
+        "namemap",
+        "netgroup",
+        "passwd",
+    ]
+    """group,hosts,namemap,netgroup,passwd,"""
 
 
-class SvmNsswitch(Resource):  # pylint: disable=missing-docstring
+class SvmNsswitch(Resource):
 
     _schema = SvmNsswitchSchema
