@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["SvmSnapmirror", "SvmSnapmirrorSchema"]
@@ -28,24 +22,28 @@ class SvmSnapmirrorSchema(ResourceSchema):
     is_protected = fields.Boolean(data_key="is_protected")
     r""" Specifies whether the SVM is a SnapMirror source SVM, using SnapMirror to protect its data. """
 
-    protected_volumes_count = fields.Integer(data_key="protected_volumes_count")
+    protected_volumes_count = Size(data_key="protected_volumes_count")
     r""" Specifies the number of SVM DR protected volumes in the SVM. """
 
     @property
     def resource(self):
         return SvmSnapmirror
 
-    @property
-    def patchable_fields(self):
-        return [
-        ]
+    gettable_fields = [
+        "is_protected",
+        "protected_volumes_count",
+    ]
+    """is_protected,protected_volumes_count,"""
 
-    @property
-    def postable_fields(self):
-        return [
-        ]
+    patchable_fields = [
+    ]
+    """"""
+
+    postable_fields = [
+    ]
+    """"""
 
 
-class SvmSnapmirror(Resource):  # pylint: disable=missing-docstring
+class SvmSnapmirror(Resource):
 
     _schema = SvmSnapmirrorSchema
