@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["VdiOnSanNewIgroups", "VdiOnSanNewIgroupsSchema"]
@@ -44,23 +38,26 @@ Valid choices:
     def resource(self):
         return VdiOnSanNewIgroups
 
-    @property
-    def patchable_fields(self):
-        return [
-            "initiators",
-            "name",
-            "protocol",
-        ]
+    gettable_fields = [
+        "initiators",
+    ]
+    """initiators,"""
 
-    @property
-    def postable_fields(self):
-        return [
-            "initiators",
-            "name",
-            "protocol",
-        ]
+    patchable_fields = [
+        "initiators",
+        "name",
+        "protocol",
+    ]
+    """initiators,name,protocol,"""
+
+    postable_fields = [
+        "initiators",
+        "name",
+        "protocol",
+    ]
+    """initiators,name,protocol,"""
 
 
-class VdiOnSanNewIgroups(Resource):  # pylint: disable=missing-docstring
+class VdiOnSanNewIgroups(Resource):
 
     _schema = VdiOnSanNewIgroupsSchema
