@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["Version", "VersionSchema"]
@@ -30,17 +24,17 @@ class VersionSchema(ResourceSchema):
 
 Example: NetApp Release 9.4.0: Sun Nov 05 18:20:57 UTC 2017 """
 
-    generation = fields.Integer(data_key="generation")
+    generation = Size(data_key="generation")
     r""" The generation portion of the version.
 
 Example: 9 """
 
-    major = fields.Integer(data_key="major")
+    major = Size(data_key="major")
     r""" The major portion of the version.
 
 Example: 4 """
 
-    minor = fields.Integer(data_key="minor")
+    minor = Size(data_key="minor")
     r""" The minor portion of the version.
 
 Example: 0 """
@@ -49,17 +43,23 @@ Example: 0 """
     def resource(self):
         return Version
 
-    @property
-    def patchable_fields(self):
-        return [
-        ]
+    gettable_fields = [
+        "full",
+        "generation",
+        "major",
+        "minor",
+    ]
+    """full,generation,major,minor,"""
 
-    @property
-    def postable_fields(self):
-        return [
-        ]
+    patchable_fields = [
+    ]
+    """"""
+
+    postable_fields = [
+    ]
+    """"""
 
 
-class Version(Resource):  # pylint: disable=missing-docstring
+class Version(Resource):
 
     _schema = VersionSchema
