@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["VolumeEncryptionSupport", "VolumeEncryptionSupportSchema"]
@@ -25,7 +19,7 @@ __pdoc__ = {
 class VolumeEncryptionSupportSchema(ResourceSchema):
     """The fields of the VolumeEncryptionSupport object"""
 
-    code = fields.Integer(data_key="code")
+    code = Size(data_key="code")
     r""" Code corresponding to the status message. Returns a 0 if volume encryption is supported in all nodes of the cluster.
 
 Example: 346758 """
@@ -42,23 +36,22 @@ Example: No platform support for volume encryption in following nodes - node1, n
     def resource(self):
         return VolumeEncryptionSupport
 
-    @property
-    def patchable_fields(self):
-        return [
-            "code",
-            "message",
-            "supported",
-        ]
+    gettable_fields = [
+        "code",
+        "message",
+        "supported",
+    ]
+    """code,message,supported,"""
 
-    @property
-    def postable_fields(self):
-        return [
-            "code",
-            "message",
-            "supported",
-        ]
+    patchable_fields = [
+    ]
+    """"""
+
+    postable_fields = [
+    ]
+    """"""
 
 
-class VolumeEncryptionSupport(Resource):  # pylint: disable=missing-docstring
+class VolumeEncryptionSupport(Resource):
 
     _schema = VolumeEncryptionSupportSchema
