@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["VolumeErrorState", "VolumeErrorStateSchema"]
@@ -35,17 +29,21 @@ class VolumeErrorStateSchema(ResourceSchema):
     def resource(self):
         return VolumeErrorState
 
-    @property
-    def patchable_fields(self):
-        return [
-        ]
+    gettable_fields = [
+        "has_bad_blocks",
+        "is_inconsistent",
+    ]
+    """has_bad_blocks,is_inconsistent,"""
 
-    @property
-    def postable_fields(self):
-        return [
-        ]
+    patchable_fields = [
+    ]
+    """"""
+
+    postable_fields = [
+    ]
+    """"""
 
 
-class VolumeErrorState(Resource):  # pylint: disable=missing-docstring
+class VolumeErrorState(Resource):
 
     _schema = VolumeErrorStateSchema
