@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["VolumeGuarantee", "VolumeGuaranteeSchema"]
@@ -40,19 +34,23 @@ Valid choices:
     def resource(self):
         return VolumeGuarantee
 
-    @property
-    def patchable_fields(self):
-        return [
-            "type",
-        ]
+    gettable_fields = [
+        "honored",
+        "type",
+    ]
+    """honored,type,"""
 
-    @property
-    def postable_fields(self):
-        return [
-            "type",
-        ]
+    patchable_fields = [
+        "type",
+    ]
+    """type,"""
+
+    postable_fields = [
+        "type",
+    ]
+    """type,"""
 
 
-class VolumeGuarantee(Resource):  # pylint: disable=missing-docstring
+class VolumeGuarantee(Resource):
 
     _schema = VolumeGuaranteeSchema
