@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["VolumeQuota", "VolumeQuotaSchema"]
@@ -44,18 +38,21 @@ Valid choices:
     def resource(self):
         return VolumeQuota
 
-    @property
-    def patchable_fields(self):
-        return [
-            "enabled",
-        ]
+    gettable_fields = [
+        "state",
+    ]
+    """state,"""
 
-    @property
-    def postable_fields(self):
-        return [
-        ]
+    patchable_fields = [
+        "enabled",
+    ]
+    """enabled,"""
+
+    postable_fields = [
+    ]
+    """"""
 
 
-class VolumeQuota(Resource):  # pylint: disable=missing-docstring
+class VolumeQuota(Resource):
 
     _schema = VolumeQuotaSchema
