@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["VolumeSpaceSnapshot", "VolumeSpaceSnapshotSchema"]
@@ -28,30 +22,34 @@ class VolumeSpaceSnapshotSchema(ResourceSchema):
     autodelete_enabled = fields.Boolean(data_key="autodelete_enabled")
     r""" Specifies whether Snapshot copy autodelete is currently enabled on this volume. """
 
-    reserve_percent = fields.Integer(data_key="reserve_percent")
+    reserve_percent = Size(data_key="reserve_percent")
     r""" The space that has been set aside as a reserve for Snapshot copy usage, in percent. """
 
-    used = fields.Integer(data_key="used")
+    used = Size(data_key="used")
     r""" The total space used by Snapshot copies in the volume, in bytes. """
 
     @property
     def resource(self):
         return VolumeSpaceSnapshot
 
-    @property
-    def patchable_fields(self):
-        return [
-            "autodelete_enabled",
-            "reserve_percent",
-        ]
+    gettable_fields = [
+        "reserve_percent",
+        "used",
+    ]
+    """reserve_percent,used,"""
 
-    @property
-    def postable_fields(self):
-        return [
-            "reserve_percent",
-        ]
+    patchable_fields = [
+        "autodelete_enabled",
+        "reserve_percent",
+    ]
+    """autodelete_enabled,reserve_percent,"""
+
+    postable_fields = [
+        "reserve_percent",
+    ]
+    """reserve_percent,"""
 
 
-class VolumeSpaceSnapshot(Resource):  # pylint: disable=missing-docstring
+class VolumeSpaceSnapshot(Resource):
 
     _schema = VolumeSpaceSnapshotSchema
