@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["VsiOnNasDatastore", "VsiOnNasDatastoreSchema"]
@@ -25,10 +19,10 @@ __pdoc__ = {
 class VsiOnNasDatastoreSchema(ResourceSchema):
     """The fields of the VsiOnNasDatastore object"""
 
-    count = fields.Integer(data_key="count")
+    count = Size(data_key="count")
     r""" The number of datastores to support. """
 
-    size = fields.Integer(data_key="size")
+    size = Size(data_key="size")
     r""" The size of the datastore. Usage: {&lt;integer&gt;[KB|MB|GB|TB|PB]} """
 
     storage_service = fields.Nested("netapp_ontap.models.vsi_on_nas_datastore_storage_service.VsiOnNasDatastoreStorageServiceSchema", unknown=EXCLUDE, data_key="storage_service")
@@ -38,22 +32,27 @@ class VsiOnNasDatastoreSchema(ResourceSchema):
     def resource(self):
         return VsiOnNasDatastore
 
-    @property
-    def patchable_fields(self):
-        return [
-            "count",
-            "storage_service",
-        ]
+    gettable_fields = [
+        "count",
+        "size",
+        "storage_service",
+    ]
+    """count,size,storage_service,"""
 
-    @property
-    def postable_fields(self):
-        return [
-            "count",
-            "size",
-            "storage_service",
-        ]
+    patchable_fields = [
+        "count",
+        "storage_service",
+    ]
+    """count,storage_service,"""
+
+    postable_fields = [
+        "count",
+        "size",
+        "storage_service",
+    ]
+    """count,size,storage_service,"""
 
 
-class VsiOnNasDatastore(Resource):  # pylint: disable=missing-docstring
+class VsiOnNasDatastore(Resource):
 
     _schema = VsiOnNasDatastoreSchema
