@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["ZappNvme", "ZappNvmeSchema"]
@@ -44,22 +38,27 @@ Valid choices:
     def resource(self):
         return ZappNvme
 
-    @property
-    def patchable_fields(self):
-        return [
-            "components",
-            "rpo",
-        ]
+    gettable_fields = [
+        "components",
+        "os_type",
+        "rpo",
+    ]
+    """components,os_type,rpo,"""
 
-    @property
-    def postable_fields(self):
-        return [
-            "components",
-            "os_type",
-            "rpo",
-        ]
+    patchable_fields = [
+        "components",
+        "rpo",
+    ]
+    """components,rpo,"""
+
+    postable_fields = [
+        "components",
+        "os_type",
+        "rpo",
+    ]
+    """components,os_type,rpo,"""
 
 
-class ZappNvme(Resource):  # pylint: disable=missing-docstring
+class ZappNvme(Resource):
 
     _schema = ZappNvmeSchema
