@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["ZappNvmeComponentsSubsystemHosts", "ZappNvmeComponentsSubsystemHostsSchema"]
@@ -32,18 +26,22 @@ class ZappNvmeComponentsSubsystemHostsSchema(ResourceSchema):
     def resource(self):
         return ZappNvmeComponentsSubsystemHosts
 
-    @property
-    def patchable_fields(self):
-        return [
-        ]
+    gettable_fields = [
+        "nqn",
+    ]
+    """nqn,"""
 
-    @property
-    def postable_fields(self):
-        return [
-            "nqn",
-        ]
+    patchable_fields = [
+        "nqn",
+    ]
+    """nqn,"""
+
+    postable_fields = [
+        "nqn",
+    ]
+    """nqn,"""
 
 
-class ZappNvmeComponentsSubsystemHosts(Resource):  # pylint: disable=missing-docstring
+class ZappNvmeComponentsSubsystemHosts(Resource):
 
     _schema = ZappNvmeComponentsSubsystemHostsSchema
