@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -12,7 +6,7 @@ All rights reserved.
 """
 
 from marshmallow import EXCLUDE, fields  # type: ignore
-from netapp_ontap.resource import Resource, ResourceSchema
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 
 
 __all__ = ["ZappNvmePerformance", "ZappNvmePerformanceSchema"]
@@ -32,19 +26,22 @@ class ZappNvmePerformanceSchema(ResourceSchema):
     def resource(self):
         return ZappNvmePerformance
 
-    @property
-    def patchable_fields(self):
-        return [
-            "storage_service",
-        ]
+    gettable_fields = [
+        "storage_service",
+    ]
+    """storage_service,"""
 
-    @property
-    def postable_fields(self):
-        return [
-            "storage_service",
-        ]
+    patchable_fields = [
+        "storage_service",
+    ]
+    """storage_service,"""
+
+    postable_fields = [
+        "storage_service",
+    ]
+    """storage_service,"""
 
 
-class ZappNvmePerformance(Resource):  # pylint: disable=missing-docstring
+class ZappNvmePerformance(Resource):
 
     _schema = ZappNvmePerformanceSchema
