@@ -1,6 +1,6 @@
 # pylint: disable=line-too-long
 """
-Copyright &copy; 2019 NetApp Inc.
+Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
 
 This module defines the base Resource class. This class is implemented by each
@@ -11,7 +11,6 @@ perform actions against the host (GET, POST, PATCH, DELETE) via its REST interfa
 # pylint: disable=too-many-lines
 
 import collections.abc
-import datetime
 import json
 import logging
 import operator
@@ -23,15 +22,20 @@ from typing import (  # pylint: disable=unused-import
     Optional,
     Type,
     Union,
-    cast,
+    Tuple,
 )
 import urllib.parse
-
-import marshmallow  # type: ignore
+import datetime
 from marshmallow import (  # type: ignore
+    INCLUDE,
+    RAISE,
+    Schema,
+    fields,
     missing,
+    post_load,
 )
 import requests
+from requests_toolbelt.multipart import decoder # type: ignore
 
 from netapp_ontap import config, utils
 from netapp_ontap.error import NetAppRestError
@@ -48,7 +52,7 @@ LOGGER = logging.getLogger(__name__)
 LOGGER.addHandler(logging.NullHandler())
 
 
-class ResourceSchema(marshmallow.Schema):
+class ResourceSchema(Schema):
     """An abstract class which is the base of all resource schemas.
 
     A resource schema defines the fields of a resource with which the client can
@@ -56,6 +60,15 @@ class ResourceSchema(marshmallow.Schema):
     is responsible for validating and transforming the data.
     """
 
+    patchable_fields = []  # type: List[str]
+    """Only fields in this list will be considered when patching a resource"""
+
+    postable_fields = []  # type: List[str]
+    """Only fields in this list will be considered when posting a resource"""
+
+    gettable_fields = []  # type: List[str]
+    """The fields in this list may be queried and retrieved from the host"""
+
     @property
     def resource(self) -> "Type[Resource]":
         """The resource class associated with this schema.
@@ -69,7 +82,7 @@ class ResourceSchema(marshmallow.Schema):
             An instance of a `type` object which descends from `netapp_ontap.resource.Resource`
         """
 
-    @marshmallow.post_load
+    @post_load
     def make_resource(self, data: dict, **_kwargs) -> "Resource":
         """Automatically called by the library after we load data from a dict.
 
@@ -87,17 +100,71 @@ class ResourceSchema(marshmallow.Schema):
 
         return self.resource(**data)
 
-    @property
-    def patchable_fields(self):
-        """Only fields in this list will be considered when patching a resource"""
 
-        return []
+class ImpreciseDateTime(fields.DateTime):
+    """A customer DateTime field that serializes its value minus any microseconds
+    that might exist on it. Microseconds are not accepted in a date-time formatted
+    field in ONTAP.
+    """
 
-    @property
-    def postable_fields(self):
-        """Only fields in this list will be considered when posting a resource"""
+    def _serialize(self, value, attr, obj, **kwargs):
+        try:
+            lossy_value = value.replace(microsecond=0)
+            return super()._serialize(lossy_value, attr, obj, **kwargs)
+        except Exception as erro:
+            raise self.make_error(
+                "invalid", input=value, obj_type=self.OBJ_TYPE,
+            ) from erro
+
+
+class Size(fields.Field):
+    """A custom class that can interpret strings as integers assuming they are
+    using a known suffix like G, M, K, etc"""
+
+    SUFFIX_VALUES = {
+        "K": 1024,
+        "KB": 1024,
+        "M": 1024 ** 2,
+        "MB": 1024 ** 2,
+        "G": 1024 ** 3,
+        "GB": 1024 ** 3,
+        "T": 1024 ** 4,
+        "TB": 1024 ** 4,
+        "P": 1024 ** 5,
+        "PB": 1024 ** 5,
+    }
+
+    default_error_messages = {
+        "invalid": (
+            "\"{input}\" could not be interpreted as a valid size. Valid values"
+            r"  are of the form \d+[KB|MB|GB|TB|PB]"
+        )
+    }
+
+    def _serialize(self, value, attr, obj, **kwargs):
+        return self._to_int(value)
+
+    def _deserialize(self, value, attr, data, **kwargs):
+        return self._to_int(value)
+
+    def _to_int(self, value):
+        value = str(value).upper()
+        size = 1
+        for suffix, suffix_size in self.SUFFIX_VALUES.items():
+            if value.endswith(suffix):
+                value = value[:-len(suffix)]
+                size = suffix_size
+                break
+        else:
+            if value.endswith("B"):
+                value = value[:-1]
+
+        # now it must be parsable to an integer, or else it fails validation
+        try:
+            return int(value) * size
+        except (ValueError, TypeError):
+            raise self.make_error("invalid", input=value)
 
-        return []
 
 class ResourceJSONEncoder(json.JSONEncoder):
     """A custom JSON encoder for the Resource class"""
@@ -106,9 +173,21 @@ class ResourceJSONEncoder(json.JSONEncoder):
         if isinstance(obj, Resource):
             return obj.to_dict()
         if isinstance(obj, datetime.datetime):
-            return obj.isoformat()
+            return obj.replace(microsecond=0).isoformat()
         return json.JSONEncoder.default(self, obj)
 
+class LazyFile: # pylint: disable=too-few-public-methods
+    """ Class that handles open file handles """
+
+    def __init__(self, filename, mode):
+        """ Initialize variables """
+        self.filename = filename
+        self.mode = mode
+
+    def read(self):
+        """ Reads opened file, returns the object, and then closes the file """
+        with open(self.filename, self.mode) as file_name:
+            return file_name.read()
 
 class Resource:  # pylint: disable=too-many-instance-attributes
     """An abstract class which is the base of all resources.
@@ -122,6 +201,9 @@ class Resource:  # pylint: disable=too-many-instance-attributes
     _schema_instance = None  # type: ResourceSchema
     _schema_fields = None  # type: List[str]
     _path = ""
+    _keys = []  # type: List[str]
+    _post_form_data_parameters = {} # type: dict
+    _patch_form_data_parameters = {} # type: dict
 
     def __init__(self, *args, **kwargs) -> None:
         """Initialize the instance of the resource.
@@ -145,6 +227,7 @@ class Resource:  # pylint: disable=too-many-instance-attributes
         self._connection = HostConnection.get_host_context()
         self._last_response = None  # type: Optional[NetAppResponse]
         self.parent_keys = args
+        self.response_files = [] # type: List[dict]
         if getattr(self.__class__, "_schema_instance", None) is None:
             self.__class__._schema_instance = self._schema()  # pylint: disable=protected-access
             self.__class__._schema_fields = list(  # pylint: disable=protected-access
@@ -215,23 +298,6 @@ class Resource:  # pylint: disable=too-many-instance-attributes
         self._prevent_recurse = False
         return value
 
-    @property
-    def _keys(self) -> List[str]:
-        """A list of keys that uniquely identify the object on the host.
-
-        This list is what you would see if you built the path/location of the
-        object. For example, if the path to the object was
-        /api/storage/volumes/55be2443/snapshots/005056bb3fd7, then the keys
-        would be ['volume.uuid', 'uuid']
-
-        Returns:
-            A list of strings. Entries in the list which are dotted are foreign
-            keys (i.e. keys belonging to a parent object). Entries which do not
-            have a dot belong natively to this object.
-        """
-
-        return []
-
     @property
     def _key_values(self) -> List:
         """Return a list of values of the keys of the object.
@@ -292,10 +358,24 @@ class Resource:  # pylint: disable=too-many-instance-attributes
 
             # if we were given parent_keys when the object was constructed, then
             # use those
-            if len(self.parent_keys) == len(self.path_keys):
+
+            # URL encode the parent key values with character '/'
+            if self.parent_keys:
+                LOGGER.debug(
+                    "Key values provided for the API endpoint: %s",
+                    ", ".join(str(item) for item in self.parent_keys)
+                )
+
+            # If there are any None values in the list, clean them up
+            parent_keys_encoded = []
+            for _key in self.parent_keys:
+                if _key:
+                    parent_keys_encoded.append(str(urllib.parse.quote_plus(_key)))
+
+            if len(parent_keys_encoded) >= len(self.path_keys):
                 for index, key in enumerate(self.path_keys):
                     pieces = key.split(".")
-                    format_keys[pieces[0]] = {pieces[1]: self.parent_keys[index]}
+                    format_keys[pieces[0]] = {pieces[1]: parent_keys_encoded[index]}
             else:
                 representative = self
                 if self._last_state:
@@ -304,7 +384,16 @@ class Resource:  # pylint: disable=too-many-instance-attributes
                     key = key.split(".")[0]
                     format_keys[key] = operator.attrgetter(key)(representative)
 
-            return self._path.format(**format_keys)
+            location = self._path.format(**format_keys)
+
+            # If there are more parent keys than path keys, those should be child keys
+            # appended to the url. This is an edge case where same endpoint is being
+            # used for both GET instance and collection, which needs to be handled here.
+            if len(parent_keys_encoded) > len(self.path_keys) and self.__module__ == "netapp_ontap.resources.file_info":
+                child_keys = "/".join(parent_keys_encoded[len(self.path_keys):])
+                location = "/".join([location, child_keys])
+
+            return location
         except Exception as exc:
             msg = (
                 "Could not compute the location of the %s collection. Values for"
@@ -328,6 +417,10 @@ class Resource:  # pylint: disable=too-many-instance-attributes
             A string representing the full path to this resource. When interacting with the host, this location is used as the URL.
         """
 
+        if self.parent_keys and self.path_keys:
+            if len(self.parent_keys) > len(self.path_keys):
+                return self._location
+
         # a keyless resource looks more like a collection location
         if not self._keys:
             return self._location
@@ -384,10 +477,10 @@ class Resource:  # pylint: disable=too-many-instance-attributes
 
         if getattr(cls, "_schema_instance", None) is None:
             cls._schema_instance = cls._schema()
-        unknown_policy = marshmallow.RAISE if strict else marshmallow.INCLUDE
+        unknown_policy = RAISE if strict else INCLUDE
         try:
-            if cls.__name__ == "Software":
-                input_dict = _cluster_software_fix(cls, input_dict)
+            if cls.__module__ == 'netapp_ontap.resources.software':
+                input_dict = _cluster_software_fix(input_dict)
             resource = cls._schema_instance.load(input_dict, unknown=unknown_policy)
         except Exception as exc:
             raise NetAppRestError(cause=exc) from None
@@ -548,10 +641,10 @@ class Resource:  # pylint: disable=too-many-instance-attributes
                     if connection is not None:
                         obj.set_connection(connection)
                     yield obj
-        except (requests.exceptions.RequestException) as error:
+        except (requests.exceptions.RequestException) as erro:
             # our @utils.api wrapper cannot help us generically catch this error
             # since this is a generator function and not a normal function
-            utils.on_api_fail(error)
+            utils.on_api_fail(erro)
 
     @classmethod
     def _count_collection(
@@ -597,9 +690,9 @@ class Resource:  # pylint: disable=too-many-instance-attributes
             )
             response.raise_for_status()
             return response.json().get("num_records", -1)
-        except (requests.exceptions.RequestException) as error:
+        except (requests.exceptions.RequestException) as erro:
             if config.RAISE_API_ERRORS:
-                raise NetAppRestError(cause=error) from None
+                raise NetAppRestError(cause=erro) from None
             return -1
 
     @classmethod
@@ -640,7 +733,7 @@ class Resource:  # pylint: disable=too-many-instance-attributes
         while url:
             response = sample.get_connection().session.patch(  # pylint: disable=protected-access
                 url,
-                data=json.dumps(body, cls=ResourceJSONEncoder).encode("utf-8"),
+                data=json.dumps(body, cls=ResourceJSONEncoder, ensure_ascii=False).encode("utf-8"),
                 params=params,
                 headers={"Content-Type": "application/json"},
             )
@@ -656,6 +749,7 @@ class Resource:  # pylint: disable=too-many-instance-attributes
                 params = {}
             else:
                 url = ""
+        cls._check_collection_jobs(response, connection=connection)
         return NetAppResponse(response)
 
     # pylint: disable=bad-continuation
@@ -712,8 +806,50 @@ class Resource:  # pylint: disable=too-many-instance-attributes
                 params = {}
             else:
                 url = ""
+        cls._check_collection_jobs(response, connection=connection)
         return NetAppResponse(response)
 
+    # pylint: disable=bad-continuation
+    @classmethod
+    def _check_collection_jobs(
+        cls,
+        response: requests.Response,
+        connection: HostConnection = None,
+    ) -> None:
+        """Checks the status of any jobs that were run as part of a collection
+        operation. If any of the jobs failed, this function will raise an exception
+        with the error message of all of the failures (if more than 1).
+
+        Args:
+            response: The response received from the API after all of the collection
+                operations are complete
+            connection: The `netapp_ontap.host_connection.HostConnection` object
+                to use for this API call. If unset, tries to use the connection
+                which is set globally for the library or from the current context.
+
+        Raises:
+            `netapp_ontap.error.NetAppRestError`: If one or more jobs have an
+                ending state of "failed"
+        """
+
+        response_body = response.json()
+        if "jobs" not in response_body:
+            return
+
+        errors = []
+        for job in response_body["jobs"]:
+            job_link = job.get("_links", {}).get("self", {}).get("href")
+            if not job_link:
+                continue
+            try:
+                utils.watch_job(job_link, connection=connection)
+            except NetAppRestError as exc:
+                # collect all error messages
+                errors.append(str(exc))
+
+        if errors:
+            raise NetAppRestError("One or more jobs failed: %s" % errors)
+
     @classmethod
     @utils.api
     def _find(cls, *args, connection: HostConnection = None, **kwargs) -> Optional["Resource"]:
@@ -756,7 +892,8 @@ class Resource:  # pylint: disable=too-many-instance-attributes
             raise NetAppRestError(message=msg)
 
         resource = results[0]
-        resource.set_connection(connection)
+        if connection is not None:
+            resource.set_connection(connection)
         resource._get(fields=kwargs.get("fields"))  # pylint: disable=protected-access
         return resource
 
@@ -779,7 +916,34 @@ class Resource:  # pylint: disable=too-many-instance-attributes
         url = "%s%s" % (self.get_connection().origin, self.instance_location)
         response = self.get_connection().session.get(url, params=kwargs)
         response.raise_for_status()
-        self._clone_from_dict(response.json())
+        if response.content.decode("utf-8").startswith("{"):
+            response_dict = response.json()
+            if 'record' in response_dict:
+                response_dict = response_dict['record']
+            elif 'records' in response_dict:
+                if response_dict['num_records'] == 1:
+                    response_dict = response_dict['records'][0]
+                else:
+                    raise NetAppRestError(
+                        message="Received more than one record in the response %s."
+                        % (self.__class__.__name__)
+                    )
+            self._clone_from_dict(response_dict)
+        else:
+            # When dealing with multipart/form-data requests a HeaderParsingError warning is thrown.
+            # This is due to the server being too restrictive in what it allows in the header.
+            # Please reference BURT: 1342153
+            multipart_data = decoder.MultipartDecoder.from_response(response)
+            response_array = []
+            for part in multipart_data.parts:
+                if b'name="bytes_read"' not in part.headers[b'Content-Disposition']:
+                    # Decode the header into a string
+                    parse_name = part.headers[b'Content-Disposition'].decode("utf-8")
+                    parse_name = parse_name.split("filename=")
+                    parse_name = parse_name[1][1:-1]
+                    obj = {"name": parse_name, "content": part.content}
+                    response_array.append(obj)
+            self.response_files = response_array
         self._set_last_state()
         self._last_response = NetAppResponse(response)
         return self._last_response
@@ -802,14 +966,13 @@ class Resource:  # pylint: disable=too-many-instance-attributes
             poll: If set to True, the call will not return until the
                 asynchronous job on the host has completed. Has no effect if the
                 host did not return a job response.
-            hydrate: If set to True, after the response is received from
-                the call, a GET call will be made to refresh all fields of the object.
             poll_interval: If the operation returns a job, this specifies how
                 often to query the job for updates.
             poll_timeout: If the operation returns a job, this specifies how
                 long to continue monitoring the job's status for completion.
-            **kwargs: Any key/value pairs passed will be sent as query parameters
-                to the host.
+	    **kwargs: Any key/value pairs passed will normally be sent as query parameters
+                to the host. If any of these pairs are parameters that are sent as formdata then
+                only parameters of that type will be accepted and all others will be discarded.
 
         Returns:
             A `netapp_ontap.response.NetAppResponse` object containing the
@@ -825,12 +988,31 @@ class Resource:  # pylint: disable=too-many-instance-attributes
         # trim out any keys from the body which are present as part of the path
         for key in self.path_keys:
             body_data.pop(key.split(".")[0], None)
-        response = self.get_connection().session.post(
-            url,
-            data=json.dumps(body_data, cls=ResourceJSONEncoder).encode("utf-8"),
-            params=kwargs,
-            headers={"Content-Type": "application/json"},
-        )
+
+	# holds a list of valid formdata parameters that the user passed in - if user tries to pass parameters that aren't valid they will just be ignored
+        valid_formdata_parameters_list = set() # type: ignore
+        if hasattr(self, '_post_form_data_parameters'):
+            valid_formdata_parameters_list = set(self._post_form_data_parameters) & set(kwargs)
+
+        # if no valid formdata parameters are passed into the request - send application/json request
+        if not valid_formdata_parameters_list:
+            response = self.get_connection().session.post(
+                url,
+                data=json.dumps(body_data, cls=ResourceJSONEncoder, ensure_ascii=False).encode("utf-8"),
+                params=kwargs,
+                headers={"Content-Type": "application/json"},
+            )
+
+	# if valid formdata parameters are passed into the request - send multipart/form-data request
+        else:
+            file_objects = self._populate_file_objects(kwargs, "post")
+            kwargs = {k: v for k, v in kwargs.items() if k not in valid_formdata_parameters_list}
+            response = self.get_connection().session.post(
+                url,
+                files=file_objects,
+                params=kwargs,
+                stream=True,
+            )
         response.raise_for_status()
 
         if not 'Location' in response.headers:
@@ -870,14 +1052,13 @@ class Resource:  # pylint: disable=too-many-instance-attributes
             poll: If set to True, the call will not return until the
                 asynchronous job on the host has completed. Has no effect if the
                 host did not return a job response.
-            hydrate: If set to True, after the response is received from
-                the call, a a GET call will be made to refresh all fields of the object.
             poll_interval: If the operation returns a job, this specifies how
                 often to query the job for updates.
             poll_timeout: If the operation returns a job, this specifies how
                 long to continue monitoring the job's status for completion.
-            **kwargs: Any key/value pairs passed will be sent as query parameters
-                to the host.
+	    **kwargs: Any key/value pairs passed will normally be sent as query parameters
+                to the host. If any of these pairs are parameters that are sent as formdata then
+                only parameters of that type will be accepted and all others will be discarded.
 
         Returns:
             A `netapp_ontap.response.NetAppResponse` object containing the
@@ -889,14 +1070,32 @@ class Resource:  # pylint: disable=too-many-instance-attributes
         """
 
         url = "%s%s" % (self.get_connection().origin, self.instance_location)
-        response = self.get_connection().session.patch(
-            url,
-            data=json.dumps(self._get_changed_data(), cls=ResourceJSONEncoder).encode(
-                "utf-8"
-            ),
-            params=kwargs,
-            headers={"Content-Type": "application/json"},
-        )
+
+	# holds a list of valid formdata parameters that the user passed in - if user tries to pass parameteres that arn't valid they will just be ignored
+        valid_formdata_parameters_list = set() # type: ignore
+        if hasattr(self, '_patch_form_data_parameters'):
+            valid_formdata_parameters_list = set(self._patch_form_data_parameters) & set(kwargs)
+
+        # if no valid formdata parameters are passed into the request - send application/json request
+        if not valid_formdata_parameters_list:
+            response = self.get_connection().session.patch(
+                url,
+                data=json.dumps(
+                    self._get_changed_data(), cls=ResourceJSONEncoder,
+                    ensure_ascii=False,
+                ).encode("utf-8"),
+                params=kwargs,
+                headers={"Content-Type": "application/json"},
+            )
+        else:
+            file_objects = self._populate_file_objects(kwargs, "patch")
+            kwargs = {k: v for k, v in kwargs.items() if k not in valid_formdata_parameters_list}
+            response = self.get_connection().session.patch(
+                url,
+                files=file_objects,
+                params=kwargs,
+                stream=True,
+            )
         response.raise_for_status()
         self._set_last_state()
         self._last_response = NetAppResponse(response)
@@ -990,9 +1189,23 @@ class Resource:  # pylint: disable=too-many-instance-attributes
         """
 
         url = "%s%s/%s" % (self.get_connection().origin, self.instance_location, path)
-        response = self.get_connection().session.post(url, json=self._get_body_data(body), params=kwargs)
-        response.raise_for_status()
 
+        # holds a list of valid formdata parameters that the user passed in - if user tries to pass parameters that aren't valid they will just be ignored
+        valid_formdata_parameters_list = set() # type: ignore
+        if hasattr(self, '_action_form_data_parameters'):
+            valid_formdata_parameters_list = set(self._action_form_data_parameters) & set(kwargs)
+
+        # if no valid formdata parameters are passed into the request - send application/json request
+        if not valid_formdata_parameters_list:
+            response = self.get_connection().session.post(url, json=self._get_body_data(body), params=kwargs)
+
+        # if valid formdata parameters are passed into the request - send multipart/form-data request
+        else:
+            file_objects = self._populate_file_objects(kwargs, "action")
+            kwargs = {k: v for k, v in kwargs.items() if k not in valid_formdata_parameters_list}
+            response = self.get_connection().session.post(url, files=file_objects, params=kwargs, stream=True)
+
+        response.raise_for_status()
         if poll:
             return utils.poll(
                 response, connection=self.get_connection(),
@@ -1162,6 +1375,7 @@ class Resource:  # pylint: disable=too-many-instance-attributes
                 raise NetAppRestError(message=msg)
 
         # now pick apart the URL and fill in our keys
+        location = location.split("?", 1)[0]
         location = location.replace(self._location, "").replace("/", "", 1)
         for key_index in range(len(self._keys) - len(self.path_keys)):
             key_attr = self._keys[-key_index - 1]
@@ -1244,7 +1458,7 @@ class Resource:  # pylint: disable=too-many-instance-attributes
             current_value = getattr(self, field, None)
             previous_value = last_state.get(field, None)
 
-            if current_value is not None and current_value != marshmallow.missing:
+            if current_value is not None and current_value != missing:
                 current_value = _get_current_value(
                     schema, field, current_value, previous_value,
                 )
@@ -1282,7 +1496,7 @@ class Resource:  # pylint: disable=too-many-instance-attributes
 
             current_value = getattr(self, field, None)
 
-            if current_value is not None and current_value != marshmallow.missing:
+            if current_value is not None and current_value != missing:
                 current_value = _get_postable_value(
                     schema, field, current_value
                 )
@@ -1319,6 +1533,61 @@ class Resource:  # pylint: disable=too-many-instance-attributes
             return True
         return False
 
+    def _populate_file_objects(self, user_params: dict, method: str = "") -> dict:
+        """Parse through all valid formdata parameters passed by user to generate
+        a file object dictionary that contains either literal or file data types or both.
+
+        Args:
+            user_params: dictionary of possible valid formData parameters and their values
+            method: a string that is used to determine which REST action is taking place.
+                This is used to differentiate between the post and patch formdata parameters.
+
+        Returns:
+            a dictionary with all valid file objects, both literal and file.
+        """
+        _form_data = {} # type: dict
+        _form_data_values = getattr(self, "_%s_form_data_parameters" % method).values()
+        _form_data = getattr(self, "_%s_form_data_parameters" % method)
+
+        # dictionary that holds all multipart/form-data that will be sent in the request
+        file_objects = {} # type: Any
+        # Whenever the user is sending a single file that may or may not be > 1GB
+        send_single_large_file = True
+
+        # populate the file_objects dictionary with parameters of type integer/boolean/string
+        literal_types = {"string", "integer", "boolean"}
+        if literal_types.intersection(set(_form_data_values)):
+            send_single_large_file = False
+            literal_list = [k for k in user_params if _form_data.get(k) in literal_types]
+            for param in literal_list:
+                data_object = user_params.get(param)
+                if data_object is not None:
+                    file_objects[param] = (param, data_object)
+
+        # if there exists a formdata parameter that is of type file
+        if 'file' in _form_data_values:
+            # create string array with all parameters of type file
+            file_list = [k for k in user_params if _form_data.get(k) == "file"]
+            # if there is only 1 file being sent as multipart/form-data
+            # to account for the possibility that this file may be > 1GB we must handle this use case differently
+            # support for uploading multiple large files will be added in the future.
+            if send_single_large_file and len(file_list) == 1 and list(user_params.values())[0].startswith("@"):
+                file_objects[file_list[0]] = (list(user_params.values())[0][1:], LazyFile(list(user_params.values())[0][1:], 'rb'), "application/octet-stream")
+                return file_objects
+            # populate the file_objects dictionary with all parameters of type file
+            for param in file_list:
+                data_file = user_params.get(param)
+                if data_file is not None:
+                    if data_file.startswith('@'):
+                        data_file = data_file[1:]
+                        file_objects[param] = (data_file, LazyFile(data_file, 'rb'), "application/octet-stream")
+                    else:
+                        file_objects[param] = (param, data_file)
+
+        return file_objects
+
+
+
 # pylint: disable=bad-continuation
 def _get_postable_value(
     schema: ResourceSchema, field: str, current_value: Any
@@ -1412,47 +1681,22 @@ def _flatten_dict(initial: dict, parent_key: str = "") -> dict:
             result[key] = value
     return result
 
-
-def _cluster_software_fix(cls: Type[Resource], input_dict: dict) -> dict:
+def _cluster_software_fix(input_dict: dict) -> dict:
     """This returns the correct schema for the /cluster/software endpoint
     to fix the backwards compatibility issue due to the model changing after 9.6
     Once we no longer support ONTAP 9.6, this hardcoded fix can be removed.
     """
-    # pylint: disable=protected-access,invalid-name
 
-    # adjust the schema definition due to bad YAML (burt 1291133)
-    try:
-        validation_field = cls._schema_instance.declared_fields["validation_results"]
-        # help mypy understand that this is a List and not just a Field
-        validation_field = cast(marshmallow.fields.List, validation_field)
-        schema_class_path = validation_field.inner.nested
-        SoftwareValidationSchema = marshmallow.class_registry._registry[schema_class_path][0]
-        action_field = SoftwareValidationSchema._declared_fields["action"]
-        issue_field = SoftwareValidationSchema._declared_fields["issue"]
-
-        # if we've already adjusted the schema once, this would fail so check if
-        # it is what we expect before doing it
-        if isinstance(action_field, marshmallow.fields.List):
-            SoftwareValidationSchema._declared_fields["action"] = action_field.inner
-        if isinstance(issue_field, marshmallow.fields.List):
-            SoftwareValidationSchema._declared_fields["issue"] = issue_field.inner
-    except Exception as exc:  # pylint: disable=broad-except
-        LOGGER.error("Failed to adjust schema for SoftwareValidationSchema: %s", exc)
-
-    # adjust the response from ONTAP due to breaking implementation changes
-    for obj in ["validation_results", "status_details"]:
+    for obj in ['validation_results', 'status_details']:
         if not obj in input_dict:
             continue
         items = input_dict[obj]
         for item in items:
-            #in 9.6, message and action are returned as top level fields
-            if isinstance(item.get("message", None), str):
-                item["issue"] = {"message": item["message"]}
-            if isinstance(item.get("action", None), str):
-                item["action"] = {"message": item["action"]}
-
+            if isinstance(item.get('message', None), str):
+                item['issue'] = {'message': item['message']}
+            if isinstance(item.get('action', None), str):
+                item['action'] = {'message': item['action']}
     return input_dict
 
-
 class _EmptyObject:  # pylint: disable=too-few-public-methods
     """This class is to be used to add dynamic, nested attributes to resources."""
