@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -13,12 +7,25 @@ Applications support Snapshot copies across all member storage elements. These S
 The functionality provided by these APIs is not integrated with the host application. Snapshot copies have limited value without host coordination, so the use of the SnapCenter Backup Management suite is recommended to ensure correct interaction between host applications and ONTAP.
 """
 
+import asyncio
+from datetime import datetime
 import inspect
-from typing import Iterable, Optional, Union
+from typing import Callable, Iterable, List, Optional, Union
 
-from marshmallow import EXCLUDE, fields  # type: ignore
+try:
+    CLICHE_INSTALLED = False
+    import cliche
+    from cliche.arg_types.choices import Choices
+    from cliche.commands import ClicheCommandError
+    from netapp_ontap.resource_table import ResourceTable
+    CLICHE_INSTALLED = True
+except ImportError:
+    pass
 
-from netapp_ontap.resource import Resource, ResourceSchema
+from marshmallow import fields, EXCLUDE  # type: ignore
+
+import netapp_ontap
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 from netapp_ontap import NetAppResponse, HostConnection
 from netapp_ontap.validations import enum_validation, len_validation, integer_validation
 from netapp_ontap.error import NetAppRestError
@@ -27,8 +34,10 @@ from netapp_ontap.error import NetAppRestError
 __all__ = ["ApplicationSnapshot", "ApplicationSnapshotSchema"]
 __pdoc__ = {
     "ApplicationSnapshotSchema.resource": False,
-    "ApplicationSnapshotSchema.patchable_fields": False,
-    "ApplicationSnapshotSchema.postable_fields": False,
+    "ApplicationSnapshot.application_snapshot_show": False,
+    "ApplicationSnapshot.application_snapshot_create": False,
+    "ApplicationSnapshot.application_snapshot_modify": False,
+    "ApplicationSnapshot.application_snapshot_delete": False,
 }
 
 
@@ -88,37 +97,69 @@ Valid choices:
     def resource(self):
         return ApplicationSnapshot
 
-    @property
-    def patchable_fields(self):
-        return [
-            "application",
-            "comment",
-            "consistency_type",
-            "name",
-            "svm",
-        ]
+    gettable_fields = [
+        "links",
+        "application",
+        "comment",
+        "components",
+        "consistency_type",
+        "create_time",
+        "is_partial",
+        "name",
+        "svm",
+        "uuid",
+    ]
+    """links,application,comment,components,consistency_type,create_time,is_partial,name,svm,uuid,"""
 
-    @property
-    def postable_fields(self):
-        return [
-            "application",
-            "comment",
-            "consistency_type",
-            "name",
-            "svm",
-        ]
+    patchable_fields = [
+        "application",
+        "comment",
+        "consistency_type",
+        "name",
+        "svm",
+    ]
+    """application,comment,consistency_type,name,svm,"""
+
+    postable_fields = [
+        "application",
+        "comment",
+        "consistency_type",
+        "name",
+        "svm",
+    ]
+    """application,comment,consistency_type,name,svm,"""
+
+def _get_field_list(field: str) -> Callable[[], List]:
+    def getter():
+        return [getattr(r, field) for r in ApplicationSnapshot.get_collection(fields=field)]
+    return getter
+
+async def _wait_for_job(response: NetAppResponse) -> None:
+    """Examine the given response. If it is a job, asynchronously wait for it to
+    complete. While polling, prints the current status message of the job.
+    """
+
+    if not response.is_job:
+        return
+    from netapp_ontap.resources import Job
+    job = Job(**response.http_response.json()["job"])
+    while True:
+        job.get(fields="state,message")
+        if hasattr(job, "message"):
+            print("[%s]: %s" % (job.state, job.message))
+        if job.state == "failure":
+            raise NetAppRestError("ApplicationSnapshot modify job failed")
+        if job.state == "success":
+            break
+        await asyncio.sleep(1)
 
 class ApplicationSnapshot(Resource):
     """Allows interaction with ApplicationSnapshot objects on the host"""
 
     _schema = ApplicationSnapshotSchema
     _path = "/api/application/applications/{application[uuid]}/snapshots"
-    @property
-    def _keys(self):
-        return ["application.uuid", "uuid"]
+    _keys = ["application.uuid", "uuid"]
 
-    # pylint: disable=bad-continuation
-    # pylint: disable=missing-docstring
     @classmethod
     def get_collection(
         cls,
@@ -143,10 +184,53 @@ GET /application/applications/{application.uuid}/snapshots?consistency_type=appl
 """
         return super()._get_collection(*args, connection=connection, max_records=max_records, **kwargs)
 
-    get_collection.__func__.__doc__ += "\n\n---\n" + inspect.cleandoc(Resource._get_collection.__doc__)  # pylint: disable=no-member
+    get_collection.__func__.__doc__ += "\n\n---\n" + inspect.cleandoc(Resource._get_collection.__doc__)
+
+    if CLICHE_INSTALLED:
+        @cliche.command(name="application snapshot show")
+        def application_snapshot_show(
+            application_uuid,
+            comment: Choices.define(_get_field_list("comment"), cache_choices=True, inexact=True)=None,
+            consistency_type: Choices.define(_get_field_list("consistency_type"), cache_choices=True, inexact=True)=None,
+            create_time: Choices.define(_get_field_list("create_time"), cache_choices=True, inexact=True)=None,
+            is_partial: Choices.define(_get_field_list("is_partial"), cache_choices=True, inexact=True)=None,
+            name: Choices.define(_get_field_list("name"), cache_choices=True, inexact=True)=None,
+            uuid: Choices.define(_get_field_list("uuid"), cache_choices=True, inexact=True)=None,
+            fields: List[Choices.define(["comment", "consistency_type", "create_time", "is_partial", "name", "uuid", "*"])]=None,
+        ) -> ResourceTable:
+            """Fetch a list of ApplicationSnapshot resources
+
+            Args:
+                comment: Comment. Valid in POST.
+                consistency_type: Consistency type. This is for categorization purposes only. A Snapshot copy should not be set to 'application consistent' unless the host application is quiesced for the Snapshot copy. Valid in POST.
+                create_time: Creation time
+                is_partial: A partial Snapshot copy means that not all volumes in an application component were included in the Snapshot copy.
+                name: The Snapshot copy name. Valid in POST.
+                uuid: The Snapshot copy UUID. Valid in URL.
+            """
+
+            kwargs = {}
+            if comment is not None:
+                kwargs["comment"] = comment
+            if consistency_type is not None:
+                kwargs["consistency_type"] = consistency_type
+            if create_time is not None:
+                kwargs["create_time"] = create_time
+            if is_partial is not None:
+                kwargs["is_partial"] = is_partial
+            if name is not None:
+                kwargs["name"] = name
+            if uuid is not None:
+                kwargs["uuid"] = uuid
+            if fields is not None:
+                fields = ",".join(fields)
+                kwargs["fields"] = fields
+
+            return ApplicationSnapshot.get_collection(
+                application_uuid,
+                **kwargs
+            )
 
-    # pylint: disable=bad-continuation
-    # pylint: disable=missing-docstring
     @classmethod
     def count_collection(
         cls,
@@ -170,11 +254,9 @@ GET /application/applications/{application.uuid}/snapshots?consistency_type=appl
 """
         return super()._count_collection(*args, connection=connection, **kwargs)
 
-    count_collection.__func__.__doc__ += "\n\n---\n" + inspect.cleandoc(Resource._count_collection.__doc__)  # pylint: disable=no-member
+    count_collection.__func__.__doc__ += "\n\n---\n" + inspect.cleandoc(Resource._count_collection.__doc__)
 
 
-    # pylint: disable=bad-continuation
-    # pylint: disable=missing-docstring
     @classmethod
     def delete_collection(
         cls,
@@ -195,9 +277,8 @@ DELETE /application/applications/{application.uuid}/snapshots?create_time=<2017-
 * [`DOC /application/applications/{application.uuid}/snapshots`](#docs-application-application_applications_{application.uuid}_snapshots)"""
         return super()._delete_collection(*args, body=body, connection=connection, **kwargs)
 
-    delete_collection.__func__.__doc__ += "\n\n---\n" + inspect.cleandoc(Resource._delete_collection.__doc__)  # pylint: disable=no-member
+    delete_collection.__func__.__doc__ += "\n\n---\n" + inspect.cleandoc(Resource._delete_collection.__doc__)
 
-    # pylint: disable=missing-docstring
     @classmethod
     def find(cls, *args, connection: HostConnection = None, **kwargs) -> Resource:
         r"""Retrieves Snapshot copies of an application.
@@ -216,9 +297,8 @@ GET /application/applications/{application.uuid}/snapshots?consistency_type=appl
 """
         return super()._find(*args, connection=connection, **kwargs)
 
-    find.__func__.__doc__ += "\n\n---\n" + inspect.cleandoc(Resource._find.__doc__)  # pylint: disable=no-member
+    find.__func__.__doc__ += "\n\n---\n" + inspect.cleandoc(Resource._find.__doc__)
 
-    # pylint: disable=missing-docstring
     def get(self, **kwargs) -> NetAppResponse:
         r"""Retrieve a Snapshot copy of an application component.<br/>
 This endpoint is only supported for Maxdata template applications.<br/>
@@ -230,10 +310,8 @@ Component Snapshot copies are essentially more granular application Snapshot cop
 """
         return super()._get(**kwargs)
 
-    get.__doc__ += "\n\n---\n" + inspect.cleandoc(Resource._get.__doc__)  # pylint: disable=no-member
+    get.__doc__ += "\n\n---\n" + inspect.cleandoc(Resource._get.__doc__)
 
-    # pylint: disable=missing-docstring
-    # pylint: disable=bad-continuation
     def post(
         self,
         hydrate: bool = False,
@@ -256,11 +334,73 @@ Component Snapshot copies are essentially more granular application Snapshot cop
             poll_timeout=poll_timeout, **kwargs
         )
 
-    post.__doc__ += "\n\n---\n" + inspect.cleandoc(Resource._post.__doc__)  # pylint: disable=no-member
+    post.__doc__ += "\n\n---\n" + inspect.cleandoc(Resource._post.__doc__)
+
+    if CLICHE_INSTALLED:
+        @cliche.command(name="application snapshot create")
+        async def application_snapshot_create(
+            application_uuid,
+            links: dict = None,
+            application: dict = None,
+            comment: str = None,
+            components: dict = None,
+            consistency_type: str = None,
+            create_time: str = None,
+            is_partial: bool = None,
+            name: str = None,
+            svm: dict = None,
+            uuid: str = None,
+        ) -> ResourceTable:
+            """Create an instance of a ApplicationSnapshot resource
+
+            Args:
+                links: 
+                application: 
+                comment: Comment. Valid in POST.
+                components: 
+                consistency_type: Consistency type. This is for categorization purposes only. A Snapshot copy should not be set to 'application consistent' unless the host application is quiesced for the Snapshot copy. Valid in POST.
+                create_time: Creation time
+                is_partial: A partial Snapshot copy means that not all volumes in an application component were included in the Snapshot copy.
+                name: The Snapshot copy name. Valid in POST.
+                svm: 
+                uuid: The Snapshot copy UUID. Valid in URL.
+            """
+
+            kwargs = {}
+            if links is not None:
+                kwargs["links"] = links
+            if application is not None:
+                kwargs["application"] = application
+            if comment is not None:
+                kwargs["comment"] = comment
+            if components is not None:
+                kwargs["components"] = components
+            if consistency_type is not None:
+                kwargs["consistency_type"] = consistency_type
+            if create_time is not None:
+                kwargs["create_time"] = create_time
+            if is_partial is not None:
+                kwargs["is_partial"] = is_partial
+            if name is not None:
+                kwargs["name"] = name
+            if svm is not None:
+                kwargs["svm"] = svm
+            if uuid is not None:
+                kwargs["uuid"] = uuid
+
+            resource = ApplicationSnapshot(
+                application_uuid,
+                **kwargs
+            )
+            try:
+                response = resource.post(hydrate=True, poll=False)
+                await _wait_for_job(response)
+                resource.get()
+            except NetAppRestError as err:
+                raise ClicheCommandError("Unable to create ApplicationSnapshot: %s" % err)
+            return [resource]
 
 
-    # pylint: disable=missing-docstring
-    # pylint: disable=bad-continuation
     def delete(
         self,
         body: Union[Resource, dict] = None,
@@ -284,10 +424,57 @@ DELETE /application/applications/{application.uuid}/snapshots?create_time=<2017-
             poll_timeout=poll_timeout, **kwargs
         )
 
-    delete.__doc__ += "\n\n---\n" + inspect.cleandoc(Resource._delete.__doc__)  # pylint: disable=no-member
+    delete.__doc__ += "\n\n---\n" + inspect.cleandoc(Resource._delete.__doc__)
+
+    if CLICHE_INSTALLED:
+        @cliche.command(name="application snapshot delete")
+        async def application_snapshot_delete(
+            application_uuid,
+            comment: str = None,
+            consistency_type: str = None,
+            create_time: str = None,
+            is_partial: bool = None,
+            name: str = None,
+            uuid: str = None,
+        ) -> None:
+            """Delete an instance of a ApplicationSnapshot resource
+
+            Args:
+                comment: Comment. Valid in POST.
+                consistency_type: Consistency type. This is for categorization purposes only. A Snapshot copy should not be set to 'application consistent' unless the host application is quiesced for the Snapshot copy. Valid in POST.
+                create_time: Creation time
+                is_partial: A partial Snapshot copy means that not all volumes in an application component were included in the Snapshot copy.
+                name: The Snapshot copy name. Valid in POST.
+                uuid: The Snapshot copy UUID. Valid in URL.
+            """
+
+            kwargs = {}
+            if comment is not None:
+                kwargs["comment"] = comment
+            if consistency_type is not None:
+                kwargs["consistency_type"] = consistency_type
+            if create_time is not None:
+                kwargs["create_time"] = create_time
+            if is_partial is not None:
+                kwargs["is_partial"] = is_partial
+            if name is not None:
+                kwargs["name"] = name
+            if uuid is not None:
+                kwargs["uuid"] = uuid
+
+            if hasattr(ApplicationSnapshot, "find"):
+                resource = ApplicationSnapshot.find(
+                    application_uuid,
+                    **kwargs
+                )
+            else:
+                resource = ApplicationSnapshot(application_uuid,)
+            try:
+                response = resource.delete(poll=False)
+                await _wait_for_job(response)
+            except NetAppRestError as err:
+                raise ClicheCommandError("Unable to delete ApplicationSnapshot: %s" % err)
 
-    # pylint: disable=missing-docstring
-    # pylint: disable=bad-continuation
     def restore(
         self,
         body: Union[Resource, dict] = None,
@@ -300,12 +487,12 @@ DELETE /application/applications/{application.uuid}/snapshots?create_time=<2017-
 Restoring an application Snapshot copy reverts all storage elements in the Snapshot copy to the state in which the Snapshot copy was in when the Snapshot copy was taken. This restoration does not apply to access settings that might have changed since the Snapshot copy was created.
 ### Learn more
 * [`DOC /application`](#docs-application-overview)
-* [`DOC Asynchronous operations`](#docs-docs-Synchronous-and-asynchronous-operations)
+* [`Asynchronous operations`](#Synchronous_and_asynchronous_operations)
 """
         return super()._action(
             "restore", body=body, poll=poll, poll_interval=poll_interval,
             poll_timeout=poll_timeout, **kwargs
         )
 
-    restore.__doc__ += "\n\n---\n" + inspect.cleandoc(Resource._action.__doc__)  # pylint: disable=no-member
+    restore.__doc__ += "\n\n---\n" + inspect.cleandoc(Resource._action.__doc__)
 
