@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -13,9 +7,19 @@ Cluster peering allows administrators of ONTAP systems to establish relationship
 ## Create a cluster peer
 You can set up a new cluster peer relationship by issuing a POST request to /cluster/peers. Parameters in the POST body define the settings of the peering relationship. A successful POST request that succeeds in creating a peer returns HTTP status code "201", along with the details of the created peer, such as peer UUID, name, and authentication information. A failed POST request returns an HTTP error code along with a message indicating the reason for the error. This can include malformed requests and invalid operations.
 ### Sample request
+```python
+from netapp_ontap import HostConnection
+from netapp_ontap.resources import ClusterPeer
+
+with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
+    resource = ClusterPeer()
+    resource.authentication.expiry_time = "12/25/2018 12:34:56"
+    resource.authentication.generate_passphrase = True
+    resource.post(hydrate=True)
+    print(resource)
+
 ```
-curl -X POST 'https://<mgmt-ip>/api/cluster/peers/' -d '{"authentication":{"expiry_time":"12/25/2018 12:34:56","generate_passphrase":true}}'
-```
+
 ### Examples
 ```
 # Create - no params
@@ -74,29 +78,28 @@ After local interfaces have been created, do not specify them for subsequent clu
 ### Additional information on network routes
 When creating LIFs, the network route discovery mechanism might take additional time (1-5 seconds) to become visible in the network outside of the cluster. This delay in publishing the routes might cause an initial cluster peer "create" request to fail. This error disappears with a retry of the same request.
 ### Example
+```python
+from netapp_ontap import HostConnection
+from netapp_ontap.resources import ClusterPeer
+
+with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
+    resource = ClusterPeer()
+    resource.local_network.interfaces = [
+        {"ip_address": "1.2.3.4"},
+        {"ip_address": "1.2.3.5"},
+        {"ip_address": "1.2.3.6"},
+    ]
+    resource.local_network.netmask = "255.255.0.0"
+    resource.local_network.broadcast_domain = "Default"
+    resource.local_network.gateway = "1.2.0.1"
+    resource.remote.ip_addresses = ["1.2.9.9"]
+    resource.authentication.passphrase = "xyz12345"
+    resource.post(hydrate=True)
+    print(resource)
+
 ```
-curl -X POST "https://<mgmt-ip>/api/cluster/peers" -d body
-```
-Note that "<mgmt-ip>" is replaced by the IP address of the cluster management LIF, and "body" is replaced by the JSON body of the POST request containing the fields for the new peering relationship and local LIFs.
-### Example POST body
-This example shows the POST body when creating four intercluster LIFs on a 4-node cluster before creating a cluster peer relationship.
-```
-{
-    "local_network":
-    {
-        "interfaces": [
-            {"ip_address":"1.2.3.4"},
-            {"ip_address":"1.2.3.5"},
-            {"ip_address":"1.2.3.6"}
-            ],
-        "netmask": "255.255.0.0",
-        "broadcast_domain": "Default",
-        "gateway": "1.2.0.1"
-    }
-    "remote.ip_addresses": ["1.2.9.9"],
-    "authentication.passphrase": "xyz12345"
-}
-```
+
+Note that "<mgmt-ip>" is replaced by the IP address of the cluster management interface, and the body is read from the specified text file containing the fields for the new peering relationship and local interfaces.
 ---
 ## Retrieve a cluster peer
 You can retrieve peers in a cluster by issuing a GET request to /cluster/peers. It is also possible to retrieve a specific peer when qualified by its UUID to /cluster/peers/{uuid}.
@@ -109,11 +112,37 @@ The following fields are optional for GET requests
 
 * UUID - UUID of the cluster peer.
 ### Examples
+```python
+from netapp_ontap import HostConnection
+from netapp_ontap.resources import ClusterPeer
+
+with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
+    print(list(ClusterPeer.get_collection()))
+
 ```
-curl -X GET "https://<mgmt-ip>/api/cluster/peers/"
-curl -X GET "https://<mgmt-ip>/api/cluster/peers/{uuid}"
-curl -X GET "https://<mgmt-ip>/api/cluster/peers/{uuid}?fields=*"
+
+```python
+from netapp_ontap import HostConnection
+from netapp_ontap.resources import ClusterPeer
+
+with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
+    resource = ClusterPeer(uuid="{uuid}")
+    resource.get()
+    print(resource)
+
 ```
+
+```python
+from netapp_ontap import HostConnection
+from netapp_ontap.resources import ClusterPeer
+
+with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
+    resource = ClusterPeer(uuid="{uuid}")
+    resource.get(fields="*")
+    print(resource)
+
+```
+
 ---
 ## Update a cluster peer
 You can update a cluster peer relationship by issuing a PATCH request to /cluster/peers/{uuid}. As in the CLI mode, you can toggle the proposed encryption protocol, update the passphrase, or specify a new set of stable addresses.  All PATCH requests take the parameters that are to be updated in the request body. If the generate_passphrase is "true", the passphrase is returned in the PATCH response.
@@ -173,12 +202,18 @@ body =
 }
 ```
 ### Sample requests
+```python
+from netapp_ontap import HostConnection
+from netapp_ontap.resources import ClusterPeer
+
+with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
+    resource = ClusterPeer(uuid="73123071-d0b9-11e8-a686-005056a7179a")
+    resource.authentication.passphrase = "xyz12345"
+    resource.authentication.in_use = "ok"
+    resource.patch()
+
 ```
-# Setting a passphrase
-curl -X PATCH 'https://<mgmt-ip>/api/cluster/peers/73123071-d0b9-11e8-a686-005056a7179a' -d '{"authentication":{"passphrase":"xyz12345","in_use":"ok"}}'
-# Updating a peer address
-curl -X PATCH 'https://<mgmt-ip>/api/cluster/peers/73123071-d0b9-11e8-a686-005056a7179a' -d '{"remote":{"ip_addresses":["1.2.3.4"]}}'
-```
+
 ---
 ## Delete a cluster peer
 You can delete a cluster peer using the HTTP DELETE request.
@@ -190,17 +225,37 @@ The DELETE operation has no optional fields.
 DELETE "https://<mgmt-ip>/api/cluster/peers/{uuid}"
 ### Example
 The following request deletes a peer with peer UUID "8becc0d4-c12c-11e8-9ceb-005056bbd143".
+```python
+from netapp_ontap import HostConnection
+from netapp_ontap.resources import ClusterPeer
+
+with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
+    resource = ClusterPeer(uuid="8becc0d4-c12c-11e8-9ceb-005056bbd143")
+    resource.delete()
+
 ```
-curl -X DELETE "https://<mgmt-ip>/api/cluster/peers/8becc0d4-c12c-11e8-9ceb-005056bbd143"
-```
+
 """
 
+import asyncio
+from datetime import datetime
 import inspect
-from typing import Iterable, Optional, Union
+from typing import Callable, Iterable, List, Optional, Union
 
-from marshmallow import EXCLUDE, fields  # type: ignore
+try:
+    CLICHE_INSTALLED = False
+    import cliche
+    from cliche.arg_types.choices import Choices
+    from cliche.commands import ClicheCommandError
+    from netapp_ontap.resource_table import ResourceTable
+    CLICHE_INSTALLED = True
+except ImportError:
+    pass
 
-from netapp_ontap.resource import Resource, ResourceSchema
+from marshmallow import fields, EXCLUDE  # type: ignore
+
+import netapp_ontap
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 from netapp_ontap import NetAppResponse, HostConnection
 from netapp_ontap.validations import enum_validation, len_validation, integer_validation
 from netapp_ontap.error import NetAppRestError
@@ -209,8 +264,10 @@ from netapp_ontap.error import NetAppRestError
 __all__ = ["ClusterPeer", "ClusterPeerSchema"]
 __pdoc__ = {
     "ClusterPeerSchema.resource": False,
-    "ClusterPeerSchema.patchable_fields": False,
-    "ClusterPeerSchema.postable_fields": False,
+    "ClusterPeer.cluster_peer_show": False,
+    "ClusterPeer.cluster_peer_create": False,
+    "ClusterPeer.cluster_peer_modify": False,
+    "ClusterPeer.cluster_peer_delete": False,
 }
 
 
@@ -267,50 +324,87 @@ Example: 1cd8a442-86d1-11e0-ae1c-123478563412 """
     def resource(self):
         return ClusterPeer
 
-    @property
-    def patchable_fields(self):
-        return [
-            "links",
-            "authentication",
-            "encryption",
-            "initial_allowed_svms.name",
-            "initial_allowed_svms.uuid",
-            "ipspace.name",
-            "ipspace.uuid",
-            "name",
-            "peer_applications",
-            "remote",
-            "status",
-        ]
+    gettable_fields = [
+        "links",
+        "authentication",
+        "encryption",
+        "initial_allowed_svms.links",
+        "initial_allowed_svms.name",
+        "initial_allowed_svms.uuid",
+        "ipspace.links",
+        "ipspace.name",
+        "ipspace.uuid",
+        "name",
+        "peer_applications",
+        "remote",
+        "status",
+        "uuid",
+        "version",
+    ]
+    """links,authentication,encryption,initial_allowed_svms.links,initial_allowed_svms.name,initial_allowed_svms.uuid,ipspace.links,ipspace.name,ipspace.uuid,name,peer_applications,remote,status,uuid,version,"""
 
-    @property
-    def postable_fields(self):
-        return [
-            "links",
-            "authentication",
-            "encryption",
-            "initial_allowed_svms.name",
-            "initial_allowed_svms.uuid",
-            "ipspace.name",
-            "ipspace.uuid",
-            "local_network",
-            "name",
-            "peer_applications",
-            "remote",
-            "status",
-        ]
+    patchable_fields = [
+        "links",
+        "authentication",
+        "encryption",
+        "initial_allowed_svms.name",
+        "initial_allowed_svms.uuid",
+        "ipspace.name",
+        "ipspace.uuid",
+        "name",
+        "peer_applications",
+        "remote",
+        "status",
+    ]
+    """links,authentication,encryption,initial_allowed_svms.name,initial_allowed_svms.uuid,ipspace.name,ipspace.uuid,name,peer_applications,remote,status,"""
+
+    postable_fields = [
+        "links",
+        "authentication",
+        "encryption",
+        "initial_allowed_svms.name",
+        "initial_allowed_svms.uuid",
+        "ipspace.name",
+        "ipspace.uuid",
+        "local_network",
+        "name",
+        "peer_applications",
+        "remote",
+        "status",
+    ]
+    """links,authentication,encryption,initial_allowed_svms.name,initial_allowed_svms.uuid,ipspace.name,ipspace.uuid,local_network,name,peer_applications,remote,status,"""
+
+def _get_field_list(field: str) -> Callable[[], List]:
+    def getter():
+        return [getattr(r, field) for r in ClusterPeer.get_collection(fields=field)]
+    return getter
+
+async def _wait_for_job(response: NetAppResponse) -> None:
+    """Examine the given response. If it is a job, asynchronously wait for it to
+    complete. While polling, prints the current status message of the job.
+    """
+
+    if not response.is_job:
+        return
+    from netapp_ontap.resources import Job
+    job = Job(**response.http_response.json()["job"])
+    while True:
+        job.get(fields="state,message")
+        if hasattr(job, "message"):
+            print("[%s]: %s" % (job.state, job.message))
+        if job.state == "failure":
+            raise NetAppRestError("ClusterPeer modify job failed")
+        if job.state == "success":
+            break
+        await asyncio.sleep(1)
 
 class ClusterPeer(Resource):
     """Allows interaction with ClusterPeer objects on the host"""
 
     _schema = ClusterPeerSchema
     _path = "/api/cluster/peers"
-    @property
-    def _keys(self):
-        return ["uuid"]
+    _keys = ["uuid"]
 
-    # pylint: disable=bad-continuation
-    # pylint: disable=missing-docstring
     @classmethod
     def get_collection(
         cls,
@@ -324,10 +418,39 @@ class ClusterPeer(Resource):
 * [`DOC /cluster/peers`](#docs-cluster-cluster_peers)"""
         return super()._get_collection(*args, connection=connection, max_records=max_records, **kwargs)
 
-    get_collection.__func__.__doc__ += "\n\n---\n" + inspect.cleandoc(Resource._get_collection.__doc__)  # pylint: disable=no-member
+    get_collection.__func__.__doc__ += "\n\n---\n" + inspect.cleandoc(Resource._get_collection.__doc__)
+
+    if CLICHE_INSTALLED:
+        @cliche.command(name="cluster peer show")
+        def cluster_peer_show(
+            name: Choices.define(_get_field_list("name"), cache_choices=True, inexact=True)=None,
+            peer_applications: Choices.define(_get_field_list("peer_applications"), cache_choices=True, inexact=True)=None,
+            uuid: Choices.define(_get_field_list("uuid"), cache_choices=True, inexact=True)=None,
+            fields: List[Choices.define(["name", "peer_applications", "uuid", "*"])]=None,
+        ) -> ResourceTable:
+            """Fetch a list of ClusterPeer resources
+
+            Args:
+                name: Optional name for the cluster peer relationship. By default, it is the name of the remote cluster.
+                peer_applications: Peering applications against which allowed SVMs are configured.
+                uuid: UUID of the cluster peer relationship. For anonymous cluster peer offers, the UUID will change when the remote cluster accepts the relationship.
+            """
+
+            kwargs = {}
+            if name is not None:
+                kwargs["name"] = name
+            if peer_applications is not None:
+                kwargs["peer_applications"] = peer_applications
+            if uuid is not None:
+                kwargs["uuid"] = uuid
+            if fields is not None:
+                fields = ",".join(fields)
+                kwargs["fields"] = fields
+
+            return ClusterPeer.get_collection(
+                **kwargs
+            )
 
-    # pylint: disable=bad-continuation
-    # pylint: disable=missing-docstring
     @classmethod
     def count_collection(
         cls,
@@ -340,10 +463,8 @@ class ClusterPeer(Resource):
 * [`DOC /cluster/peers`](#docs-cluster-cluster_peers)"""
         return super()._count_collection(*args, connection=connection, **kwargs)
 
-    count_collection.__func__.__doc__ += "\n\n---\n" + inspect.cleandoc(Resource._count_collection.__doc__)  # pylint: disable=no-member
+    count_collection.__func__.__doc__ += "\n\n---\n" + inspect.cleandoc(Resource._count_collection.__doc__)
 
-    # pylint: disable=bad-continuation
-    # pylint: disable=missing-docstring
     @classmethod
     def patch_collection(
         cls,
@@ -357,10 +478,8 @@ class ClusterPeer(Resource):
 * [`DOC /cluster/peers`](#docs-cluster-cluster_peers)"""
         return super()._patch_collection(body, *args, connection=connection, **kwargs)
 
-    patch_collection.__func__.__doc__ += "\n\n---\n" + inspect.cleandoc(Resource._patch_collection.__doc__)  # pylint: disable=no-member
+    patch_collection.__func__.__doc__ += "\n\n---\n" + inspect.cleandoc(Resource._patch_collection.__doc__)
 
-    # pylint: disable=bad-continuation
-    # pylint: disable=missing-docstring
     @classmethod
     def delete_collection(
         cls,
@@ -374,9 +493,8 @@ class ClusterPeer(Resource):
 * [`DOC /cluster/peers`](#docs-cluster-cluster_peers)"""
         return super()._delete_collection(*args, body=body, connection=connection, **kwargs)
 
-    delete_collection.__func__.__doc__ += "\n\n---\n" + inspect.cleandoc(Resource._delete_collection.__doc__)  # pylint: disable=no-member
+    delete_collection.__func__.__doc__ += "\n\n---\n" + inspect.cleandoc(Resource._delete_collection.__doc__)
 
-    # pylint: disable=missing-docstring
     @classmethod
     def find(cls, *args, connection: HostConnection = None, **kwargs) -> Resource:
         r"""Retrieves the collection of cluster peers.
@@ -384,19 +502,16 @@ class ClusterPeer(Resource):
 * [`DOC /cluster/peers`](#docs-cluster-cluster_peers)"""
         return super()._find(*args, connection=connection, **kwargs)
 
-    find.__func__.__doc__ += "\n\n---\n" + inspect.cleandoc(Resource._find.__doc__)  # pylint: disable=no-member
+    find.__func__.__doc__ += "\n\n---\n" + inspect.cleandoc(Resource._find.__doc__)
 
-    # pylint: disable=missing-docstring
     def get(self, **kwargs) -> NetAppResponse:
         r"""Retrieves a specific cluster peer instance.
 ### Learn more
 * [`DOC /cluster/peers`](#docs-cluster-cluster_peers)"""
         return super()._get(**kwargs)
 
-    get.__doc__ += "\n\n---\n" + inspect.cleandoc(Resource._get.__doc__)  # pylint: disable=no-member
+    get.__doc__ += "\n\n---\n" + inspect.cleandoc(Resource._get.__doc__)
 
-    # pylint: disable=missing-docstring
-    # pylint: disable=bad-continuation
     def post(
         self,
         hydrate: bool = False,
@@ -440,10 +555,78 @@ As with creating a cluster peer through the CLI, the combinations of options mus
             poll_timeout=poll_timeout, **kwargs
         )
 
-    post.__doc__ += "\n\n---\n" + inspect.cleandoc(Resource._post.__doc__)  # pylint: disable=no-member
+    post.__doc__ += "\n\n---\n" + inspect.cleandoc(Resource._post.__doc__)
+
+    if CLICHE_INSTALLED:
+        @cliche.command(name="cluster peer create")
+        async def cluster_peer_create(
+            links: dict = None,
+            authentication: dict = None,
+            encryption: dict = None,
+            initial_allowed_svms: dict = None,
+            ipspace: dict = None,
+            local_network: dict = None,
+            name: str = None,
+            peer_applications: List[str] = None,
+            remote: dict = None,
+            status: dict = None,
+            uuid: str = None,
+            version: dict = None,
+        ) -> ResourceTable:
+            """Create an instance of a ClusterPeer resource
+
+            Args:
+                links: 
+                authentication: 
+                encryption: 
+                initial_allowed_svms: The local SVMs allowed to peer with the peer cluster's SVMs. This list can be modified until the remote cluster accepts this cluster peering relationship.
+                ipspace: 
+                local_network: 
+                name: Optional name for the cluster peer relationship. By default, it is the name of the remote cluster.
+                peer_applications: Peering applications against which allowed SVMs are configured.
+                remote: 
+                status: 
+                uuid: UUID of the cluster peer relationship. For anonymous cluster peer offers, the UUID will change when the remote cluster accepts the relationship.
+                version: 
+            """
+
+            kwargs = {}
+            if links is not None:
+                kwargs["links"] = links
+            if authentication is not None:
+                kwargs["authentication"] = authentication
+            if encryption is not None:
+                kwargs["encryption"] = encryption
+            if initial_allowed_svms is not None:
+                kwargs["initial_allowed_svms"] = initial_allowed_svms
+            if ipspace is not None:
+                kwargs["ipspace"] = ipspace
+            if local_network is not None:
+                kwargs["local_network"] = local_network
+            if name is not None:
+                kwargs["name"] = name
+            if peer_applications is not None:
+                kwargs["peer_applications"] = peer_applications
+            if remote is not None:
+                kwargs["remote"] = remote
+            if status is not None:
+                kwargs["status"] = status
+            if uuid is not None:
+                kwargs["uuid"] = uuid
+            if version is not None:
+                kwargs["version"] = version
+
+            resource = ClusterPeer(
+                **kwargs
+            )
+            try:
+                response = resource.post(hydrate=True, poll=False)
+                await _wait_for_job(response)
+                resource.get()
+            except NetAppRestError as err:
+                raise ClicheCommandError("Unable to create ClusterPeer: %s" % err)
+            return [resource]
 
-    # pylint: disable=missing-docstring
-    # pylint: disable=bad-continuation
     def patch(
         self,
         hydrate: bool = False,
@@ -460,10 +643,61 @@ As with creating a cluster peer through the CLI, the combinations of options mus
             poll_timeout=poll_timeout, **kwargs
         )
 
-    patch.__doc__ += "\n\n---\n" + inspect.cleandoc(Resource._patch.__doc__)  # pylint: disable=no-member
+    patch.__doc__ += "\n\n---\n" + inspect.cleandoc(Resource._patch.__doc__)
+
+    if CLICHE_INSTALLED:
+        @cliche.command(name="cluster peer modify")
+        async def cluster_peer_modify(
+            name: str = None,
+            query_name: str = None,
+            peer_applications: List[str] = None,
+            query_peer_applications: List[str] = None,
+            uuid: str = None,
+            query_uuid: str = None,
+        ) -> ResourceTable:
+            """Modify an instance of a ClusterPeer resource
+
+            Args:
+                name: Optional name for the cluster peer relationship. By default, it is the name of the remote cluster.
+                query_name: Optional name for the cluster peer relationship. By default, it is the name of the remote cluster.
+                peer_applications: Peering applications against which allowed SVMs are configured.
+                query_peer_applications: Peering applications against which allowed SVMs are configured.
+                uuid: UUID of the cluster peer relationship. For anonymous cluster peer offers, the UUID will change when the remote cluster accepts the relationship.
+                query_uuid: UUID of the cluster peer relationship. For anonymous cluster peer offers, the UUID will change when the remote cluster accepts the relationship.
+            """
+
+            kwargs = {}
+            changes = {}
+            if query_name is not None:
+                kwargs["name"] = query_name
+            if query_peer_applications is not None:
+                kwargs["peer_applications"] = query_peer_applications
+            if query_uuid is not None:
+                kwargs["uuid"] = query_uuid
+
+            if name is not None:
+                changes["name"] = name
+            if peer_applications is not None:
+                changes["peer_applications"] = peer_applications
+            if uuid is not None:
+                changes["uuid"] = uuid
+
+            if hasattr(ClusterPeer, "find"):
+                resource = ClusterPeer.find(
+                    **kwargs
+                )
+            else:
+                resource = ClusterPeer()
+            try:
+                for key, value in changes.items():
+                    setattr(resource, key, value)
+                response = resource.patch(poll=False)
+                await _wait_for_job(response)
+                resource.get(fields=",".join(changes.keys()))
+                return [resource]
+            except NetAppRestError as err:
+                raise ClicheCommandError("Unable to modify ClusterPeer: %s" % err)
 
-    # pylint: disable=missing-docstring
-    # pylint: disable=bad-continuation
     def delete(
         self,
         body: Union[Resource, dict] = None,
@@ -480,6 +714,41 @@ As with creating a cluster peer through the CLI, the combinations of options mus
             poll_timeout=poll_timeout, **kwargs
         )
 
-    delete.__doc__ += "\n\n---\n" + inspect.cleandoc(Resource._delete.__doc__)  # pylint: disable=no-member
+    delete.__doc__ += "\n\n---\n" + inspect.cleandoc(Resource._delete.__doc__)
+
+    if CLICHE_INSTALLED:
+        @cliche.command(name="cluster peer delete")
+        async def cluster_peer_delete(
+            name: str = None,
+            peer_applications: List[str] = None,
+            uuid: str = None,
+        ) -> None:
+            """Delete an instance of a ClusterPeer resource
+
+            Args:
+                name: Optional name for the cluster peer relationship. By default, it is the name of the remote cluster.
+                peer_applications: Peering applications against which allowed SVMs are configured.
+                uuid: UUID of the cluster peer relationship. For anonymous cluster peer offers, the UUID will change when the remote cluster accepts the relationship.
+            """
+
+            kwargs = {}
+            if name is not None:
+                kwargs["name"] = name
+            if peer_applications is not None:
+                kwargs["peer_applications"] = peer_applications
+            if uuid is not None:
+                kwargs["uuid"] = uuid
+
+            if hasattr(ClusterPeer, "find"):
+                resource = ClusterPeer.find(
+                    **kwargs
+                )
+            else:
+                resource = ClusterPeer()
+            try:
+                response = resource.delete(poll=False)
+                await _wait_for_job(response)
+            except NetAppRestError as err:
+                raise ClicheCommandError("Unable to delete ClusterPeer: %s" % err)
 
 
