@@ -1,9 +1,3 @@
-# pylint: disable=trailing-newlines
-# pylint: disable=line-too-long
-# pylint: disable=too-many-lines
-# pylint: disable=unused-import
-# pylint: disable=invalid-name
-
 r"""
 Copyright &copy; 2020 NetApp Inc.
 All rights reserved.
@@ -21,12 +15,25 @@ SVM administrators might have all or some of the following administration capabi
 4. Updating the TLS certificate for this SVM.
 """
 
+import asyncio
+from datetime import datetime
 import inspect
-from typing import Iterable, Optional, Union
+from typing import Callable, Iterable, List, Optional, Union
 
-from marshmallow import EXCLUDE, fields  # type: ignore
+try:
+    CLICHE_INSTALLED = False
+    import cliche
+    from cliche.arg_types.choices import Choices
+    from cliche.commands import ClicheCommandError
+    from netapp_ontap.resource_table import ResourceTable
+    CLICHE_INSTALLED = True
+except ImportError:
+    pass
 
-from netapp_ontap.resource import Resource, ResourceSchema
+from marshmallow import fields, EXCLUDE  # type: ignore
+
+import netapp_ontap
+from netapp_ontap.resource import Resource, ResourceSchema, ImpreciseDateTime, Size
 from netapp_ontap import NetAppResponse, HostConnection
 from netapp_ontap.validations import enum_validation, len_validation, integer_validation
 from netapp_ontap.error import NetAppRestError
@@ -35,8 +42,10 @@ from netapp_ontap.error import NetAppRestError
 __all__ = ["Svm", "SvmSchema"]
 __pdoc__ = {
     "SvmSchema.resource": False,
-    "SvmSchema.patchable_fields": False,
-    "SvmSchema.postable_fields": False,
+    "Svm.svm_show": False,
+    "Svm.svm_create": False,
+    "Svm.svm_modify": False,
+    "Svm.svm_delete": False,
 }
 
 
@@ -231,75 +240,159 @@ Valid choices:
 
 Example: 02c9e252-41be-11e9-81d5-00a0986138f7 """
 
+    volume_efficiency_policy = fields.Nested("netapp_ontap.resources.volume_efficiency_policy.VolumeEfficiencyPolicySchema", data_key="volume_efficiency_policy", unknown=EXCLUDE)
+    r""" The volume_efficiency_policy field of the svm. """
+
     @property
     def resource(self):
         return Svm
 
-    @property
-    def patchable_fields(self):
-        return [
-            "aggregates.name",
-            "aggregates.uuid",
-            "certificate.uuid",
-            "comment",
-            "fc_interfaces",
-            "ip_interfaces",
-            "language",
-            "name",
-            "nsswitch",
-            "snapmirror",
-            "snapshot_policy.name",
-            "snapshot_policy.uuid",
-            "state",
-        ]
+    gettable_fields = [
+        "links",
+        "aggregates.links",
+        "aggregates.name",
+        "aggregates.uuid",
+        "aggregates_delegated",
+        "certificate.links",
+        "certificate.name",
+        "certificate.uuid",
+        "cifs.links",
+        "cifs.ad_domain",
+        "cifs.enabled",
+        "cifs.name",
+        "comment",
+        "dns",
+        "fc_interfaces",
+        "fcp",
+        "ip_interfaces",
+        "ipspace.links",
+        "ipspace.name",
+        "ipspace.uuid",
+        "iscsi",
+        "language",
+        "ldap.ad_domain",
+        "ldap.base_dn",
+        "ldap.bind_dn",
+        "ldap.enabled",
+        "ldap.servers",
+        "name",
+        "nfs",
+        "nis",
+        "nsswitch",
+        "nvme",
+        "s3.links",
+        "s3.certificate",
+        "s3.enabled",
+        "s3.is_http_enabled",
+        "s3.is_https_enabled",
+        "s3.name",
+        "s3.port",
+        "s3.secure_port",
+        "snapmirror",
+        "snapshot_policy.links",
+        "snapshot_policy.name",
+        "snapshot_policy.uuid",
+        "state",
+        "subtype",
+        "uuid",
+        "volume_efficiency_policy.links",
+        "volume_efficiency_policy.name",
+        "volume_efficiency_policy.uuid",
+    ]
+    """links,aggregates.links,aggregates.name,aggregates.uuid,aggregates_delegated,certificate.links,certificate.name,certificate.uuid,cifs.links,cifs.ad_domain,cifs.enabled,cifs.name,comment,dns,fc_interfaces,fcp,ip_interfaces,ipspace.links,ipspace.name,ipspace.uuid,iscsi,language,ldap.ad_domain,ldap.base_dn,ldap.bind_dn,ldap.enabled,ldap.servers,name,nfs,nis,nsswitch,nvme,s3.links,s3.certificate,s3.enabled,s3.is_http_enabled,s3.is_https_enabled,s3.name,s3.port,s3.secure_port,snapmirror,snapshot_policy.links,snapshot_policy.name,snapshot_policy.uuid,state,subtype,uuid,volume_efficiency_policy.links,volume_efficiency_policy.name,volume_efficiency_policy.uuid,"""
 
-    @property
-    def postable_fields(self):
-        return [
-            "aggregates.name",
-            "aggregates.uuid",
-            "cifs.ad_domain",
-            "cifs.enabled",
-            "cifs.name",
-            "comment",
-            "dns",
-            "fc_interfaces",
-            "fcp",
-            "ip_interfaces",
-            "ipspace.name",
-            "ipspace.uuid",
-            "iscsi",
-            "language",
-            "ldap.ad_domain",
-            "ldap.base_dn",
-            "ldap.bind_dn",
-            "ldap.enabled",
-            "ldap.servers",
-            "name",
-            "nfs",
-            "nis",
-            "nsswitch",
-            "nvme",
-            "routes",
-            "s3.enabled",
-            "s3.name",
-            "snapmirror",
-            "snapshot_policy.name",
-            "snapshot_policy.uuid",
-            "subtype",
-        ]
+    patchable_fields = [
+        "aggregates.name",
+        "aggregates.uuid",
+        "certificate.name",
+        "certificate.uuid",
+        "comment",
+        "ip_interfaces",
+        "language",
+        "name",
+        "nsswitch",
+        "snapmirror",
+        "snapshot_policy.name",
+        "snapshot_policy.uuid",
+        "state",
+        "volume_efficiency_policy.name",
+        "volume_efficiency_policy.uuid",
+    ]
+    """aggregates.name,aggregates.uuid,certificate.name,certificate.uuid,comment,ip_interfaces,language,name,nsswitch,snapmirror,snapshot_policy.name,snapshot_policy.uuid,state,volume_efficiency_policy.name,volume_efficiency_policy.uuid,"""
+
+    postable_fields = [
+        "aggregates.name",
+        "aggregates.uuid",
+        "cifs.ad_domain",
+        "cifs.enabled",
+        "cifs.name",
+        "comment",
+        "dns",
+        "fc_interfaces",
+        "fcp",
+        "ip_interfaces",
+        "ipspace.name",
+        "ipspace.uuid",
+        "iscsi",
+        "language",
+        "ldap.ad_domain",
+        "ldap.base_dn",
+        "ldap.bind_dn",
+        "ldap.enabled",
+        "ldap.servers",
+        "name",
+        "nfs",
+        "nis",
+        "nsswitch",
+        "nvme",
+        "routes",
+        "s3.certificate",
+        "s3.enabled",
+        "s3.is_http_enabled",
+        "s3.is_https_enabled",
+        "s3.name",
+        "s3.port",
+        "s3.secure_port",
+        "snapmirror",
+        "snapshot_policy.name",
+        "snapshot_policy.uuid",
+        "subtype",
+        "volume_efficiency_policy.name",
+        "volume_efficiency_policy.uuid",
+    ]
+    """aggregates.name,aggregates.uuid,cifs.ad_domain,cifs.enabled,cifs.name,comment,dns,fc_interfaces,fcp,ip_interfaces,ipspace.name,ipspace.uuid,iscsi,language,ldap.ad_domain,ldap.base_dn,ldap.bind_dn,ldap.enabled,ldap.servers,name,nfs,nis,nsswitch,nvme,routes,s3.certificate,s3.enabled,s3.is_http_enabled,s3.is_https_enabled,s3.name,s3.port,s3.secure_port,snapmirror,snapshot_policy.name,snapshot_policy.uuid,subtype,volume_efficiency_policy.name,volume_efficiency_policy.uuid,"""
+
+def _get_field_list(field: str) -> Callable[[], List]:
+    def getter():
+        return [getattr(r, field) for r in Svm.get_collection(fields=field)]
+    return getter
+
+async def _wait_for_job(response: NetAppResponse) -> None:
+    """Examine the given response. If it is a job, asynchronously wait for it to
+    complete. While polling, prints the current status message of the job.
+    """
+
+    if not response.is_job:
+        return
+    from netapp_ontap.resources import Job
+    job = Job(**response.http_response.json()["job"])
+    while True:
+        job.get(fields="state,message")
+        if hasattr(job, "message"):
+            print("[%s]: %s" % (job.state, job.message))
+        if job.state == "failure":
+            raise NetAppRestError("Svm modify job failed")
+        if job.state == "success":
+            break
+        await asyncio.sleep(1)
 
 class Svm(Resource):
     """Allows interaction with Svm objects on the host"""
 
     _schema = SvmSchema
     _path = "/api/svm/svms"
-    @property
-    def _keys(self):
-        return ["uuid"]
+    _keys = ["uuid"]
 
-    # pylint: disable=bad-continuation
-    # pylint: disable=missing-docstring
     @classmethod
     def get_collection(
         cls,
@@ -314,7 +407,7 @@ class Svm(Resource):
 * It is not recommended to create or delete more than five SVMs in parallel.
 * REST APIs only expose a data SVM as an SVM.
 ### Expensive properties
-There is an added cost to retrieving values for these properties. They are not included by default in GET results and must be explicitly requested using the `fields` query parameter. See [`DOC Requesting specific fields`](#docs-docs-Requesting-specific-fields) to learn more.
+There is an added cost to retrieving values for these properties. They are not included by default in GET results and must be explicitly requested using the `fields` query parameter. See [`Requesting specific fields`](#Requesting_specific_fields) to learn more.
 * `snapmirror.*`
 ### Related ONTAP commands
 * `vserver show`
@@ -348,10 +441,55 @@ There is an added cost to retrieving values for these properties. They are not i
 """
         return super()._get_collection(*args, connection=connection, max_records=max_records, **kwargs)
 
-    get_collection.__func__.__doc__ += "\n\n---\n" + inspect.cleandoc(Resource._get_collection.__doc__)  # pylint: disable=no-member
+    get_collection.__func__.__doc__ += "\n\n---\n" + inspect.cleandoc(Resource._get_collection.__doc__)
+
+    if CLICHE_INSTALLED:
+        @cliche.command(name="svm show")
+        def svm_show(
+            aggregates_delegated: Choices.define(_get_field_list("aggregates_delegated"), cache_choices=True, inexact=True)=None,
+            comment: Choices.define(_get_field_list("comment"), cache_choices=True, inexact=True)=None,
+            language: Choices.define(_get_field_list("language"), cache_choices=True, inexact=True)=None,
+            name: Choices.define(_get_field_list("name"), cache_choices=True, inexact=True)=None,
+            state: Choices.define(_get_field_list("state"), cache_choices=True, inexact=True)=None,
+            subtype: Choices.define(_get_field_list("subtype"), cache_choices=True, inexact=True)=None,
+            uuid: Choices.define(_get_field_list("uuid"), cache_choices=True, inexact=True)=None,
+            fields: List[Choices.define(["aggregates_delegated", "comment", "language", "name", "state", "subtype", "uuid", "*"])]=None,
+        ) -> ResourceTable:
+            """Fetch a list of Svm resources
+
+            Args:
+                aggregates_delegated: This property is true when the administrator has delegated the aggregates for the SVM volumes.
+                comment: Comment
+                language: Default volume language code. UTF-8 encoded languages are valid in POST or PATCH. Non UTF-8 language encodings are for backward compatibility and are not valid input for POST and PATCH requests.
+                name: The name of the SVM. 
+                state: SVM State
+                subtype: SVM subtype. The SVM subtype sync_destination is created automatically when an SVM of subtype sync_source is created on the source MetroCluster cluster. A POST request with sync_destination as SVM subtype is invalid.
+                uuid: The unique identifier of the SVM. 
+            """
+
+            kwargs = {}
+            if aggregates_delegated is not None:
+                kwargs["aggregates_delegated"] = aggregates_delegated
+            if comment is not None:
+                kwargs["comment"] = comment
+            if language is not None:
+                kwargs["language"] = language
+            if name is not None:
+                kwargs["name"] = name
+            if state is not None:
+                kwargs["state"] = state
+            if subtype is not None:
+                kwargs["subtype"] = subtype
+            if uuid is not None:
+                kwargs["uuid"] = uuid
+            if fields is not None:
+                fields = ",".join(fields)
+                kwargs["fields"] = fields
+
+            return Svm.get_collection(
+                **kwargs
+            )
 
-    # pylint: disable=bad-continuation
-    # pylint: disable=missing-docstring
     @classmethod
     def count_collection(
         cls,
@@ -365,7 +503,7 @@ There is an added cost to retrieving values for these properties. They are not i
 * It is not recommended to create or delete more than five SVMs in parallel.
 * REST APIs only expose a data SVM as an SVM.
 ### Expensive properties
-There is an added cost to retrieving values for these properties. They are not included by default in GET results and must be explicitly requested using the `fields` query parameter. See [`DOC Requesting specific fields`](#docs-docs-Requesting-specific-fields) to learn more.
+There is an added cost to retrieving values for these properties. They are not included by default in GET results and must be explicitly requested using the `fields` query parameter. See [`Requesting specific fields`](#Requesting_specific_fields) to learn more.
 * `snapmirror.*`
 ### Related ONTAP commands
 * `vserver show`
@@ -399,10 +537,8 @@ There is an added cost to retrieving values for these properties. They are not i
 """
         return super()._count_collection(*args, connection=connection, **kwargs)
 
-    count_collection.__func__.__doc__ += "\n\n---\n" + inspect.cleandoc(Resource._count_collection.__doc__)  # pylint: disable=no-member
+    count_collection.__func__.__doc__ += "\n\n---\n" + inspect.cleandoc(Resource._count_collection.__doc__)
 
-    # pylint: disable=bad-continuation
-    # pylint: disable=missing-docstring
     @classmethod
     def patch_collection(
         cls,
@@ -466,10 +602,8 @@ There is an added cost to retrieving values for these properties. They are not i
 """
         return super()._patch_collection(body, *args, connection=connection, **kwargs)
 
-    patch_collection.__func__.__doc__ += "\n\n---\n" + inspect.cleandoc(Resource._patch_collection.__doc__)  # pylint: disable=no-member
+    patch_collection.__func__.__doc__ += "\n\n---\n" + inspect.cleandoc(Resource._patch_collection.__doc__)
 
-    # pylint: disable=bad-continuation
-    # pylint: disable=missing-docstring
     @classmethod
     def delete_collection(
         cls,
@@ -495,9 +629,8 @@ Deleting an individual SVM in the cluster.
 """
         return super()._delete_collection(*args, body=body, connection=connection, **kwargs)
 
-    delete_collection.__func__.__doc__ += "\n\n---\n" + inspect.cleandoc(Resource._delete_collection.__doc__)  # pylint: disable=no-member
+    delete_collection.__func__.__doc__ += "\n\n---\n" + inspect.cleandoc(Resource._delete_collection.__doc__)
 
-    # pylint: disable=missing-docstring
     @classmethod
     def find(cls, *args, connection: HostConnection = None, **kwargs) -> Resource:
         r"""Retrieves a list of SVMs and individual SVM properties. This includes protocol configurations such as CIFS and NFS, export policies, name service configurations, and network services.
@@ -506,7 +639,7 @@ Deleting an individual SVM in the cluster.
 * It is not recommended to create or delete more than five SVMs in parallel.
 * REST APIs only expose a data SVM as an SVM.
 ### Expensive properties
-There is an added cost to retrieving values for these properties. They are not included by default in GET results and must be explicitly requested using the `fields` query parameter. See [`DOC Requesting specific fields`](#docs-docs-Requesting-specific-fields) to learn more.
+There is an added cost to retrieving values for these properties. They are not included by default in GET results and must be explicitly requested using the `fields` query parameter. See [`Requesting specific fields`](#Requesting_specific_fields) to learn more.
 * `snapmirror.*`
 ### Related ONTAP commands
 * `vserver show`
@@ -540,16 +673,15 @@ There is an added cost to retrieving values for these properties. They are not i
 """
         return super()._find(*args, connection=connection, **kwargs)
 
-    find.__func__.__doc__ += "\n\n---\n" + inspect.cleandoc(Resource._find.__doc__)  # pylint: disable=no-member
+    find.__func__.__doc__ += "\n\n---\n" + inspect.cleandoc(Resource._find.__doc__)
 
-    # pylint: disable=missing-docstring
     def get(self, **kwargs) -> NetAppResponse:
         r"""Retrieves the properties for an individual SVM. This includes protocol configurations such as CIFS and NFS, export policies, name service configurations, and network services.
 ### Important notes
 * The SVM object includes a large set of fields and can be expensive to retrieve.
 * REST APIs only expose a data SVM as an SVM.
 ### Expensive properties
-There is an added cost to retrieving values for these properties. They are not included by default in GET results and must be explicitly requested using the `fields` query parameter. See [`DOC Requesting specific fields`](#docs-docs-Requesting-specific-fields) to learn more.
+There is an added cost to retrieving values for these properties. They are not included by default in GET results and must be explicitly requested using the `fields` query parameter. See [`Requesting specific fields`](#Requesting_specific_fields) to learn more.
 * `snapmirror.*`
 ### Example
     Retrieving an individual SVM in the cluster
@@ -563,10 +695,8 @@ There is an added cost to retrieving values for these properties. They are not i
 * [`DOC /svm/svms`](#docs-svm-svm_svms)"""
         return super()._get(**kwargs)
 
-    get.__doc__ += "\n\n---\n" + inspect.cleandoc(Resource._get.__doc__)  # pylint: disable=no-member
+    get.__doc__ += "\n\n---\n" + inspect.cleandoc(Resource._get.__doc__)
 
-    # pylint: disable=missing-docstring
-    # pylint: disable=bad-continuation
     def post(
         self,
         hydrate: bool = False,
@@ -700,10 +830,138 @@ If not specified in POST, the following default property values are assigned:
             poll_timeout=poll_timeout, **kwargs
         )
 
-    post.__doc__ += "\n\n---\n" + inspect.cleandoc(Resource._post.__doc__)  # pylint: disable=no-member
+    post.__doc__ += "\n\n---\n" + inspect.cleandoc(Resource._post.__doc__)
+
+    if CLICHE_INSTALLED:
+        @cliche.command(name="svm create")
+        async def svm_create(
+            links: dict = None,
+            aggregates: dict = None,
+            aggregates_delegated: bool = None,
+            certificate: dict = None,
+            cifs: dict = None,
+            comment: str = None,
+            dns: dict = None,
+            fc_interfaces: dict = None,
+            fcp: dict = None,
+            ip_interfaces: dict = None,
+            ipspace: dict = None,
+            iscsi: dict = None,
+            language: str = None,
+            ldap: dict = None,
+            name: str = None,
+            nfs: dict = None,
+            nis: dict = None,
+            nsswitch: dict = None,
+            nvme: dict = None,
+            routes: dict = None,
+            s3: dict = None,
+            snapmirror: dict = None,
+            snapshot_policy: dict = None,
+            state: str = None,
+            subtype: str = None,
+            uuid: str = None,
+            volume_efficiency_policy: dict = None,
+        ) -> ResourceTable:
+            """Create an instance of a Svm resource
+
+            Args:
+                links: 
+                aggregates: List of allowed aggregates for SVM volumes. An administrator is allowed to create volumes on these aggregates.
+                aggregates_delegated: This property is true when the administrator has delegated the aggregates for the SVM volumes.
+                certificate: 
+                cifs: 
+                comment: Comment
+                dns: 
+                fc_interfaces: FC Interface for the SVM
+                fcp: 
+                ip_interfaces: IP interfaces for the SVM
+                ipspace: 
+                iscsi: 
+                language: Default volume language code. UTF-8 encoded languages are valid in POST or PATCH. Non UTF-8 language encodings are for backward compatibility and are not valid input for POST and PATCH requests.
+                ldap: 
+                name: The name of the SVM. 
+                nfs: 
+                nis: 
+                nsswitch: 
+                nvme: 
+                routes: Optional array of routes for the SVM
+                s3: 
+                snapmirror: 
+                snapshot_policy: 
+                state: SVM State
+                subtype: SVM subtype. The SVM subtype sync_destination is created automatically when an SVM of subtype sync_source is created on the source MetroCluster cluster. A POST request with sync_destination as SVM subtype is invalid.
+                uuid: The unique identifier of the SVM. 
+                volume_efficiency_policy: 
+            """
+
+            kwargs = {}
+            if links is not None:
+                kwargs["links"] = links
+            if aggregates is not None:
+                kwargs["aggregates"] = aggregates
+            if aggregates_delegated is not None:
+                kwargs["aggregates_delegated"] = aggregates_delegated
+            if certificate is not None:
+                kwargs["certificate"] = certificate
+            if cifs is not None:
+                kwargs["cifs"] = cifs
+            if comment is not None:
+                kwargs["comment"] = comment
+            if dns is not None:
+                kwargs["dns"] = dns
+            if fc_interfaces is not None:
+                kwargs["fc_interfaces"] = fc_interfaces
+            if fcp is not None:
+                kwargs["fcp"] = fcp
+            if ip_interfaces is not None:
+                kwargs["ip_interfaces"] = ip_interfaces
+            if ipspace is not None:
+                kwargs["ipspace"] = ipspace
+            if iscsi is not None:
+                kwargs["iscsi"] = iscsi
+            if language is not None:
+                kwargs["language"] = language
+            if ldap is not None:
+                kwargs["ldap"] = ldap
+            if name is not None:
+                kwargs["name"] = name
+            if nfs is not None:
+                kwargs["nfs"] = nfs
+            if nis is not None:
+                kwargs["nis"] = nis
+            if nsswitch is not None:
+                kwargs["nsswitch"] = nsswitch
+            if nvme is not None:
+                kwargs["nvme"] = nvme
+            if routes is not None:
+                kwargs["routes"] = routes
+            if s3 is not None:
+                kwargs["s3"] = s3
+            if snapmirror is not None:
+                kwargs["snapmirror"] = snapmirror
+            if snapshot_policy is not None:
+                kwargs["snapshot_policy"] = snapshot_policy
+            if state is not None:
+                kwargs["state"] = state
+            if subtype is not None:
+                kwargs["subtype"] = subtype
+            if uuid is not None:
+                kwargs["uuid"] = uuid
+            if volume_efficiency_policy is not None:
+                kwargs["volume_efficiency_policy"] = volume_efficiency_policy
+
+            resource = Svm(
+                **kwargs
+            )
+            try:
+                response = resource.post(hydrate=True, poll=False)
+                await _wait_for_job(response)
+                resource.get()
+            except NetAppRestError as err:
+                raise ClicheCommandError("Unable to create Svm: %s" % err)
+            return [resource]
 
-    # pylint: disable=missing-docstring
-    # pylint: disable=bad-continuation
     def patch(
         self,
         hydrate: bool = False,
@@ -770,10 +1028,93 @@ If not specified in POST, the following default property values are assigned:
             poll_timeout=poll_timeout, **kwargs
         )
 
-    patch.__doc__ += "\n\n---\n" + inspect.cleandoc(Resource._patch.__doc__)  # pylint: disable=no-member
+    patch.__doc__ += "\n\n---\n" + inspect.cleandoc(Resource._patch.__doc__)
+
+    if CLICHE_INSTALLED:
+        @cliche.command(name="svm modify")
+        async def svm_modify(
+            aggregates_delegated: bool = None,
+            query_aggregates_delegated: bool = None,
+            comment: str = None,
+            query_comment: str = None,
+            language: str = None,
+            query_language: str = None,
+            name: str = None,
+            query_name: str = None,
+            state: str = None,
+            query_state: str = None,
+            subtype: str = None,
+            query_subtype: str = None,
+            uuid: str = None,
+            query_uuid: str = None,
+        ) -> ResourceTable:
+            """Modify an instance of a Svm resource
+
+            Args:
+                aggregates_delegated: This property is true when the administrator has delegated the aggregates for the SVM volumes.
+                query_aggregates_delegated: This property is true when the administrator has delegated the aggregates for the SVM volumes.
+                comment: Comment
+                query_comment: Comment
+                language: Default volume language code. UTF-8 encoded languages are valid in POST or PATCH. Non UTF-8 language encodings are for backward compatibility and are not valid input for POST and PATCH requests.
+                query_language: Default volume language code. UTF-8 encoded languages are valid in POST or PATCH. Non UTF-8 language encodings are for backward compatibility and are not valid input for POST and PATCH requests.
+                name: The name of the SVM. 
+                query_name: The name of the SVM. 
+                state: SVM State
+                query_state: SVM State
+                subtype: SVM subtype. The SVM subtype sync_destination is created automatically when an SVM of subtype sync_source is created on the source MetroCluster cluster. A POST request with sync_destination as SVM subtype is invalid.
+                query_subtype: SVM subtype. The SVM subtype sync_destination is created automatically when an SVM of subtype sync_source is created on the source MetroCluster cluster. A POST request with sync_destination as SVM subtype is invalid.
+                uuid: The unique identifier of the SVM. 
+                query_uuid: The unique identifier of the SVM. 
+            """
+
+            kwargs = {}
+            changes = {}
+            if query_aggregates_delegated is not None:
+                kwargs["aggregates_delegated"] = query_aggregates_delegated
+            if query_comment is not None:
+                kwargs["comment"] = query_comment
+            if query_language is not None:
+                kwargs["language"] = query_language
+            if query_name is not None:
+                kwargs["name"] = query_name
+            if query_state is not None:
+                kwargs["state"] = query_state
+            if query_subtype is not None:
+                kwargs["subtype"] = query_subtype
+            if query_uuid is not None:
+                kwargs["uuid"] = query_uuid
+
+            if aggregates_delegated is not None:
+                changes["aggregates_delegated"] = aggregates_delegated
+            if comment is not None:
+                changes["comment"] = comment
+            if language is not None:
+                changes["language"] = language
+            if name is not None:
+                changes["name"] = name
+            if state is not None:
+                changes["state"] = state
+            if subtype is not None:
+                changes["subtype"] = subtype
+            if uuid is not None:
+                changes["uuid"] = uuid
+
+            if hasattr(Svm, "find"):
+                resource = Svm.find(
+                    **kwargs
+                )
+            else:
+                resource = Svm()
+            try:
+                for key, value in changes.items():
+                    setattr(resource, key, value)
+                response = resource.patch(poll=False)
+                await _wait_for_job(response)
+                resource.get(fields=",".join(changes.keys()))
+                return [resource]
+            except NetAppRestError as err:
+                raise ClicheCommandError("Unable to modify Svm: %s" % err)
 
-    # pylint: disable=missing-docstring
-    # pylint: disable=bad-continuation
     def delete(
         self,
         body: Union[Resource, dict] = None,
@@ -802,6 +1143,57 @@ Deleting an individual SVM in the cluster.
             poll_timeout=poll_timeout, **kwargs
         )
 
-    delete.__doc__ += "\n\n---\n" + inspect.cleandoc(Resource._delete.__doc__)  # pylint: disable=no-member
+    delete.__doc__ += "\n\n---\n" + inspect.cleandoc(Resource._delete.__doc__)
+
+    if CLICHE_INSTALLED:
+        @cliche.command(name="svm delete")
+        async def svm_delete(
+            aggregates_delegated: bool = None,
+            comment: str = None,
+            language: str = None,
+            name: str = None,
+            state: str = None,
+            subtype: str = None,
+            uuid: str = None,
+        ) -> None:
+            """Delete an instance of a Svm resource
+
+            Args:
+                aggregates_delegated: This property is true when the administrator has delegated the aggregates for the SVM volumes.
+                comment: Comment
+                language: Default volume language code. UTF-8 encoded languages are valid in POST or PATCH. Non UTF-8 language encodings are for backward compatibility and are not valid input for POST and PATCH requests.
+                name: The name of the SVM. 
+                state: SVM State
+                subtype: SVM subtype. The SVM subtype sync_destination is created automatically when an SVM of subtype sync_source is created on the source MetroCluster cluster. A POST request with sync_destination as SVM subtype is invalid.
+                uuid: The unique identifier of the SVM. 
+            """
+
+            kwargs = {}
+            if aggregates_delegated is not None:
+                kwargs["aggregates_delegated"] = aggregates_delegated
+            if comment is not None:
+                kwargs["comment"] = comment
+            if language is not None:
+                kwargs["language"] = language
+            if name is not None:
+                kwargs["name"] = name
+            if state is not None:
+                kwargs["state"] = state
+            if subtype is not None:
+                kwargs["subtype"] = subtype
+            if uuid is not None:
+                kwargs["uuid"] = uuid
+
+            if hasattr(Svm, "find"):
+                resource = Svm.find(
+                    **kwargs
+                )
+            else:
+                resource = Svm()
+            try:
+                response = resource.delete(poll=False)
+                await _wait_for_job(response)
+            except NetAppRestError as err:
+                raise ClicheCommandError("Unable to delete Svm: %s" % err)
 
 
